pub unsafe fn __tile_movrow(src: __tile1024i, row: u32) -> __m512i🔬This is a nightly-only experimental API. (
x86_amx_intrinsics)Expand description
Moves one row of tile data into a zmm vector register
The shape of the tile is specified in the struct of __tile1024i. The register of the tile is allocated by the compiler.