Freeze

Trait Freeze 

pub unsafe auto trait Freeze { }
๐Ÿ”ฌThis is a nightly-only experimental API. (freeze)
Used to determine whether a type contains any UnsafeCell internally, but not through an indirection. This affects, for example, whether a static of that type is placed in read-only static memory or writable static memory. This can be used to declare that a constant with a generic type will not contain interior mutability, and subsequently allow placing the constant behind references.

Safety

This trait is a core part of the language, it is just expressed as a trait in libcore for convenience. Do not implement it for other types.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> !Freeze for UnsafeCell<T>
where T: ?Sized,

Source

impl<T> Freeze for &T
where T: ?Sized,

Source

impl<T> Freeze for &mut T
where T: ?Sized,

Source

impl<T> Freeze for *const T is !null
where T: ?Sized,

Source

impl<T> Freeze for *const T
where T: ?Sized,

Source

impl<T> Freeze for *mut T is !null
where T: ?Sized,

Source

impl<T> Freeze for *mut T
where T: ?Sized,

1.28.0 ยท Source

impl<T> Freeze for NonZero<T>

Source

impl<T> Freeze for PhantomData<T>
where T: ?Sized,

Auto implementors



impl Freeze for wasmtime_environ::Abi



impl Freeze for wasmtime_environ::__core::mem::type_info::Abi



impl Freeze for AbstractResourceIndex



impl Freeze for Adapter



impl Freeze for AdapterId



impl Freeze for AdapterModuleId



impl Freeze for AdapterOptions



impl Freeze for AddrParseError



impl Freeze for AddressMapSection



impl Freeze for wasmtime_environ::__core::mem::Alignment



impl Freeze for wasmtime_environ::__core::fmt::Alignment



impl Freeze for AllocError



impl Freeze for Array



impl Freeze for AsciiChar



impl Freeze for Assume



impl Freeze for Atom



impl Freeze for AtomicOrdering



impl Freeze for BasicBlock



impl Freeze for BorrowError



impl Freeze for BorrowMutError



impl Freeze for BuiltinFunctionIndex



impl Freeze for ByteStr



impl Freeze for CStr



impl Freeze for CallbackId



impl Freeze for CanonicalAbiInfo



impl Freeze for wasmtime_environ::component::CanonicalOptions



impl Freeze for wasmtime_environ::component::dfg::CanonicalOptions



impl Freeze for wasmtime_environ::component::CanonicalOptionsDataModel



impl Freeze for wasmtime_environ::component::dfg::CanonicalOptionsDataModel



impl Freeze for CharCase



impl Freeze for CharTryFromError



impl Freeze for Collector



impl Freeze for CompileError



impl Freeze for CompiledComponentInfo



impl Freeze for CompiledFunctionBody



impl Freeze for CompiledFunctionsTable



impl Freeze for CompiledFunctionsTableBuilder



impl Freeze for CompiledModuleInfo



impl Freeze for CompiledTrap



impl Freeze for Component



impl Freeze for ComponentArtifacts



impl Freeze for ComponentBuiltinFunctionIndex



impl Freeze for ComponentDfg



impl Freeze for ComponentExtern



impl Freeze for ComponentExternData



impl Freeze for ComponentFuncIndex



impl Freeze for ComponentIndex



impl Freeze for ComponentInstanceIndex



impl Freeze for ComponentItem



impl Freeze for ComponentPC



impl Freeze for ComponentTranslation



impl Freeze for ComponentTypeIndex



impl Freeze for ComponentTypes



impl Freeze for ComponentTypesBuilder



impl Freeze for ComponentUpvarIndex



impl Freeze for ConfigTunables



impl Freeze for Const



impl Freeze for ConstExpr



impl Freeze for ConstOp



impl Freeze for CopyingTypeLayouts



impl Freeze for wasmtime_environ::component::CoreDef



impl Freeze for wasmtime_environ::component::dfg::CoreDef



impl Freeze for CpuidResult



impl Freeze for DataIndex



impl Freeze for DataModel



impl Freeze for DebugAsHex



impl Freeze for DecodeUtf16Error



impl Freeze for DefaultHasher



impl Freeze for DefinedFuncIndex



impl Freeze for DefinedGlobalIndex



impl Freeze for DefinedMemoryIndex



impl Freeze for DefinedResourceIndex



impl Freeze for DefinedTableIndex



impl Freeze for DefinedTagIndex



impl Freeze for DrcTypeLayouts



impl Freeze for Duration



impl Freeze for DynTrait



impl Freeze for DynTraitPredicate



impl Freeze for ElemIndex



impl Freeze for wasmtime_environ::__core::io::Empty



impl Freeze for EngineInternedRecGroupIndex



impl Freeze for EngineOrModuleTypeIndex



impl Freeze for EntityIndex



impl Freeze for EntityType



impl Freeze for wasmtime_environ::prelude::Error



impl Freeze for wasmtime_environ::__core::io::Error



impl Freeze for wasmtime_environ::__core::fmt::Error



impl Freeze for ErrorKind



impl Freeze for wasmtime_environ::__core::char::EscapeDebug



impl Freeze for wasmtime_environ::__core::ascii::EscapeDefault



impl Freeze for wasmtime_environ::__core::char::EscapeDefault



impl Freeze for wasmtime_environ::__core::char::EscapeUnicode



impl Freeze for Evaporation



impl Freeze for wasmtime_environ::component::Export



impl Freeze for wasmtime_environ::component::dfg::Export



impl Freeze for ExportIndex



impl Freeze for ExtractCallback



impl Freeze for ExtractMemory



impl Freeze for ExtractPostReturn



impl Freeze for ExtractRealloc



impl Freeze for ExtractTable



impl Freeze for FactInlineIntrinsic



impl Freeze for FieldId



impl Freeze for FilePos



impl Freeze for FixedEncoding



impl Freeze for FlatType



impl Freeze for FnPtr



impl Freeze for FormattingOptions



impl Freeze for FpCategory



impl Freeze for FrameInstPos



impl Freeze for FrameStackShape



impl Freeze for FrameStateSlotBuilder



impl Freeze for FrameStateSlotOffset



impl Freeze for FrameTableBuilder



impl Freeze for FrameTableDescriptorIndex



impl Freeze for FrameValType



impl Freeze for FromBytesUntilNulError



impl Freeze for FromBytesWithNulError



impl Freeze for FuncIndex



impl Freeze for FuncKey



impl Freeze for FuncKeyIndex



impl Freeze for FuncKeyKind



impl Freeze for FuncKeyNamespace



impl Freeze for FuncRefIndex



impl Freeze for FunctionLoc



impl Freeze for FunctionMetadata



impl Freeze for FunctionName



impl Freeze for FunctionType



impl Freeze for FutureInfo



impl Freeze for GcArrayLayout



impl Freeze for GcLayout



impl Freeze for GcStructLayout



impl Freeze for GcStructLayoutField



impl Freeze for Generic



impl Freeze for GenericType



impl Freeze for GetDisjointMutError



impl Freeze for Global



impl Freeze for GlobalConstValue



impl Freeze for GlobalIndex



impl Freeze for GlobalInitializer



impl Freeze for HostCall



impl Freeze for HostPtr



impl Freeze for Import



impl Freeze for ImportIndex



impl Freeze for IndexType



impl Freeze for Infallible



impl Freeze for Initializer



impl Freeze for InlineTraceInfo



impl Freeze for Inlining



impl Freeze for Instance



impl Freeze for InstanceId



impl Freeze for InstantiateModule



impl Freeze for InstructionAddressMap



impl Freeze for IntErrorKind



impl Freeze for InterfaceType



impl Freeze for IpAddr



impl Freeze for Ipv4Addr



impl Freeze for Ipv6Addr



impl Freeze for Ipv6MulticastScope



impl Freeze for KnownFunc



impl Freeze for KnownGlobal



impl Freeze for Last



impl Freeze for Layout



impl Freeze for LayoutError



impl Freeze for Lifetime



impl Freeze for Limits



impl Freeze for LinearMemoryOptions



impl Freeze for LocalDataModel



impl Freeze for LocalWaker



impl Freeze for Locality



impl Freeze for LoweredIndex



impl Freeze for Memory



impl Freeze for MemoryId



impl Freeze for MemoryIndex



impl Freeze for MemoryInitialization



impl Freeze for MemoryKind



impl Freeze for MemorySegmentOffset



impl Freeze for Metadata



impl Freeze for wasmtime_environ::Module



impl Freeze for ModuleIndex



impl Freeze for ModuleInstanceIndex



impl Freeze for ModuleInternedRecGroupIndex



impl Freeze for ModuleInternedTypeIndex



impl Freeze for ModulePC



impl Freeze for ModuleStartup



impl Freeze for ModuleTypes



impl Freeze for ModuleTypesBuilder



impl Freeze for ModuleUpvarIndex



impl Freeze for NameMapNoIntern



impl Freeze for NonMaxU8



impl Freeze for NonMaxU16



impl Freeze for NonMaxU32



impl Freeze for NonMaxU64



impl Freeze for NonMaxUsize



impl Freeze for NullTypeLayouts



impl Freeze for ObjectCrateErrorWrapper



impl Freeze for ObjectKind



impl Freeze for OneSidedRangeBound



impl Freeze for OperatorCost



impl Freeze for OperatorCostStrategy



impl Freeze for OptionsId



impl Freeze for OptionsIndex



impl Freeze for wasmtime_environ::__core::cmp::Ordering



impl Freeze for wasmtime_environ::__core::sync::atomic::Ordering



impl Freeze for OutOfMemory



impl Freeze for OwnedMemoryIndex



impl Freeze for ParseBoolError



impl Freeze for ParseCharError



impl Freeze for ParseFloatError



impl Freeze for ParseIntError



impl Freeze for PassiveElemIndex



impl Freeze for PhantomPinned



impl Freeze for Pointer



impl Freeze for PostReturnId



impl Freeze for RandomState



impl Freeze for RangeFull



impl Freeze for RawWaker



impl Freeze for RawWakerVTable



impl Freeze for ReallocId



impl Freeze for RecGroupRelativeTypeIndex



impl Freeze for RecordField



impl Freeze for Reference



impl Freeze for wasmtime_environ::__core::io::Repeat



impl Freeze for wasmtime_environ::component::Resource



impl Freeze for wasmtime_environ::component::dfg::Resource



impl Freeze for ResourceIndex



impl Freeze for ResourcesBuilder



impl Freeze for ReturnToArg



impl Freeze for RuntimeCallbackIndex



impl Freeze for RuntimeComponentInstanceIndex



impl Freeze for RuntimeDataIndex



impl Freeze for RuntimeImportIndex



impl Freeze for RuntimeInstanceIndex



impl Freeze for RuntimeMemoryIndex



impl Freeze for RuntimePostReturnIndex



impl Freeze for RuntimeReallocIndex



impl Freeze for RuntimeTableIndex



impl Freeze for Scc



impl Freeze for SearchStep



impl Freeze for SeekFrom



impl Freeze for Setting



impl Freeze for SettingKind



impl Freeze for SideEffect



impl Freeze for Sign



impl Freeze for SimdAlign



impl Freeze for Sink



impl Freeze for SipHasher



impl Freeze for SizeOverflow



impl Freeze for Slice



impl Freeze for SocketAddr



impl Freeze for SocketAddrV4



impl Freeze for SocketAddrV6



impl Freeze for StackMapSection



impl Freeze for StaticComponentIndex



impl Freeze for StaticModuleIndex



impl Freeze for Str



impl Freeze for StreamInfo



impl Freeze for String



impl Freeze for StringEncoding



impl Freeze for StringPool



impl Freeze for Table



impl Freeze for TableId



impl Freeze for TableIndex



impl Freeze for TableInitialValue



impl Freeze for TableInitialization



impl Freeze for TableSegment



impl Freeze for TableSegmentElements



impl Freeze for Tag



impl Freeze for TagIndex



impl Freeze for ToCasefold



impl Freeze for ToLowercase



impl Freeze for ToTitlecase



impl Freeze for ToUppercase



impl Freeze for Trait



impl Freeze for wasmtime_environ::component::Trampoline



impl Freeze for wasmtime_environ::component::dfg::Trampoline



impl Freeze for TrampolineIndex



impl Freeze for Transcode



impl Freeze for Trap



impl Freeze for TrapEncodingBuilder



impl Freeze for TrapInformation



impl Freeze for TrapSentinel



impl Freeze for TryFromCharError



impl Freeze for TryFromFloatSecsError



impl Freeze for TryFromIntError



impl Freeze for TryFromSliceError



impl Freeze for TryString



impl Freeze for Tunables



impl Freeze for Type



impl Freeze for TypeComponent



impl Freeze for TypeComponentGlobalErrorContextTableIndex



impl Freeze for TypeComponentIndex



impl Freeze for TypeComponentInstance



impl Freeze for TypeComponentInstanceIndex



impl Freeze for TypeComponentLocalErrorContextTableIndex



impl Freeze for TypeDef



impl Freeze for TypeEnum



impl Freeze for TypeEnumIndex



impl Freeze for TypeErrorContextTable



impl Freeze for TypeFixedLengthList



impl Freeze for TypeFixedLengthListIndex



impl Freeze for TypeFlags



impl Freeze for TypeFlagsIndex



impl Freeze for TypeFunc



impl Freeze for TypeFuncIndex



impl Freeze for TypeFuture



impl Freeze for TypeFutureIndex



impl Freeze for TypeFutureTable



impl Freeze for TypeFutureTableIndex



impl Freeze for TypeId



impl Freeze for TypeIndex



impl Freeze for TypeKind



impl Freeze for TypeList



impl Freeze for TypeListIndex



impl Freeze for TypeMap



impl Freeze for TypeMapIndex



impl Freeze for TypeModule



impl Freeze for TypeModuleIndex



impl Freeze for TypeOption



impl Freeze for TypeOptionIndex



impl Freeze for TypeRecord



impl Freeze for TypeRecordIndex



impl Freeze for TypeResourceTable



impl Freeze for TypeResourceTableIndex



impl Freeze for TypeResult



impl Freeze for TypeResultIndex



impl Freeze for TypeStream



impl Freeze for TypeStreamIndex



impl Freeze for TypeStreamTable



impl Freeze for TypeStreamTableIndex



impl Freeze for TypeTuple



impl Freeze for TypeTupleIndex



impl Freeze for TypeVariant



impl Freeze for TypeVariantIndex



impl Freeze for UnsafeIntrinsic



impl Freeze for UnwindActionArg



impl Freeze for UnwindTerminateReason



impl Freeze for Utf8Error



impl Freeze for VMGcKind



impl Freeze for VMSharedTypeIndex



impl Freeze for VariableOperatorCost



impl Freeze for VariantId



impl Freeze for VariantInfo



impl Freeze for Waker



impl Freeze for WasmArrayType



impl Freeze for WasmChecksum



impl Freeze for WasmCompositeInnerType



impl Freeze for WasmCompositeType



impl Freeze for WasmContType



impl Freeze for WasmError



impl Freeze for WasmExnType



impl Freeze for WasmFieldType



impl Freeze for WasmFileInfo



impl Freeze for WasmFuncType



impl Freeze for WasmHeapBottomType



impl Freeze for WasmHeapTopType



impl Freeze for WasmHeapType



impl Freeze for WasmRecGroup



impl Freeze for WasmRefType



impl Freeze for WasmStorageType



impl Freeze for WasmStructType



impl Freeze for WasmSubType



impl Freeze for WasmValType



impl Freeze for __m128



impl Freeze for __m256



impl Freeze for __m512



impl Freeze for __m128bh



impl Freeze for __m128d



impl Freeze for __m128h



impl Freeze for __m128i



impl Freeze for __m256bh



impl Freeze for __m256d



impl Freeze for __m256h



impl Freeze for __m256i



impl Freeze for __m512bh



impl Freeze for __m512d



impl Freeze for __m512h



impl Freeze for __m512i



impl Freeze for __tile1024i



impl Freeze for bf16



impl Freeze for c_void



impl<'a, 'b, const N: usize> Freeze for CharArrayRefSearcher<'a, 'b, N>
where <MultiCharEqPattern<&'b [char; N]> as Pattern>::Searcher<'a>: Freeze,



impl<'a, 'b> Freeze for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Freeze for DebugList<'a, 'b>



impl<'a, 'b> Freeze for DebugMap<'a, 'b>



impl<'a, 'b> Freeze for DebugSet<'a, 'b>



impl<'a, 'b> Freeze for DebugStruct<'a, 'b>



impl<'a, 'b> Freeze for DebugTuple<'a, 'b>



impl<'a, 'b> Freeze for StrSearcher<'a, 'b>



impl<'a, 'data> Freeze for ModuleEnvironment<'a, 'data>



impl<'a, 'data> Freeze for Translator<'a, 'data>



impl<'a, A> Freeze for wasmtime_environ::__core::option::Iter<'a, A>
where Item<&'a A>: Freeze,



impl<'a, A> Freeze for wasmtime_environ::__core::option::IterMut<'a, A>
where Item<&'a mut A>: Freeze,



impl<'a, B> Freeze for TryCow<'a, B>
where &'a B: Freeze, <B as TryToOwned>::Owned: Freeze, B: ?Sized,



impl<'a, F> Freeze for CharPredicateSearcher<'a, F>
where <MultiCharEqPattern<F> as Pattern>::Searcher<'a>: Freeze,



impl<'a, F> Freeze for WasmparserTypeConverter<'a, F>
where F: Freeze,



impl<'a, I, A> Freeze for Splice<'a, I, A>
where Drain<'a, <I as Iterator>::Item, A>: Freeze, I: Freeze,



impl<'a, I> Freeze for ByRefSized<'a, I>



impl<'a, K, A> Freeze for wasmtime_environ::collections::oom_abort::hash_set::Drain<'a, K, A>
where Drain<'a, K, A>: Freeze,



impl<'a, K, F, A> Freeze for wasmtime_environ::collections::oom_abort::hash_set::ExtractIf<'a, K, F, A>
where ExtractIf<'a, K, F, A>: Freeze,



impl<'a, K, V, A> Freeze for wasmtime_environ::collections::oom_abort::hash_map::Drain<'a, K, V, A>
where Drain<'a, K, V, A>: Freeze,



impl<'a, K, V, A> Freeze for wasmtime_environ::collections::oom_abort::hash_map::Entry<'a, K, V, A>
where OccupiedEntry<'a, K, V, A>: Freeze, VacantEntry<'a, K, V, A>: Freeze,



impl<'a, K, V, A> Freeze for wasmtime_environ::collections::oom_abort::hash_map::OccupiedEntry<'a, K, V, A>
where RustcOccupiedEntry<'a, K, V, A>: Freeze,



impl<'a, K, V, A> Freeze for OccupiedError<'a, K, V, A>
where OccupiedEntry<'a, K, V, A>: Freeze, K: Freeze, V: Freeze,



impl<'a, K, V, A> Freeze for wasmtime_environ::collections::oom_abort::hash_map::VacantEntry<'a, K, V, A>
where RustcVacantEntry<'a, K, V, A>: Freeze,



impl<'a, K, V, F, A> Freeze for wasmtime_environ::collections::oom_abort::hash_map::ExtractIf<'a, K, V, F, A>
where ExtractIf<'a, K, V, F, A>: Freeze,



impl<'a, K, V> Freeze for BTreeMapIter<'a, K, V>
where MapIter<'a, K, Id>: Freeze, &'a Slab<V>: Freeze,



impl<'a, K, V> Freeze for BTreeMapIterMut<'a, K, V>
where MapIter<'a, K, Id>: Freeze, &'a mut Slab<V>: Freeze,



impl<'a, K, V> Freeze for BTreeMapKeys<'a, K, V>
where BTreeMapIter<'a, K, V>: Freeze,



impl<'a, K, V> Freeze for BTreeMapRange<'a, K, V>
where MapRange<'a, K, Id, ()>: Freeze, &'a Slab<V>: Freeze,



impl<'a, K, V> Freeze for BTreeMapRangeMut<'a, K, V>
where MapRange<'a, K, Id, ()>: Freeze, &'a mut Slab<V>: Freeze,



impl<'a, K, V> Freeze for BTreeMapValues<'a, K, V>
where BTreeMapIter<'a, K, V>: Freeze,



impl<'a, K, V> Freeze for BTreeMapValuesMut<'a, K, V>
where BTreeMapIterMut<'a, K, V>: Freeze,



impl<'a, K, V> Freeze for wasmtime_environ::collections::btree_map::Entry<'a, K, V>
where OccupiedEntry<'a, K, V>: Freeze, VacantEntry<'a, K, V>: Freeze,



impl<'a, K, V> Freeze for wasmtime_environ::Iter<'a, K, V>
where Enumerate<Iter<'a, V>>: Freeze, PhantomData<K>: Freeze,



impl<'a, K, V> Freeze for wasmtime_environ::collections::oom_abort::hash_map::Iter<'a, K, V>
where Iter<'a, K, V>: Freeze,



impl<'a, K, V> Freeze for wasmtime_environ::IterMut<'a, K, V>



impl<'a, K, V> Freeze for wasmtime_environ::collections::oom_abort::hash_map::IterMut<'a, K, V>
where IterMut<'a, K, V>: Freeze,



impl<'a, K, V> Freeze for wasmtime_environ::collections::oom_abort::hash_map::Keys<'a, K, V>
where Iter<'a, K, V>: Freeze,



impl<'a, K, V> Freeze for wasmtime_environ::collections::btree_map::OccupiedEntry<'a, K, V>
where MapCursorMut<'a, K, Id, ()>: Freeze, &'a mut Slab<V>: Freeze,



impl<'a, K, V> Freeze for wasmtime_environ::collections::btree_map::VacantEntry<'a, K, V>
where K: Freeze, MapCursorMut<'a, K, Id, ()>: Freeze, &'a mut Slab<V>: Freeze,



impl<'a, K, V> Freeze for Values<'a, K, V>
where Iter<'a, K, V>: Freeze,



impl<'a, K, V> Freeze for ValuesMut<'a, K, V>
where IterMut<'a, K, V>: Freeze,



impl<'a, K> Freeze for wasmtime_environ::collections::oom_abort::hash_set::Iter<'a, K>
where Iter<'a, K>: Freeze,



impl<'a, K> Freeze for SetIter<'a, K>
where PhantomData<K>: Freeze,



impl<'a, P> Freeze for MatchIndices<'a, P>
where MatchIndicesInternal<'a, P>: Freeze,



impl<'a, P> Freeze for Matches<'a, P>
where MatchesInternal<'a, P>: Freeze,



impl<'a, P> Freeze for RMatchIndices<'a, P>
where MatchIndicesInternal<'a, P>: Freeze,



impl<'a, P> Freeze for RMatches<'a, P>
where MatchesInternal<'a, P>: Freeze,



impl<'a, P> Freeze for wasmtime_environ::__core::str::RSplit<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, P> Freeze for wasmtime_environ::__core::str::RSplitN<'a, P>
where SplitNInternal<'a, P>: Freeze,



impl<'a, P> Freeze for RSplitTerminator<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, P> Freeze for wasmtime_environ::__core::str::Split<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, P> Freeze for wasmtime_environ::__core::str::SplitInclusive<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, P> Freeze for wasmtime_environ::__core::str::SplitN<'a, P>
where SplitNInternal<'a, P>: Freeze,



impl<'a, P> Freeze for SplitTerminator<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, T, A> Freeze for wasmtime_environ::prelude::vec::Drain<'a, T, A>
where Iter<'a, T>: Freeze, NonNull<Vec<T, A>>: Freeze,



impl<'a, T, A> Freeze for PeekMut<'a, T, A>
where &'a mut Vec<T, A>: Freeze,



impl<'a, T, F, A> Freeze for wasmtime_environ::prelude::vec::ExtractIf<'a, T, F, A>
where &'a mut Vec<T, A>: Freeze, F: Freeze,



impl<'a, T, P> Freeze for ChunkBy<'a, T, P>
where &'a [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for ChunkByMut<'a, T, P>
where &'a mut [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for wasmtime_environ::__core::slice::RSplit<'a, T, P>
where Split<'a, T, P>: Freeze,



impl<'a, T, P> Freeze for RSplitMut<'a, T, P>
where SplitMut<'a, T, P>: Freeze,



impl<'a, T, P> Freeze for wasmtime_environ::__core::slice::RSplitN<'a, T, P>
where GenericSplitN<RSplit<'a, T, P>>: Freeze,



impl<'a, T, P> Freeze for RSplitNMut<'a, T, P>
where GenericSplitN<RSplitMut<'a, T, P>>: Freeze,



impl<'a, T, P> Freeze for wasmtime_environ::__core::slice::Split<'a, T, P>
where &'a [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for wasmtime_environ::__core::slice::SplitInclusive<'a, T, P>
where &'a [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for SplitInclusiveMut<'a, T, P>
where &'a mut [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for SplitMut<'a, T, P>
where &'a mut [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for wasmtime_environ::__core::slice::SplitN<'a, T, P>
where GenericSplitN<Split<'a, T, P>>: Freeze,



impl<'a, T, P> Freeze for SplitNMut<'a, T, P>
where GenericSplitN<SplitMut<'a, T, P>>: Freeze,



impl<'a, T, S, A> Freeze for Difference<'a, T, S, A>
where Iter<'a, T>: Freeze, &'a HashSet<T, S, A>: Freeze,



impl<'a, T, S, A> Freeze for wasmtime_environ::collections::oom_abort::hash_set::Entry<'a, T, S, A>
where OccupiedEntry<'a, T, S, A>: Freeze, VacantEntry<'a, T, S, A>: Freeze,



impl<'a, T, S, A> Freeze for Intersection<'a, T, S, A>
where Iter<'a, T>: Freeze, &'a HashSet<T, S, A>: Freeze,



impl<'a, T, S, A> Freeze for wasmtime_environ::collections::oom_abort::hash_set::OccupiedEntry<'a, T, S, A>
where OccupiedEntry<'a, T, S, A>: Freeze,



impl<'a, T, S, A> Freeze for SymmetricDifference<'a, T, S, A>
where Chain<Difference<'a, T, S, A>, Difference<'a, T, S, A>>: Freeze,



impl<'a, T, S, A> Freeze for Union<'a, T, S, A>
where Chain<Iter<'a, T>, Difference<'a, T, S, A>>: Freeze,



impl<'a, T, S, A> Freeze for wasmtime_environ::collections::oom_abort::hash_set::VacantEntry<'a, T, S, A>
where VacantEntry<'a, T, S, A>: Freeze,



impl<'a, T, const N: usize> Freeze for ArrayWindows<'a, T, N>
where &'a [T]: Freeze,



impl<'a, T> Freeze for BorrowedCursor<'a, T>



impl<'a, T> Freeze for Chunks<'a, T>
where &'a [T]: Freeze,



impl<'a, T> Freeze for ChunksExact<'a, T>
where &'a [T]: Freeze,



impl<'a, T> Freeze for ChunksExactMut<'a, T>



impl<'a, T> Freeze for ChunksMut<'a, T>



impl<'a, T> Freeze for wasmtime_environ::__core::slice::Iter<'a, T>



impl<'a, T> Freeze for wasmtime_environ::__core::result::Iter<'a, T>



impl<'a, T> Freeze for wasmtime_environ::__core::slice::IterMut<'a, T>



impl<'a, T> Freeze for wasmtime_environ::__core::result::IterMut<'a, T>



impl<'a, T> Freeze for RChunks<'a, T>
where &'a [T]: Freeze,



impl<'a, T> Freeze for RChunksExact<'a, T>
where &'a [T]: Freeze,



impl<'a, T> Freeze for RChunksExactMut<'a, T>
where *mut [T]: Freeze, &'a mut [T]: Freeze,



impl<'a, T> Freeze for RChunksMut<'a, T>



impl<'a, T> Freeze for Windows<'a, T>
where &'a [T]: Freeze,



impl<'a, const N: usize> Freeze for CharArraySearcher<'a, N>
where <MultiCharEqPattern<[char; N]> as Pattern>::Searcher<'a>: Freeze,



impl<'a> !Freeze for Request<'a>



impl<'a> Freeze for AbstractInstantiations<'a>



impl<'a> Freeze for Arguments<'a>



impl<'a> Freeze for wasmtime_environ::__core::ffi::c_str::Bytes<'a>



impl<'a> Freeze for wasmtime_environ::__core::str::Bytes<'a>



impl<'a> Freeze for wasmtime_environ::error::Chain<'a>



impl<'a> Freeze for CharIndices<'a>



impl<'a> Freeze for CharSearcher<'a>



impl<'a> Freeze for Chars<'a>



impl<'a> Freeze for Context<'a>



impl<'a> Freeze for ContextBuilder<'a>



impl<'a> Freeze for DebugInfoData<'a>



impl<'a> Freeze for EncodeUtf16<'a>



impl<'a> Freeze for EscapeAscii<'a>



impl<'a> Freeze for wasmtime_environ::__core::str::EscapeDebug<'a>



impl<'a> Freeze for wasmtime_environ::__core::str::EscapeDefault<'a>



impl<'a> Freeze for wasmtime_environ::__core::str::EscapeUnicode<'a>



impl<'a> Freeze for FlagValue<'a>



impl<'a> Freeze for FlatTypes<'a>



impl<'a> Freeze for Formatter<'a>



impl<'a> Freeze for FrameStateSlot<'a>



impl<'a> Freeze for FrameTable<'a>



impl<'a> Freeze for FrameTableBreakpointData<'a>



impl<'a> Freeze for FunctionBodyData<'a>



impl<'a> Freeze for IoSlice<'a>



impl<'a> Freeze for IoSliceMut<'a>



impl<'a> Freeze for Lines<'a>



impl<'a> Freeze for LinesAny<'a>



impl<'a> Freeze for Location<'a>



impl<'a> Freeze for MemoryInit<'a>



impl<'a> Freeze for MemoryInitializer<'a>



impl<'a> Freeze for MemoryTunables<'a>



impl<'a> Freeze for wasmtime_environ::fact::Module<'a>



impl<'a> Freeze for NameSection<'a>



impl<'a> Freeze for ObjectBuilder<'a>



impl<'a> Freeze for PanicInfo<'a>



impl<'a> Freeze for PanicMessage<'a>



impl<'a> Freeze for PhantomContravariantLifetime<'a>



impl<'a> Freeze for PhantomCovariantLifetime<'a>



impl<'a> Freeze for PhantomInvariantLifetime<'a>



impl<'a> Freeze for Source<'a>



impl<'a> Freeze for SplitAsciiWhitespace<'a>



impl<'a> Freeze for SplitWhitespace<'a>



impl<'a> Freeze for StackMap<'a>



impl<'a> Freeze for Utf8Chunk<'a>



impl<'a> Freeze for Utf8Chunks<'a>



impl<'a> Freeze for Utf8Pattern<'a>



impl<'a> Freeze for VaList<'a>



impl<'b, T> Freeze for Ref<'b, T>
where NonNull<T>: Freeze, T: ?Sized,



impl<'b, T> Freeze for RefMut<'b, T>



impl<'data, T> Freeze for BorrowedBuf<'data, T>
where &'data mut [MaybeUninit<T>]: Freeze,



impl<'data> Freeze for ModuleTranslation<'data>



impl<A, B> Freeze for wasmtime_environ::__core::iter::Chain<A, B>
where Option<A>: Freeze, Option<B>: Freeze,



impl<A, B> Freeze for Zip<A, B>
where A: Freeze, B: Freeze,



impl<A> Freeze for wasmtime_environ::__core::option::IntoIter<A>
where Item<A>: Freeze,



impl<A> Freeze for OptionFlatten<A>
where Option<A>: Freeze,



impl<A> Freeze for RangeFromIter<A>
where A: Freeze,



impl<A> Freeze for RangeInclusiveIter<A>



impl<A> Freeze for RangeIter<A>
where Range<A>: Freeze,



impl<A> Freeze for wasmtime_environ::__core::iter::Repeat<A>
where A: Freeze,



impl<A> Freeze for RepeatN<A>
where Option<RepeatNInner<A>>: Freeze,



impl<B, C> Freeze for ControlFlow<B, C>
where C: Freeze, B: Freeze,



impl<Dyn> Freeze for DynMetadata<Dyn>
where PhantomData<Dyn>: Freeze, Dyn: ?Sized,



impl<E> Freeze for IterEntityRange<E>
where PhantomData<E>: Freeze,



impl<F> Freeze for wasmtime_environ::__core::iter::FromFn<F>
where F: Freeze,



impl<F> Freeze for wasmtime_environ::__core::fmt::FromFn<F>
where F: Freeze,



impl<F> Freeze for OnceWith<F>
where Option<F>: Freeze,



impl<F> Freeze for PollFn<F>
where F: Freeze,



impl<F> Freeze for RepeatWith<F>
where F: Freeze,



impl<G, F> Freeze for FilterNodes<G, F>
where G: Freeze, F: Freeze,



impl<G> Freeze for FromCoroutine<G>
where G: Freeze,



impl<H> Freeze for BuildHasherDefault<H>
where PhantomData<fn() -> H>: Freeze,



impl<I, F, const N: usize> Freeze for MapWindows<I, F, N>
where F: Freeze, MapWindowsInner<I, N>: Freeze,



impl<I, F> Freeze for FilterMap<I, F>
where I: Freeze, F: Freeze,



impl<I, F> Freeze for Inspect<I, F>
where I: Freeze, F: Freeze,



impl<I, F> Freeze for Map<I, F>
where I: Freeze, F: Freeze,



impl<I, G> Freeze for IntersperseWith<I, G>
where G: Freeze, Option<<I as Iterator>::Item>: Freeze, I: Freeze,



impl<I, P> Freeze for Filter<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for MapWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for SkipWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for TakeWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, St, F> Freeze for Scan<I, St, F>
where I: Freeze, F: Freeze, St: Freeze,



impl<I, U, F> Freeze for FlatMap<I, U, F>
where FlattenCompat<Map<I, F>, <U as IntoIterator>::IntoIter>: Freeze,



impl<I, const N: usize> Freeze for ArrayChunks<I, N>
where I: Freeze, Option<IntoIter<<I as Iterator>::Item, N>>: Freeze,



impl<I> Freeze for ArrayOffsets<I>
where PhantomData<I>: Freeze,



impl<I> Freeze for Cloned<I>
where I: Freeze,



impl<I> Freeze for Copied<I>
where I: Freeze,



impl<I> Freeze for Cycle<I>
where I: Freeze,



impl<I> Freeze for DecodeUtf16<I>
where I: Freeze,



impl<I> Freeze for Enumerate<I>
where I: Freeze,



impl<I> Freeze for Flatten<I>
where FlattenCompat<I, <<I as Iterator>::Item as IntoIterator>::IntoIter>: Freeze,



impl<I> Freeze for FromIter<I>
where I: Freeze,



impl<I> Freeze for Fuse<I>
where Option<I>: Freeze,



impl<I> Freeze for Intersperse<I>
where <I as Iterator>::Item: Sized + Freeze, Option<<I as Iterator>::Item>: Freeze, I: Freeze,



impl<I> Freeze for Peekable<I>
where I: Freeze, Option<Option<<I as Iterator>::Item>>: Freeze,



impl<I> Freeze for Skip<I>
where I: Freeze,



impl<I> Freeze for StepBy<I>
where I: Freeze,



impl<I> Freeze for wasmtime_environ::__core::iter::Take<I>
where I: Freeze,



impl<Idx> Freeze for Clamp<Idx>
where Idx: Freeze,



impl<Idx> Freeze for wasmtime_environ::__core::ops::Range<Idx>
where Idx: Freeze,



impl<Idx> Freeze for wasmtime_environ::__core::range::Range<Idx>
where Idx: Freeze,



impl<Idx> Freeze for wasmtime_environ::__core::ops::RangeFrom<Idx>
where Idx: Freeze,



impl<Idx> Freeze for wasmtime_environ::__core::range::RangeFrom<Idx>
where Idx: Freeze,



impl<Idx> Freeze for wasmtime_environ::__core::ops::RangeInclusive<Idx>
where Idx: Freeze,



impl<Idx> Freeze for wasmtime_environ::__core::range::RangeInclusive<Idx>
where Idx: Freeze,



impl<Idx> Freeze for RangeTo<Idx>
where Idx: Freeze,



impl<Idx> Freeze for wasmtime_environ::__core::ops::RangeToInclusive<Idx>
where Idx: Freeze,



impl<Idx> Freeze for wasmtime_environ::__core::range::RangeToInclusive<Idx>
where Idx: Freeze,



impl<K, A> Freeze for wasmtime_environ::collections::oom_abort::hash_set::IntoIter<K, A>
where IntoIter<K, A>: Freeze,



impl<K, V, A> Freeze for wasmtime_environ::collections::oom_abort::hash_map::IntoIter<K, V, A>
where IntoIter<K, V, A>: Freeze,



impl<K, V, A> Freeze for IntoKeys<K, V, A>
where IntoIter<K, V, A>: Freeze,



impl<K, V, A> Freeze for IntoValues<K, V, A>
where IntoIter<K, V, A>: Freeze,



impl<K, V, S, A> Freeze for HashMap<K, V, S, A>
where HashMap<K, V, S, A>: Freeze,



impl<K, V, S> Freeze for TryHashMap<K, V, S>
where HashMap<K, V, S>: Freeze,



impl<K, V, S> Freeze for TryIndexMap<K, V, S>
where IndexMap<K, V, S>: Freeze,



impl<K, V> Freeze for BTreeMapIntoIter<K, V>
where MapIntoIter<K, Id>: Freeze, Slab<V>: Freeze,



impl<K, V> Freeze for BoxedSlice<K, V>



impl<K, V> Freeze for IndexMap<K, V>
where IndexMap<K, V, RandomState>: Freeze,



impl<K, V> Freeze for Intern<K, V>
where HashMap<V, K>: Freeze, PrimaryMap<K, V>: Freeze,



impl<K, V> Freeze for wasmtime_environ::IntoIter<K, V>



impl<K, V> Freeze for NameMap<K, V>
where TryIndexMap<K, V>: Freeze, TryIndexMap<K, (K, TryVersion)>: Freeze,



impl<K, V> Freeze for PrimaryMap<K, V>
where Vec<V>: Freeze, PhantomData<K>: Freeze,



impl<K, V> Freeze for SecondaryMap<K, V>
where Vec<V>: Freeze, V: Freeze, PhantomData<K>: Freeze,



impl<K, V> Freeze for SparseMap<K, V>
where SecondaryMap<K, u32>: Freeze, Vec<V>: Freeze,



impl<K, V> Freeze for TryBTreeMap<K, V>
where Slab<V>: Freeze, MapForest<K, Id>: Freeze, Map<K, Id>: Freeze,



impl<K, V> Freeze for TryPrimaryMap<K, V>
where PrimaryMap<K, V>: Freeze,



impl<K, V> Freeze for TrySecondaryMap<K, V>
where SecondaryMap<K, V>: Freeze,



impl<K> Freeze for EntitySet<K>
where PhantomData<K>: Freeze,



impl<K> Freeze for wasmtime_environ::Keys<K>
where PhantomData<K>: Freeze,



impl<K> Freeze for TryEntitySet<K>
where EntitySet<K>: Freeze,



impl<Node> Freeze for Dfs<Node>
where Vec<DfsEvent<Node>>: Freeze,



impl<Node> Freeze for DfsEvent<Node>
where Node: Freeze,



impl<Node> Freeze for EntityGraph<Node>
where SecondaryMap<Node, Range<u32>>: Freeze, Vec<Node>: Freeze,



impl<Node> Freeze for StronglyConnectedComponents<Node>
where Vec<Node>: Freeze,



impl<P> Freeze for MaybeDangling<P>
where P: Freeze + ?Sized,



impl<P> Freeze for VMComponentContext<P>
where P: Freeze,



impl<P> Freeze for VMComponentOffsets<P>
where P: Freeze,



impl<P> Freeze for VMContext<P>
where P: Freeze,



impl<P> Freeze for VMDeferredThread<P>
where P: Freeze,



impl<P> Freeze for VMFuncRef<P>
where P: Freeze,



impl<P> Freeze for VMFunctionImport<P>
where P: Freeze,



impl<P> Freeze for VMGlobalDefinition<P>
where P: Freeze,



impl<P> Freeze for VMGlobalImport<P>
where P: Freeze,



impl<P> Freeze for VMLazyThread<P>
where P: Freeze,



impl<P> Freeze for VMMemoryDefinition<P>
where P: Freeze,



impl<P> Freeze for VMMemoryImport<P>
where P: Freeze,



impl<P> Freeze for VMOffsets<P>
where P: Freeze,



impl<P> Freeze for VMOffsetsFields<P>
where P: Freeze,



impl<P> Freeze for VMStoreContext<P>
where P: Freeze,



impl<P> Freeze for VMTableDefinition<P>
where P: Freeze,



impl<P> Freeze for VMTableImport<P>
where P: Freeze,



impl<P> Freeze for VMTagDefinition<P>
where P: Freeze,



impl<P> Freeze for VMTagImport<P>
where P: Freeze,



impl<Ptr> Freeze for Pin<Ptr>
where Ptr: Freeze,



impl<T, A> Freeze for Box<T, A>
where Unique<T>: Freeze, A: Freeze, T: ?Sized,



impl<T, A> Freeze for wasmtime_environ::prelude::vec::IntoIter<T, A>



impl<T, A> Freeze for Vec<T, A>
where RawVec<T, A>: Freeze,



impl<T, E> Freeze for Result<T, E>
where T: Freeze, E: Freeze,



impl<T, F = fn() -> T> !Freeze for LazyCell<T, F>



impl<T, F> Freeze for DropGuard<T, F>



impl<T, F> Freeze for Successors<T, F>
where Option<T>: Freeze, F: Freeze,



impl<T, F> Freeze for Undo<T, F>



impl<T, S, A> Freeze for HashSet<T, S, A>
where HashSet<T, S, A>: Freeze,



impl<T, S> Freeze for TryHashSet<T, S>
where HashSet<T, S>: Freeze,



impl<T, U> Freeze for wasmtime_environ::__core::io::Chain<T, U>
where T: Freeze, U: Freeze,



impl<T, const N: usize> Freeze for wasmtime_environ::__core::array::IntoIter<T, N>
where ManuallyDrop<PolymorphicIter<[MaybeUninit<T>; N]>>: Freeze,



impl<T, const N: usize> Freeze for Mask<T, N>
where Simd<T, N>: Freeze,



impl<T, const N: usize> Freeze for Simd<T, N>
where [T; N]: Freeze,



impl<T, const VARIANT: u32, const FIELD: u32> Freeze for FieldRepresentingType<T, VARIANT, FIELD>
where PhantomData<fn(T) -> T>: Freeze, T: ?Sized,



impl<T> !Freeze for Atomic<T>



impl<T> !Freeze for Cell<T>



impl<T> !Freeze for CovariantUnsafeCell<T>



impl<T> !Freeze for OnceCell<T>



impl<T> !Freeze for RefCell<T>



impl<T> !Freeze for ScopeVec<T>



impl<T> !Freeze for SyncUnsafeCell<T>



impl<T> !Freeze for UnsafePinned<T>



impl<T> Freeze for AssertUnwindSafe<T>
where T: Freeze,



impl<T> Freeze for Bound<T>
where T: Freeze,



impl<T> Freeze for Complex<T>
where T: Freeze,



impl<T> Freeze for wasmtime_environ::component::CoreExport<T>
where ExportItem<T>: Freeze,



impl<T> Freeze for wasmtime_environ::component::dfg::CoreExport<T>
where ExportItem<T>: Freeze,



impl<T> Freeze for Cursor<T>
where T: Freeze,



impl<T> Freeze for Discriminant<T>



impl<T> Freeze for wasmtime_environ::__core::iter::Empty<T>
where PhantomData<fn() -> T>: Freeze,



impl<T> Freeze for EntityList<T>
where PhantomData<T>: Freeze,



impl<T> Freeze for ExportItem<T>
where T: Freeze,



impl<T> Freeze for IndexSet<T>
where IndexMap<T, ()>: Freeze,



impl<T> Freeze for wasmtime_environ::__core::result::IntoIter<T>
where Option<T>: Freeze,



impl<T> Freeze for KnownEntity<T>
where T: Freeze,



impl<T> Freeze for ListPool<T>
where Vec<T>: Freeze,



impl<T> Freeze for ManuallyDrop<T>
where MaybeDangling<T>: Freeze, T: ?Sized,



impl<T> Freeze for MaybeUninit<T>
where ManuallyDrop<T>: Freeze,



impl<T> Freeze for NonNull<T>
where *const T is !null: Freeze, T: ?Sized,



impl<T> Freeze for NumBuffer<T>



impl<T> Freeze for Once<T>
where IntoIter<T>: Freeze,



impl<T> Freeze for Option<T>
where T: Freeze,



impl<T> Freeze for PackedOption<T>
where T: Freeze,



impl<T> Freeze for Pending<T>
where PhantomData<fn() -> T>: Freeze,



impl<T> Freeze for PhantomContravariant<T>
where PhantomData<fn(T)>: Freeze, T: ?Sized,



impl<T> Freeze for PhantomCovariant<T>
where PhantomData<fn() -> T>: Freeze, T: ?Sized,



impl<T> Freeze for PhantomInvariant<T>
where PhantomData<fn(T) -> T>: Freeze, T: ?Sized,



impl<T> Freeze for Poll<T>
where T: Freeze,



impl<T> Freeze for Ready<T>
where Option<T>: Freeze,



impl<T> Freeze for Rev<T>
where T: Freeze,



impl<T> Freeze for Reverse<T>
where T: Freeze,



impl<T> Freeze for Saturating<T>
where T: Freeze,



impl<T> Freeze for SyncView<T>
where T: Freeze + ?Sized,



impl<T> Freeze for wasmtime_environ::__core::io::Take<T>
where T: Freeze,



impl<T> Freeze for TraitImpl<T>
where DynMetadata<T>: Freeze, T: ?Sized,



impl<T> Freeze for TryVec<T>
where Vec<T>: Freeze,



impl<T> Freeze for Wrapping<T>
where T: Freeze,



impl<T> Freeze for Yeet<T>
where T: Freeze,



impl<Y, R> Freeze for CoroutineState<Y, R>
where Y: Freeze, R: Freeze,