Send

Trait Send 

1.6.0 · Source
pub unsafe auto trait Send { }
Types that can be transferred across thread boundaries.

This trait is automatically implemented when the compiler determines it’s appropriate.

An example of a non-Send type is the reference-counting pointer rc::Rc. If two threads attempt to clone Rcs that point to the same reference-counted value, they might try to update the reference count at the same time, which is undefined behavior because Rc doesn’t use atomic operations. Its cousin sync::Arc does use atomic operations (incurring some overhead) and thus is Send.

See the Nomicon and the Sync trait for more details.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.26.0 · Source

impl !Send for Args

1.26.0 · Source

impl !Send for ArgsOs

1.0.0 · Source

impl !Send for Arguments<'_>

Source

impl !Send for LocalWaker

1.98.0 · Source

impl !Send for VarsOs

Source

impl Send for wasmtime_environ::__core::ffi::c_str::Bytes<'_>

1.6.0 · Source

impl Send for alloc::string::Drain<'_>

1.10.0 · Source

impl Send for Location<'_>



impl Send for OutOfMemory

1.0.0 · Source

impl Send for TypeId

1.36.0 · Source

impl Send for Waker



impl<'a, T> Send for Drain<'a, T>
where T: Send + Array,

1.44.0 · Source

impl<'a> Send for IoSlice<'a>

1.44.0 · Source

impl<'a> Send for IoSliceMut<'a>



impl<A> Send for SmallVec<A>
where A: Array, <A as Array>::Item: Send,

Source

impl<Dyn> Send for DynMetadata<Dyn>
where Dyn: ?Sized,



impl<K, V, S, A> Send for OccupiedEntry<'_, K, V, S, A>
where K: Send, V: Send, S: Send, A: Send + Allocator,



impl<K, V, S, A> Send for OccupiedEntry<'_, K, V, S, A>
where K: Send, V: Send, S: Send, A: Send + Allocator,



impl<K, V> Send for IterMut<'_, K, V>
where K: Send, V: Send,



impl<K, V> Send for IterMut<'_, K, V>
where K: Send, V: Send,

1.0.0 · Source

impl<T, A> !Send for Rc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> !Send for UniqueRc<T, A>
where A: Allocator, T: ?Sized,

1.4.0 · Source

impl<T, A> !Send for alloc::rc::Weak<T, A>
where A: Allocator, T: ?Sized,

1.0.0 · Source

impl<T, A> Send for Arc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send + Sync,

Source

impl<T, A> Send for alloc::collections::linked_list::Cursor<'_, T, A>
where T: Sync, A: Allocator + Sync,

Source

impl<T, A> Send for CursorMut<'_, T, A>
where T: Send, A: Allocator + Send,

1.6.0 · Source

impl<T, A> Send for alloc::collections::vec_deque::drain::Drain<'_, T, A>
where T: Send, A: Allocator + Send,

1.6.0 · Source

impl<T, A> Send for wasmtime_environ::prelude::vec::Drain<'_, T, A>
where T: Send, A: Send + Allocator,

1.0.0 · Source

impl<T, A> Send for wasmtime_environ::prelude::vec::IntoIter<T, A>
where T: Send, A: Allocator + Send,

1.0.0 · Source

impl<T, A> Send for LinkedList<T, A>
where T: Send, A: Allocator + Send,



impl<T, A> Send for OccupiedEntry<'_, T, A>
where T: Send, A: Send + Allocator,



impl<T, A> Send for OccupiedEntry<'_, T, A>
where T: Send, A: Send + Allocator,

Source

impl<T, A> Send for UniqueArc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send + Sync,

1.4.0 · Source

impl<T, A> Send for alloc::sync::Weak<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send + Sync,



impl<T, N> Send for GenericArray<T, N>
where T: Send, N: ArrayLength<T>,

1.0.0 · Source

impl<T> !Send for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for *mut T
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: ?Sized,

A MutexGuard is not Send to maximize platform portability.

On platforms that use POSIX threads (commonly referred to as pthreads) there is a requirement to release mutex locks on the same thread they were acquired. For this reason, MutexGuard must not implement Send to prevent it being dropped from another thread.

1.0.0 · Source

impl<T> !Send for std::sync::poison::mutex::MutexGuard<'_, T>
where T: ?Sized,

A MutexGuard is not Send to maximize platform portability.

On platforms that use POSIX threads (commonly referred to as pthreads) there is a requirement to release mutex locks on the same thread they were acquired. For this reason, MutexGuard must not implement Send to prevent it being dropped from another thread.

1.25.0 · Source

impl<T> !Send for NonNull<T>
where T: ?Sized,

NonNull pointers are not Send because the data they reference may be aliased.

Source

impl<T> !Send for ReentrantLockGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> Send for &T
where T: Sync + ?Sized,

1.0.0 · Source

impl<T> Send for Atomic<T>
where T: AtomicPrimitive,

1.0.0 · Source

impl<T> Send for Cell<T>
where T: Send + ?Sized,

1.31.0 · Source

impl<T> Send for ChunksExactMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for ChunksMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for wasmtime_environ::__core::slice::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Send for alloc::collections::linked_list::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Send for wasmtime_environ::__core::slice::IterMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for alloc::collections::linked_list::IterMut<'_, T>
where T: Send,

1.29.0 · Source

impl<T> Send for JoinHandle<T>

Source

impl<T> Send for std::sync::nonpoison::mutex::Mutex<T>
where T: Send + ?Sized,

T must be Send for a Mutex to be Send because it is possible to acquire the owned T from the Mutex via into_inner.

1.0.0 · Source

impl<T> Send for std::sync::poison::mutex::Mutex<T>
where T: Send + ?Sized,

T must be Send for a Mutex to be Send because it is possible to acquire the owned T from the Mutex via into_inner.

1.28.0 · Source

impl<T> Send for NonZero<T>

1.70.0 · Source

impl<T> Send for OnceLock<T>
where T: Send,

1.31.0 · Source

impl<T> Send for RChunksExactMut<'_, T>
where T: Send,

1.31.0 · Source

impl<T> Send for RChunksMut<'_, T>
where T: Send,

Source

impl<T> Send for std::sync::mpmc::Receiver<T>
where T: Send,

1.0.0 · Source

impl<T> Send for std::sync::mpsc::Receiver<T>
where T: Send,

Source

impl<T> Send for ReentrantLock<T>
where T: Send + ?Sized,

1.0.0 · Source

impl<T> Send for RefCell<T>
where T: Send + ?Sized,

Source

impl<T> Send for std::sync::nonpoison::rwlock::RwLock<T>
where T: Send + ?Sized,

1.0.0 · Source

impl<T> Send for std::sync::poison::rwlock::RwLock<T>
where T: Send + ?Sized,

Source

impl<T> Send for std::sync::mpmc::Sender<T>
where T: Send,

1.0.0 · Source

impl<T> Send for std::sync::mpsc::Sender<T>
where T: Send,

1.0.0 · Source

impl<T> Send for SyncSender<T>
where T: Send,

Source

impl<T> Send for ThinBox<T>
where T: Send + ?Sized,

ThinBox<T> is Send if T is Send because the data is owned.

Auto implementors



impl !Send for RawWaker



impl Send for wasmtime_environ::Abi



impl Send for wasmtime_environ::__core::mem::type_info::Abi



impl Send for AbstractResourceIndex



impl Send for Adapter



impl Send for AdapterId



impl Send for AdapterModuleId



impl Send for AdapterOptions



impl Send for AddrParseError



impl Send for AddressMapSection



impl Send for wasmtime_environ::__core::mem::Alignment



impl Send for wasmtime_environ::__core::fmt::Alignment



impl Send for AllocError



impl Send for Array



impl Send for AsciiChar



impl Send for Assume



impl Send for Atom



impl Send for AtomicOrdering



impl Send for BasicBlock



impl Send for BorrowError



impl Send for BorrowMutError



impl Send for BuiltinFunctionIndex



impl Send for ByteStr



impl Send for CStr



impl Send for CallbackId



impl Send for CanonicalAbiInfo



impl Send for wasmtime_environ::component::CanonicalOptions



impl Send for wasmtime_environ::component::dfg::CanonicalOptions



impl Send for wasmtime_environ::component::CanonicalOptionsDataModel



impl Send for wasmtime_environ::component::dfg::CanonicalOptionsDataModel



impl Send for CharCase



impl Send for CharTryFromError



impl Send for Collector



impl Send for CompileError



impl Send for CompiledComponentInfo



impl Send for CompiledFunctionBody



impl Send for CompiledFunctionsTable



impl Send for CompiledFunctionsTableBuilder



impl Send for CompiledModuleInfo



impl Send for CompiledTrap



impl Send for Component



impl Send for ComponentArtifacts



impl Send for ComponentBuiltinFunctionIndex



impl Send for ComponentDfg



impl Send for ComponentExtern



impl Send for ComponentExternData



impl Send for ComponentFuncIndex



impl Send for ComponentIndex



impl Send for ComponentInstanceIndex



impl Send for ComponentItem



impl Send for ComponentPC



impl Send for ComponentTranslation



impl Send for ComponentTypeIndex



impl Send for ComponentTypes



impl Send for ComponentTypesBuilder



impl Send for ComponentUpvarIndex



impl Send for ConfigTunables



impl Send for Const



impl Send for ConstExpr



impl Send for ConstOp



impl Send for CopyingTypeLayouts



impl Send for wasmtime_environ::component::CoreDef



impl Send for wasmtime_environ::component::dfg::CoreDef



impl Send for CpuidResult



impl Send for DataIndex



impl Send for DataModel



impl Send for DebugAsHex



impl Send for DecodeUtf16Error



impl Send for DefaultHasher



impl Send for DefinedFuncIndex



impl Send for DefinedGlobalIndex



impl Send for DefinedMemoryIndex



impl Send for DefinedResourceIndex



impl Send for DefinedTableIndex



impl Send for DefinedTagIndex



impl Send for DrcTypeLayouts



impl Send for Duration



impl Send for DynTrait



impl Send for DynTraitPredicate



impl Send for ElemIndex



impl Send for wasmtime_environ::__core::io::Empty



impl Send for EngineInternedRecGroupIndex



impl Send for EngineOrModuleTypeIndex



impl Send for EntityIndex



impl Send for EntityType



impl Send for wasmtime_environ::prelude::Error



impl Send for wasmtime_environ::__core::io::Error



impl Send for wasmtime_environ::__core::fmt::Error



impl Send for ErrorKind



impl Send for wasmtime_environ::__core::char::EscapeDebug



impl Send for wasmtime_environ::__core::ascii::EscapeDefault



impl Send for wasmtime_environ::__core::char::EscapeDefault



impl Send for wasmtime_environ::__core::char::EscapeUnicode



impl Send for Evaporation



impl Send for wasmtime_environ::component::Export



impl Send for wasmtime_environ::component::dfg::Export



impl Send for ExportIndex



impl Send for ExtractCallback



impl Send for ExtractMemory



impl Send for ExtractPostReturn



impl Send for ExtractRealloc



impl Send for ExtractTable



impl Send for FactInlineIntrinsic



impl Send for FieldId



impl Send for FilePos



impl Send for FixedEncoding



impl Send for FlatType



impl Send for FnPtr



impl Send for FormattingOptions



impl Send for FpCategory



impl Send for FrameInstPos



impl Send for FrameStackShape



impl Send for FrameStateSlotBuilder



impl Send for FrameStateSlotOffset



impl Send for FrameTableBuilder



impl Send for FrameTableDescriptorIndex



impl Send for FrameValType



impl Send for FromBytesUntilNulError



impl Send for FromBytesWithNulError



impl Send for FuncIndex



impl Send for FuncKey



impl Send for FuncKeyIndex



impl Send for FuncKeyKind



impl Send for FuncKeyNamespace



impl Send for FuncRefIndex



impl Send for FunctionLoc



impl Send for FunctionMetadata



impl Send for FunctionName



impl Send for FunctionType



impl Send for FutureInfo



impl Send for GcArrayLayout



impl Send for GcLayout



impl Send for GcStructLayout



impl Send for GcStructLayoutField



impl Send for Generic



impl Send for GenericType



impl Send for GetDisjointMutError



impl Send for Global



impl Send for GlobalConstValue



impl Send for GlobalIndex



impl Send for GlobalInitializer



impl Send for HostCall



impl Send for HostPtr



impl Send for Import



impl Send for ImportIndex



impl Send for IndexType



impl Send for Infallible



impl Send for Initializer



impl Send for InlineTraceInfo



impl Send for Inlining



impl Send for Instance



impl Send for InstanceId



impl Send for InstantiateModule



impl Send for InstructionAddressMap



impl Send for IntErrorKind



impl Send for InterfaceType



impl Send for IpAddr



impl Send for Ipv4Addr



impl Send for Ipv6Addr



impl Send for Ipv6MulticastScope



impl Send for KnownFunc



impl Send for KnownGlobal



impl Send for Last



impl Send for Layout



impl Send for LayoutError



impl Send for Lifetime



impl Send for Limits



impl Send for LinearMemoryOptions



impl Send for LocalDataModel



impl Send for Locality



impl Send for LoweredIndex



impl Send for Memory



impl Send for MemoryId



impl Send for MemoryIndex



impl Send for MemoryInitialization



impl Send for MemoryKind



impl Send for MemorySegmentOffset



impl Send for Metadata



impl Send for wasmtime_environ::Module



impl Send for ModuleIndex



impl Send for ModuleInstanceIndex



impl Send for ModuleInternedRecGroupIndex



impl Send for ModuleInternedTypeIndex



impl Send for ModulePC



impl Send for ModuleStartup



impl Send for ModuleTypes



impl Send for ModuleTypesBuilder



impl Send for ModuleUpvarIndex



impl Send for NameMapNoIntern



impl Send for NonMaxU8



impl Send for NonMaxU16



impl Send for NonMaxU32



impl Send for NonMaxU64



impl Send for NonMaxUsize



impl Send for NullTypeLayouts



impl Send for ObjectCrateErrorWrapper



impl Send for ObjectKind



impl Send for OneSidedRangeBound



impl Send for OperatorCost



impl Send for OperatorCostStrategy



impl Send for OptionsId



impl Send for OptionsIndex



impl Send for wasmtime_environ::__core::cmp::Ordering



impl Send for wasmtime_environ::__core::sync::atomic::Ordering



impl Send for OwnedMemoryIndex



impl Send for ParseBoolError



impl Send for ParseCharError



impl Send for ParseFloatError



impl Send for ParseIntError



impl Send for PassiveElemIndex



impl Send for PhantomPinned



impl Send for Pointer



impl Send for PostReturnId



impl Send for RandomState



impl Send for RangeFull



impl Send for RawWakerVTable



impl Send for ReallocId



impl Send for RecGroupRelativeTypeIndex



impl Send for RecordField



impl Send for Reference



impl Send for wasmtime_environ::__core::io::Repeat



impl Send for wasmtime_environ::component::Resource



impl Send for wasmtime_environ::component::dfg::Resource



impl Send for ResourceIndex



impl Send for ResourcesBuilder



impl Send for ReturnToArg



impl Send for RuntimeCallbackIndex



impl Send for RuntimeComponentInstanceIndex



impl Send for RuntimeDataIndex



impl Send for RuntimeImportIndex



impl Send for RuntimeInstanceIndex



impl Send for RuntimeMemoryIndex



impl Send for RuntimePostReturnIndex



impl Send for RuntimeReallocIndex



impl Send for RuntimeTableIndex



impl Send for Scc



impl Send for SearchStep



impl Send for SeekFrom



impl Send for Setting



impl Send for SettingKind



impl Send for SideEffect



impl Send for Sign



impl Send for SimdAlign



impl Send for Sink



impl Send for SipHasher



impl Send for SizeOverflow



impl Send for Slice



impl Send for SocketAddr



impl Send for SocketAddrV4



impl Send for SocketAddrV6



impl Send for StackMapSection



impl Send for StaticComponentIndex



impl Send for StaticModuleIndex



impl Send for Str



impl Send for StreamInfo



impl Send for String



impl Send for StringEncoding



impl Send for StringPool



impl Send for Table



impl Send for TableId



impl Send for TableIndex



impl Send for TableInitialValue



impl Send for TableInitialization



impl Send for TableSegment



impl Send for TableSegmentElements



impl Send for Tag



impl Send for TagIndex



impl Send for ToCasefold



impl Send for ToLowercase



impl Send for ToTitlecase



impl Send for ToUppercase



impl Send for Trait



impl Send for wasmtime_environ::component::Trampoline



impl Send for wasmtime_environ::component::dfg::Trampoline



impl Send for TrampolineIndex



impl Send for Transcode



impl Send for Trap



impl Send for TrapEncodingBuilder



impl Send for TrapInformation



impl Send for TrapSentinel



impl Send for TryFromCharError



impl Send for TryFromFloatSecsError



impl Send for TryFromIntError



impl Send for TryFromSliceError



impl Send for TryString



impl Send for Tunables



impl Send for Type



impl Send for TypeComponent



impl Send for TypeComponentGlobalErrorContextTableIndex



impl Send for TypeComponentIndex



impl Send for TypeComponentInstance



impl Send for TypeComponentInstanceIndex



impl Send for TypeComponentLocalErrorContextTableIndex



impl Send for TypeDef



impl Send for TypeEnum



impl Send for TypeEnumIndex



impl Send for TypeErrorContextTable



impl Send for TypeFixedLengthList



impl Send for TypeFixedLengthListIndex



impl Send for TypeFlags



impl Send for TypeFlagsIndex



impl Send for TypeFunc



impl Send for TypeFuncIndex



impl Send for TypeFuture



impl Send for TypeFutureIndex



impl Send for TypeFutureTable



impl Send for TypeFutureTableIndex



impl Send for TypeIndex



impl Send for TypeKind



impl Send for TypeList



impl Send for TypeListIndex



impl Send for TypeMap



impl Send for TypeMapIndex



impl Send for TypeModule



impl Send for TypeModuleIndex



impl Send for TypeOption



impl Send for TypeOptionIndex



impl Send for TypeRecord



impl Send for TypeRecordIndex



impl Send for TypeResourceTable



impl Send for TypeResourceTableIndex



impl Send for TypeResult



impl Send for TypeResultIndex



impl Send for TypeStream



impl Send for TypeStreamIndex



impl Send for TypeStreamTable



impl Send for TypeStreamTableIndex



impl Send for TypeTuple



impl Send for TypeTupleIndex



impl Send for TypeVariant



impl Send for TypeVariantIndex



impl Send for UnsafeIntrinsic



impl Send for UnwindActionArg



impl Send for UnwindTerminateReason



impl Send for Utf8Error



impl Send for VMGcKind



impl Send for VMSharedTypeIndex



impl Send for VariableOperatorCost



impl Send for VariantId



impl Send for VariantInfo



impl Send for WasmArrayType



impl Send for WasmChecksum



impl Send for WasmCompositeInnerType



impl Send for WasmCompositeType



impl Send for WasmContType



impl Send for WasmError



impl Send for WasmExnType



impl Send for WasmFieldType



impl Send for WasmFileInfo



impl Send for WasmFuncType



impl Send for WasmHeapBottomType



impl Send for WasmHeapTopType



impl Send for WasmHeapType



impl Send for WasmRecGroup



impl Send for WasmRefType



impl Send for WasmStorageType



impl Send for WasmStructType



impl Send for WasmSubType



impl Send for WasmValType



impl Send for __m128



impl Send for __m256



impl Send for __m512



impl Send for __m128bh



impl Send for __m128d



impl Send for __m128h



impl Send for __m128i



impl Send for __m256bh



impl Send for __m256d



impl Send for __m256h



impl Send for __m256i



impl Send for __m512bh



impl Send for __m512d



impl Send for __m512h



impl Send for __m512i



impl Send for __tile1024i



impl Send for bf16



impl Send for c_void



impl<'a, 'b, const N: usize> Send for CharArrayRefSearcher<'a, 'b, N>
where <MultiCharEqPattern<&'b [char; N]> as Pattern>::Searcher<'a>: Send,



impl<'a, 'b> !Send for DebugList<'a, 'b>



impl<'a, 'b> !Send for DebugMap<'a, 'b>



impl<'a, 'b> !Send for DebugSet<'a, 'b>



impl<'a, 'b> !Send for DebugStruct<'a, 'b>



impl<'a, 'b> !Send for DebugTuple<'a, 'b>



impl<'a, 'b> Send for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Send for StrSearcher<'a, 'b>



impl<'a, 'data> !Send for Translator<'a, 'data>



impl<'a, 'data> Send for ModuleEnvironment<'a, 'data>



impl<'a, A> Send for wasmtime_environ::__core::option::Iter<'a, A>
where Item<&'a A>: Send,



impl<'a, A> Send for wasmtime_environ::__core::option::IterMut<'a, A>
where Item<&'a mut A>: Send,



impl<'a, B> Send for TryCow<'a, B>
where &'a B: Send, <B as TryToOwned>::Owned: Send, B: ?Sized,



impl<'a, F> Send for CharPredicateSearcher<'a, F>
where <MultiCharEqPattern<F> as Pattern>::Searcher<'a>: Send,



impl<'a, F> Send for WasmparserTypeConverter<'a, F>
where F: Send,



impl<'a, I, A> Send for Splice<'a, I, A>
where Drain<'a, <I as Iterator>::Item, A>: Send, I: Send,



impl<'a, I> Send for ByRefSized<'a, I>
where &'a mut I: Send,



impl<'a, K, A> Send for wasmtime_environ::collections::oom_abort::hash_set::Drain<'a, K, A>
where Drain<'a, K, A>: Send,



impl<'a, K, F, A> Send for wasmtime_environ::collections::oom_abort::hash_set::ExtractIf<'a, K, F, A>
where ExtractIf<'a, K, F, A>: Send,



impl<'a, K, V, A> Send for wasmtime_environ::collections::oom_abort::hash_map::Drain<'a, K, V, A>
where Drain<'a, K, V, A>: Send,



impl<'a, K, V, A> Send for wasmtime_environ::collections::oom_abort::hash_map::Entry<'a, K, V, A>
where OccupiedEntry<'a, K, V, A>: Send, VacantEntry<'a, K, V, A>: Send,



impl<'a, K, V, A> Send for wasmtime_environ::collections::oom_abort::hash_map::OccupiedEntry<'a, K, V, A>
where RustcOccupiedEntry<'a, K, V, A>: Send,



impl<'a, K, V, A> Send for OccupiedError<'a, K, V, A>
where OccupiedEntry<'a, K, V, A>: Send, K: Send, V: Send,



impl<'a, K, V, A> Send for wasmtime_environ::collections::oom_abort::hash_map::VacantEntry<'a, K, V, A>
where RustcVacantEntry<'a, K, V, A>: Send,



impl<'a, K, V, F, A> Send for wasmtime_environ::collections::oom_abort::hash_map::ExtractIf<'a, K, V, F, A>
where ExtractIf<'a, K, V, F, A>: Send,



impl<'a, K, V> Send for BTreeMapIter<'a, K, V>
where MapIter<'a, K, Id>: Send, &'a Slab<V>: Send,



impl<'a, K, V> Send for BTreeMapIterMut<'a, K, V>
where MapIter<'a, K, Id>: Send, &'a mut Slab<V>: Send,



impl<'a, K, V> Send for BTreeMapKeys<'a, K, V>
where BTreeMapIter<'a, K, V>: Send,



impl<'a, K, V> Send for BTreeMapRange<'a, K, V>
where MapRange<'a, K, Id, ()>: Send, &'a Slab<V>: Send,



impl<'a, K, V> Send for BTreeMapRangeMut<'a, K, V>
where MapRange<'a, K, Id, ()>: Send, &'a mut Slab<V>: Send,



impl<'a, K, V> Send for BTreeMapValues<'a, K, V>
where BTreeMapIter<'a, K, V>: Send,



impl<'a, K, V> Send for BTreeMapValuesMut<'a, K, V>
where BTreeMapIterMut<'a, K, V>: Send,



impl<'a, K, V> Send for wasmtime_environ::collections::btree_map::Entry<'a, K, V>
where OccupiedEntry<'a, K, V>: Send, VacantEntry<'a, K, V>: Send,



impl<'a, K, V> Send for wasmtime_environ::Iter<'a, K, V>
where Enumerate<Iter<'a, V>>: Send, PhantomData<K>: Send,



impl<'a, K, V> Send for wasmtime_environ::collections::oom_abort::hash_map::Iter<'a, K, V>
where Iter<'a, K, V>: Send,



impl<'a, K, V> Send for wasmtime_environ::IterMut<'a, K, V>
where Enumerate<IterMut<'a, V>>: Send, PhantomData<K>: Send,



impl<'a, K, V> Send for wasmtime_environ::collections::oom_abort::hash_map::IterMut<'a, K, V>
where IterMut<'a, K, V>: Send,



impl<'a, K, V> Send for wasmtime_environ::collections::oom_abort::hash_map::Keys<'a, K, V>
where Iter<'a, K, V>: Send,



impl<'a, K, V> Send for wasmtime_environ::collections::btree_map::OccupiedEntry<'a, K, V>
where MapCursorMut<'a, K, Id, ()>: Send, &'a mut Slab<V>: Send,



impl<'a, K, V> Send for wasmtime_environ::collections::btree_map::VacantEntry<'a, K, V>
where K: Send, MapCursorMut<'a, K, Id, ()>: Send, &'a mut Slab<V>: Send,



impl<'a, K, V> Send for Values<'a, K, V>
where Iter<'a, K, V>: Send,



impl<'a, K, V> Send for ValuesMut<'a, K, V>
where IterMut<'a, K, V>: Send,



impl<'a, K> Send for wasmtime_environ::collections::oom_abort::hash_set::Iter<'a, K>
where Iter<'a, K>: Send,



impl<'a, K> Send for SetIter<'a, K>
where PhantomData<K>: Send,



impl<'a, P> Send for MatchIndices<'a, P>
where MatchIndicesInternal<'a, P>: Send,



impl<'a, P> Send for Matches<'a, P>
where MatchesInternal<'a, P>: Send,



impl<'a, P> Send for RMatchIndices<'a, P>
where MatchIndicesInternal<'a, P>: Send,



impl<'a, P> Send for RMatches<'a, P>
where MatchesInternal<'a, P>: Send,



impl<'a, P> Send for wasmtime_environ::__core::str::RSplit<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, P> Send for wasmtime_environ::__core::str::RSplitN<'a, P>
where SplitNInternal<'a, P>: Send,



impl<'a, P> Send for RSplitTerminator<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, P> Send for wasmtime_environ::__core::str::Split<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, P> Send for wasmtime_environ::__core::str::SplitInclusive<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, P> Send for wasmtime_environ::__core::str::SplitN<'a, P>
where SplitNInternal<'a, P>: Send,



impl<'a, P> Send for SplitTerminator<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, T, A> Send for PeekMut<'a, T, A>
where &'a mut Vec<T, A>: Send,



impl<'a, T, F, A> Send for wasmtime_environ::prelude::vec::ExtractIf<'a, T, F, A>
where &'a mut Vec<T, A>: Send, F: Send,



impl<'a, T, P> Send for ChunkBy<'a, T, P>
where &'a [T]: Send, P: Send,



impl<'a, T, P> Send for ChunkByMut<'a, T, P>
where &'a mut [T]: Send, P: Send,



impl<'a, T, P> Send for wasmtime_environ::__core::slice::RSplit<'a, T, P>
where Split<'a, T, P>: Send,



impl<'a, T, P> Send for RSplitMut<'a, T, P>
where SplitMut<'a, T, P>: Send,



impl<'a, T, P> Send for wasmtime_environ::__core::slice::RSplitN<'a, T, P>
where GenericSplitN<RSplit<'a, T, P>>: Send,



impl<'a, T, P> Send for RSplitNMut<'a, T, P>
where GenericSplitN<RSplitMut<'a, T, P>>: Send,



impl<'a, T, P> Send for wasmtime_environ::__core::slice::Split<'a, T, P>
where &'a [T]: Send, P: Send,



impl<'a, T, P> Send for wasmtime_environ::__core::slice::SplitInclusive<'a, T, P>
where &'a [T]: Send, P: Send,



impl<'a, T, P> Send for SplitInclusiveMut<'a, T, P>
where &'a mut [T]: Send, P: Send,



impl<'a, T, P> Send for SplitMut<'a, T, P>
where &'a mut [T]: Send, P: Send,



impl<'a, T, P> Send for wasmtime_environ::__core::slice::SplitN<'a, T, P>
where GenericSplitN<Split<'a, T, P>>: Send,



impl<'a, T, P> Send for SplitNMut<'a, T, P>
where GenericSplitN<SplitMut<'a, T, P>>: Send,



impl<'a, T, S, A> Send for Difference<'a, T, S, A>
where Iter<'a, T>: Send, &'a HashSet<T, S, A>: Send,



impl<'a, T, S, A> Send for wasmtime_environ::collections::oom_abort::hash_set::Entry<'a, T, S, A>
where OccupiedEntry<'a, T, S, A>: Send, VacantEntry<'a, T, S, A>: Send,



impl<'a, T, S, A> Send for Intersection<'a, T, S, A>
where Iter<'a, T>: Send, &'a HashSet<T, S, A>: Send,



impl<'a, T, S, A> Send for wasmtime_environ::collections::oom_abort::hash_set::OccupiedEntry<'a, T, S, A>
where OccupiedEntry<'a, T, S, A>: Send,



impl<'a, T, S, A> Send for SymmetricDifference<'a, T, S, A>
where Chain<Difference<'a, T, S, A>, Difference<'a, T, S, A>>: Send,



impl<'a, T, S, A> Send for Union<'a, T, S, A>
where Chain<Iter<'a, T>, Difference<'a, T, S, A>>: Send,



impl<'a, T, S, A> Send for wasmtime_environ::collections::oom_abort::hash_set::VacantEntry<'a, T, S, A>
where VacantEntry<'a, T, S, A>: Send,



impl<'a, T, const N: usize> Send for ArrayWindows<'a, T, N>
where &'a [T]: Send,



impl<'a, T> !Send for BorrowedCursor<'a, T>



impl<'a, T> Send for Chunks<'a, T>
where &'a [T]: Send,



impl<'a, T> Send for ChunksExact<'a, T>
where &'a [T]: Send,



impl<'a, T> Send for wasmtime_environ::__core::result::Iter<'a, T>
where Option<&'a T>: Send,



impl<'a, T> Send for wasmtime_environ::__core::result::IterMut<'a, T>



impl<'a, T> Send for RChunks<'a, T>
where &'a [T]: Send,



impl<'a, T> Send for RChunksExact<'a, T>
where &'a [T]: Send,



impl<'a, T> Send for Windows<'a, T>
where &'a [T]: Send,



impl<'a, const N: usize> Send for CharArraySearcher<'a, N>
where <MultiCharEqPattern<[char; N]> as Pattern>::Searcher<'a>: Send,



impl<'a> !Send for wasmtime_environ::error::Chain<'a>



impl<'a> !Send for Context<'a>



impl<'a> !Send for ContextBuilder<'a>



impl<'a> !Send for Formatter<'a>



impl<'a> !Send for PanicInfo<'a>



impl<'a> !Send for PanicMessage<'a>



impl<'a> !Send for Request<'a>



impl<'a> !Send for Source<'a>



impl<'a> !Send for VaList<'a>



impl<'a> Send for AbstractInstantiations<'a>



impl<'a> Send for wasmtime_environ::__core::str::Bytes<'a>



impl<'a> Send for CharIndices<'a>



impl<'a> Send for CharSearcher<'a>



impl<'a> Send for Chars<'a>



impl<'a> Send for DebugInfoData<'a>



impl<'a> Send for EncodeUtf16<'a>



impl<'a> Send for EscapeAscii<'a>



impl<'a> Send for wasmtime_environ::__core::str::EscapeDebug<'a>



impl<'a> Send for wasmtime_environ::__core::str::EscapeDefault<'a>



impl<'a> Send for wasmtime_environ::__core::str::EscapeUnicode<'a>



impl<'a> Send for FlagValue<'a>



impl<'a> Send for FlatTypes<'a>



impl<'a> Send for FrameStateSlot<'a>



impl<'a> Send for FrameTable<'a>



impl<'a> Send for FrameTableBreakpointData<'a>



impl<'a> Send for FunctionBodyData<'a>



impl<'a> Send for Lines<'a>



impl<'a> Send for LinesAny<'a>



impl<'a> Send for MemoryInit<'a>



impl<'a> Send for MemoryInitializer<'a>



impl<'a> Send for MemoryTunables<'a>



impl<'a> Send for wasmtime_environ::fact::Module<'a>



impl<'a> Send for NameSection<'a>



impl<'a> Send for ObjectBuilder<'a>



impl<'a> Send for PhantomContravariantLifetime<'a>



impl<'a> Send for PhantomCovariantLifetime<'a>



impl<'a> Send for PhantomInvariantLifetime<'a>



impl<'a> Send for SplitAsciiWhitespace<'a>



impl<'a> Send for SplitWhitespace<'a>



impl<'a> Send for StackMap<'a>



impl<'a> Send for Utf8Chunk<'a>



impl<'a> Send for Utf8Chunks<'a>



impl<'a> Send for Utf8Pattern<'a>



impl<'b, T> !Send for Ref<'b, T>



impl<'b, T> !Send for RefMut<'b, T>



impl<'data, T> Send for BorrowedBuf<'data, T>
where &'data mut [MaybeUninit<T>]: Send,



impl<'data> Send for ModuleTranslation<'data>



impl<A, B> Send for wasmtime_environ::__core::iter::Chain<A, B>
where Option<A>: Send, Option<B>: Send,



impl<A, B> Send for Zip<A, B>
where A: Send, B: Send,



impl<A> Send for wasmtime_environ::__core::option::IntoIter<A>
where Item<A>: Send,



impl<A> Send for OptionFlatten<A>
where Option<A>: Send,



impl<A> Send for RangeFromIter<A>
where A: Send,



impl<A> Send for RangeInclusiveIter<A>
where RangeInclusive<A>: Send,



impl<A> Send for RangeIter<A>
where Range<A>: Send,



impl<A> Send for wasmtime_environ::__core::iter::Repeat<A>
where A: Send,



impl<A> Send for RepeatN<A>
where Option<RepeatNInner<A>>: Send,



impl<B, C> Send for ControlFlow<B, C>
where C: Send, B: Send,



impl<E> Send for IterEntityRange<E>
where PhantomData<E>: Send,



impl<F> Send for wasmtime_environ::__core::iter::FromFn<F>
where F: Send,



impl<F> Send for wasmtime_environ::__core::fmt::FromFn<F>
where F: Send,



impl<F> Send for OnceWith<F>
where Option<F>: Send,



impl<F> Send for PollFn<F>
where F: Send,



impl<F> Send for RepeatWith<F>
where F: Send,



impl<G, F> Send for FilterNodes<G, F>
where G: Send, F: Send,



impl<G> Send for FromCoroutine<G>
where G: Send,



impl<H> Send for BuildHasherDefault<H>
where PhantomData<fn() -> H>: Send,



impl<I, F, const N: usize> Send for MapWindows<I, F, N>
where F: Send, MapWindowsInner<I, N>: Send,



impl<I, F> Send for FilterMap<I, F>
where I: Send, F: Send,



impl<I, F> Send for Inspect<I, F>
where I: Send, F: Send,



impl<I, F> Send for Map<I, F>
where I: Send, F: Send,



impl<I, G> Send for IntersperseWith<I, G>
where G: Send, Option<<I as Iterator>::Item>: Send, I: Send,



impl<I, P> Send for Filter<I, P>
where I: Send, P: Send,



impl<I, P> Send for MapWhile<I, P>
where I: Send, P: Send,



impl<I, P> Send for SkipWhile<I, P>
where I: Send, P: Send,



impl<I, P> Send for TakeWhile<I, P>
where I: Send, P: Send,



impl<I, St, F> Send for Scan<I, St, F>
where I: Send, F: Send, St: Send,



impl<I, U, F> Send for FlatMap<I, U, F>
where FlattenCompat<Map<I, F>, <U as IntoIterator>::IntoIter>: Send,



impl<I, const N: usize> Send for ArrayChunks<I, N>
where I: Send, Option<IntoIter<<I as Iterator>::Item, N>>: Send,



impl<I> Send for ArrayOffsets<I>
where PhantomData<I>: Send,



impl<I> Send for Cloned<I>
where I: Send,



impl<I> Send for Copied<I>
where I: Send,



impl<I> Send for Cycle<I>
where I: Send,



impl<I> Send for DecodeUtf16<I>
where I: Send,



impl<I> Send for Enumerate<I>
where I: Send,



impl<I> Send for Flatten<I>
where FlattenCompat<I, <<I as Iterator>::Item as IntoIterator>::IntoIter>: Send,



impl<I> Send for FromIter<I>
where I: Send,



impl<I> Send for Fuse<I>
where Option<I>: Send,



impl<I> Send for Intersperse<I>
where <I as Iterator>::Item: Sized + Send, Option<<I as Iterator>::Item>: Send, I: Send,



impl<I> Send for Peekable<I>
where I: Send, Option<Option<<I as Iterator>::Item>>: Send,



impl<I> Send for Skip<I>
where I: Send,



impl<I> Send for StepBy<I>
where I: Send,



impl<I> Send for wasmtime_environ::__core::iter::Take<I>
where I: Send,



impl<Idx> Send for Clamp<Idx>
where Idx: Send,



impl<Idx> Send for wasmtime_environ::__core::ops::Range<Idx>
where Idx: Send,



impl<Idx> Send for wasmtime_environ::__core::range::Range<Idx>
where Idx: Send,



impl<Idx> Send for wasmtime_environ::__core::ops::RangeFrom<Idx>
where Idx: Send,



impl<Idx> Send for wasmtime_environ::__core::range::RangeFrom<Idx>
where Idx: Send,



impl<Idx> Send for wasmtime_environ::__core::ops::RangeInclusive<Idx>
where Idx: Send,



impl<Idx> Send for wasmtime_environ::__core::range::RangeInclusive<Idx>
where Idx: Send,



impl<Idx> Send for RangeTo<Idx>
where Idx: Send,



impl<Idx> Send for wasmtime_environ::__core::ops::RangeToInclusive<Idx>
where Idx: Send,



impl<Idx> Send for wasmtime_environ::__core::range::RangeToInclusive<Idx>
where Idx: Send,



impl<K, A> Send for wasmtime_environ::collections::oom_abort::hash_set::IntoIter<K, A>
where IntoIter<K, A>: Send,



impl<K, V, A> Send for wasmtime_environ::collections::oom_abort::hash_map::IntoIter<K, V, A>
where IntoIter<K, V, A>: Send,



impl<K, V, A> Send for IntoKeys<K, V, A>
where IntoIter<K, V, A>: Send,



impl<K, V, A> Send for IntoValues<K, V, A>
where IntoIter<K, V, A>: Send,



impl<K, V, S, A> Send for HashMap<K, V, S, A>
where HashMap<K, V, S, A>: Send,



impl<K, V, S> Send for TryHashMap<K, V, S>
where HashMap<K, V, S>: Send,



impl<K, V, S> Send for TryIndexMap<K, V, S>
where IndexMap<K, V, S>: Send,



impl<K, V> Send for BTreeMapIntoIter<K, V>
where MapIntoIter<K, Id>: Send, Slab<V>: Send,



impl<K, V> Send for BoxedSlice<K, V>
where Box<[V]>: Send, PhantomData<K>: Send,



impl<K, V> Send for IndexMap<K, V>
where IndexMap<K, V, RandomState>: Send,



impl<K, V> Send for Intern<K, V>
where HashMap<V, K>: Send, PrimaryMap<K, V>: Send,



impl<K, V> Send for wasmtime_environ::IntoIter<K, V>



impl<K, V> Send for NameMap<K, V>
where TryIndexMap<K, V>: Send, TryIndexMap<K, (K, TryVersion)>: Send,



impl<K, V> Send for PrimaryMap<K, V>
where Vec<V>: Send, PhantomData<K>: Send,



impl<K, V> Send for SecondaryMap<K, V>
where Vec<V>: Send, V: Send, PhantomData<K>: Send,



impl<K, V> Send for SparseMap<K, V>
where SecondaryMap<K, u32>: Send, Vec<V>: Send,



impl<K, V> Send for TryBTreeMap<K, V>
where Slab<V>: Send, MapForest<K, Id>: Send, Map<K, Id>: Send,



impl<K, V> Send for TryPrimaryMap<K, V>
where PrimaryMap<K, V>: Send,



impl<K, V> Send for TrySecondaryMap<K, V>
where SecondaryMap<K, V>: Send,



impl<K> Send for EntitySet<K>
where PhantomData<K>: Send,



impl<K> Send for wasmtime_environ::Keys<K>
where PhantomData<K>: Send,



impl<K> Send for TryEntitySet<K>
where EntitySet<K>: Send,



impl<Node> Send for Dfs<Node>
where Vec<DfsEvent<Node>>: Send,



impl<Node> Send for DfsEvent<Node>
where Node: Send,



impl<Node> Send for EntityGraph<Node>
where SecondaryMap<Node, Range<u32>>: Send, Vec<Node>: Send,



impl<Node> Send for StronglyConnectedComponents<Node>
where Vec<Node>: Send,



impl<P> Send for MaybeDangling<P>
where P: Send + ?Sized,



impl<P> Send for VMCommonStackInformation<P>
where P: Send,



impl<P> Send for VMComponentContext<P>
where P: Send,



impl<P> Send for VMComponentOffsets<P>
where P: Send,



impl<P> Send for VMContRef<P>
where P: Send,



impl<P> Send for VMContext<P>
where P: Send,



impl<P> Send for VMCopyingHeapData<P>
where P: Send,



impl<P> Send for VMDeferredThread<P>
where P: Send,



impl<P> Send for VMDrcHeapData<P>
where P: Send,



impl<P> Send for VMFuncRef<P>
where P: Send,



impl<P> Send for VMFunctionImport<P>
where P: Send,



impl<P> Send for VMGlobalDefinition<P>
where P: Send,



impl<P> Send for VMGlobalImport<P>
where P: Send,



impl<P> Send for VMHostArray<P>
where P: Send,



impl<P> Send for VMLazyThread<P>
where P: Send,



impl<P> Send for VMMemoryDefinition<P>
where P: Send,



impl<P> Send for VMMemoryImport<P>
where P: Send,



impl<P> Send for VMNullHeapData<P>
where P: Send,



impl<P> Send for VMOffsets<P>
where P: Send,



impl<P> Send for VMOffsetsFields<P>
where P: Send,



impl<P> Send for VMStackLimits<P>
where P: Send,



impl<P> Send for VMStoreContext<P>
where P: Send,



impl<P> Send for VMTableDefinition<P>
where P: Send,



impl<P> Send for VMTableImport<P>
where P: Send,



impl<P> Send for VMTagDefinition<P>
where P: Send,



impl<P> Send for VMTagImport<P>
where P: Send,



impl<Ptr> Send for Pin<Ptr>
where Ptr: Send,



impl<T, A> Send for Box<T, A>
where Unique<T>: Send, A: Send, T: ?Sized,



impl<T, A> Send for Vec<T, A>
where RawVec<T, A>: Send,



impl<T, E> Send for Result<T, E>
where T: Send, E: Send,



impl<T, F> Send for DropGuard<T, F>



impl<T, F> Send for LazyCell<T, F>
where UnsafeCell<State<T, F>>: Send,



impl<T, F> Send for Successors<T, F>
where Option<T>: Send, F: Send,



impl<T, F> Send for Undo<T, F>



impl<T, S, A> Send for HashSet<T, S, A>
where HashSet<T, S, A>: Send,



impl<T, S> Send for TryHashSet<T, S>
where HashSet<T, S>: Send,



impl<T, U> Send for wasmtime_environ::__core::io::Chain<T, U>
where T: Send, U: Send,



impl<T, const N: usize> Send for wasmtime_environ::__core::array::IntoIter<T, N>
where ManuallyDrop<PolymorphicIter<[MaybeUninit<T>; N]>>: Send,



impl<T, const N: usize> Send for Mask<T, N>
where Simd<T, N>: Send,



impl<T, const N: usize> Send for Simd<T, N>
where [T; N]: Send,



impl<T, const VARIANT: u32, const FIELD: u32> Send for FieldRepresentingType<T, VARIANT, FIELD>
where PhantomData<fn(T) -> T>: Send, T: ?Sized,



impl<T> Send for AssertUnwindSafe<T>
where T: Send,



impl<T> Send for Bound<T>
where T: Send,



impl<T> Send for Complex<T>
where T: Send,



impl<T> Send for wasmtime_environ::component::CoreExport<T>
where ExportItem<T>: Send,



impl<T> Send for wasmtime_environ::component::dfg::CoreExport<T>
where ExportItem<T>: Send,



impl<T> Send for CovariantUnsafeCell<T>
where UnsafeCell<T>: Send, T: ?Sized,



impl<T> Send for wasmtime_environ::__core::io::Cursor<T>
where T: Send,



impl<T> Send for Discriminant<T>



impl<T> Send for wasmtime_environ::__core::iter::Empty<T>
where PhantomData<fn() -> T>: Send,



impl<T> Send for EntityList<T>
where PhantomData<T>: Send,



impl<T> Send for ExportItem<T>
where T: Send,



impl<T> Send for IndexSet<T>
where IndexMap<T, ()>: Send,



impl<T> Send for wasmtime_environ::__core::result::IntoIter<T>
where Option<T>: Send,



impl<T> Send for KnownEntity<T>
where T: Send,



impl<T> Send for ListPool<T>
where Vec<T>: Send,



impl<T> Send for ManuallyDrop<T>
where MaybeDangling<T>: Send, T: ?Sized,



impl<T> Send for MaybeUninit<T>
where ManuallyDrop<T>: Send,



impl<T> Send for NumBuffer<T>
where <T as NumBufferTrait>::Buf: Send, PhantomData<T>: Send,



impl<T> Send for Once<T>
where IntoIter<T>: Send,



impl<T> Send for OnceCell<T>
where UnsafeCell<Option<T>>: Send,



impl<T> Send for Option<T>
where T: Send,



impl<T> Send for PackedOption<T>
where T: Send,



impl<T> Send for Pending<T>
where PhantomData<fn() -> T>: Send,



impl<T> Send for PhantomContravariant<T>
where PhantomData<fn(T)>: Send, T: ?Sized,



impl<T> Send for PhantomCovariant<T>
where PhantomData<fn() -> T>: Send, T: ?Sized,



impl<T> Send for PhantomData<T>
where T: ?Sized,



impl<T> Send for PhantomInvariant<T>
where PhantomData<fn(T) -> T>: Send, T: ?Sized,



impl<T> Send for Poll<T>
where T: Send,



impl<T> Send for Ready<T>
where Option<T>: Send,



impl<T> Send for Rev<T>
where T: Send,



impl<T> Send for Reverse<T>
where T: Send,



impl<T> Send for Saturating<T>
where T: Send,



impl<T> Send for ScopeVec<T>
where RefCell<Vec<Box<[T]>>>: Send,



impl<T> Send for SyncUnsafeCell<T>
where UnsafeCell<T>: Send, T: ?Sized,



impl<T> Send for SyncView<T>
where T: Send + ?Sized,



impl<T> Send for wasmtime_environ::__core::io::Take<T>
where T: Send,



impl<T> Send for TraitImpl<T>
where DynMetadata<T>: Send, T: ?Sized,



impl<T> Send for TryVec<T>
where Vec<T>: Send,



impl<T> Send for UnsafeCell<T>
where T: Send + ?Sized,



impl<T> Send for UnsafePinned<T>
where UnsafeCell<T>: Send, T: ?Sized,



impl<T> Send for Wrapping<T>
where T: Send,



impl<T> Send for Yeet<T>
where T: Send,



impl<Y, R> Send for CoroutineState<Y, R>
where Y: Send, R: Send,