Unpin

Trait Unpin 

1.33.0 · Source
pub auto trait Unpin { }
Types that do not require any pinning guarantees.

For information on what “pinning” is, see the pin module documentation.

Implementing the Unpin trait for T expresses the fact that T is pinning-agnostic: it shall not expose nor rely on any pinning guarantees. This, in turn, means that a Pin-wrapped pointer to such a type can feature a fully unrestricted API. In other words, if T: Unpin, a value of type T will not be bound by the invariants which pinning otherwise offers, even when “pinned” by a Pin<Ptr> pointing at it. When a value of type T is pointed at by a Pin<Ptr>, Pin will not restrict access to the pointee value like it normally would, thus allowing the user to do anything that they normally could with a non-Pin-wrapped Ptr to that value.

The idea of this trait is to alleviate the reduced ergonomics of APIs that require the use of Pin for soundness for some types, but which also want to be used by other types that don’t care about pinning. The prime example of such an API is Future::poll. There are many Future types that don’t care about pinning. These futures can implement Unpin and therefore get around the pinning related restrictions in the API, while still allowing the subset of Futures which do require pinning to be implemented soundly.

For more discussion on the consequences of Unpin within the wider scope of the pinning system, see the section about Unpin in the pin module.

Unpin has no consequence at all for non-pinned data. In particular, mem::replace happily moves !Unpin data, which would be immovable when pinned (mem::replace works for any &mut T, not just when T: Unpin).

However, you cannot use mem::replace on !Unpin data which is pinned by being wrapped inside a Pin<Ptr> pointing at it. This is because you cannot (safely) use a Pin<Ptr> to get a &mut T to its pointee value, which you would need to call mem::replace, and that is what makes this system work.

So this, for example, can only be done on types implementing Unpin:

use std::mem;
use std::pin::Pin;

let mut string = "this".to_string();
let mut pinned_string = Pin::new(&mut string);

// We need a mutable reference to call `mem::replace`.
// We can obtain such a reference by (implicitly) invoking `Pin::deref_mut`,
// but that is only possible because `String` implements `Unpin`.
mem::replace(&mut *pinned_string, "other".to_string());

This trait is automatically implemented for almost every type. The compiler is free to take the conservative stance of marking types as Unpin so long as all of the types that compose its fields are also Unpin. This is because if a type implements Unpin, then it is unsound for that type’s implementation to rely on pinning-related guarantees for soundness, even when viewed through a “pinning” pointer! It is the responsibility of the implementor of a type that relies upon pinning for soundness to ensure that type is not marked as Unpin by adding PhantomPinned field. For more details, see the pin module docs.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.33.0 · Source

impl !Unpin for PhantomPinned

Source

impl Unpin for LocalWaker

1.36.0 · Source

impl Unpin for Waker

Source

impl<Dyn> Unpin for DynMetadata<Dyn>
where Dyn: ?Sized,

1.64.0 · Source

impl<F> Unpin for PollFn<F>
where F: Unpin,

Source

impl<I> Unpin for FromIter<I>

1.33.0 · Source

impl<T, A> Unpin for Arc<T, A>
where A: Allocator, T: ?Sized,

1.33.0 · Source

impl<T, A> Unpin for Box<T, A>
where A: Allocator, T: ?Sized,

1.33.0 · Source

impl<T, A> Unpin for Rc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> Unpin for UniqueArc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> Unpin for UniqueRc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T> !Unpin for UnsafePinned<T>
where T: ?Sized,

When this type is used, that almost certainly means safe APIs need to use pinning to avoid the aliases from becoming invalidated. Therefore let’s mark this as !Unpin. You can always opt back in to Unpin with an impl block, provided your API is still sound while unpinned.

1.33.0 · Source

impl<T> Unpin for &T
where T: ?Sized,

1.33.0 · Source

impl<T> Unpin for &mut T
where T: ?Sized,

Source

impl<T> Unpin for *const T is !null
where T: ?Sized,

1.38.0 · Source

impl<T> Unpin for *const T
where T: ?Sized,

1.38.0 · Source

impl<T> Unpin for *mut T
where T: ?Sized,

1.28.0 · Source

impl<T> Unpin for NonZero<T>

1.48.0 · Source

impl<T> Unpin for Ready<T>

Auto implementors



impl Unpin for wasmtime_environ::Abi



impl Unpin for wasmtime_environ::__core::mem::type_info::Abi



impl Unpin for AbstractResourceIndex



impl Unpin for Adapter



impl Unpin for AdapterId



impl Unpin for AdapterModuleId



impl Unpin for AdapterOptions



impl Unpin for AddrParseError



impl Unpin for AddressMapSection



impl Unpin for wasmtime_environ::__core::mem::Alignment



impl Unpin for wasmtime_environ::__core::fmt::Alignment



impl Unpin for AllocError



impl Unpin for Array



impl Unpin for AsciiChar



impl Unpin for Assume



impl Unpin for Atom



impl Unpin for AtomicOrdering



impl Unpin for BasicBlock



impl Unpin for BorrowError



impl Unpin for BorrowMutError



impl Unpin for BuiltinFunctionIndex



impl Unpin for ByteStr



impl Unpin for CStr



impl Unpin for CallbackId



impl Unpin for CanonicalAbiInfo



impl Unpin for wasmtime_environ::component::CanonicalOptions



impl Unpin for wasmtime_environ::component::dfg::CanonicalOptions



impl Unpin for wasmtime_environ::component::CanonicalOptionsDataModel



impl Unpin for wasmtime_environ::component::dfg::CanonicalOptionsDataModel



impl Unpin for CharCase



impl Unpin for CharTryFromError



impl Unpin for Collector



impl Unpin for CompileError



impl Unpin for CompiledComponentInfo



impl Unpin for CompiledFunctionBody



impl Unpin for CompiledFunctionsTable



impl Unpin for CompiledFunctionsTableBuilder



impl Unpin for CompiledModuleInfo



impl Unpin for CompiledTrap



impl Unpin for Component



impl Unpin for ComponentArtifacts



impl Unpin for ComponentBuiltinFunctionIndex



impl Unpin for ComponentDfg



impl Unpin for ComponentExtern



impl Unpin for ComponentExternData



impl Unpin for ComponentFuncIndex



impl Unpin for ComponentIndex



impl Unpin for ComponentInstanceIndex



impl Unpin for ComponentItem



impl Unpin for ComponentPC



impl Unpin for ComponentTranslation



impl Unpin for ComponentTypeIndex



impl Unpin for ComponentTypes



impl Unpin for ComponentTypesBuilder



impl Unpin for ComponentUpvarIndex



impl Unpin for ConfigTunables



impl Unpin for Const



impl Unpin for ConstExpr



impl Unpin for ConstOp



impl Unpin for CopyingTypeLayouts



impl Unpin for wasmtime_environ::component::CoreDef



impl Unpin for wasmtime_environ::component::dfg::CoreDef



impl Unpin for CpuidResult



impl Unpin for DataIndex



impl Unpin for DataModel



impl Unpin for DebugAsHex



impl Unpin for DecodeUtf16Error



impl Unpin for DefaultHasher



impl Unpin for DefinedFuncIndex



impl Unpin for DefinedGlobalIndex



impl Unpin for DefinedMemoryIndex



impl Unpin for DefinedResourceIndex



impl Unpin for DefinedTableIndex



impl Unpin for DefinedTagIndex



impl Unpin for DrcTypeLayouts



impl Unpin for Duration



impl Unpin for DynTrait



impl Unpin for DynTraitPredicate



impl Unpin for ElemIndex



impl Unpin for wasmtime_environ::__core::io::Empty



impl Unpin for EngineInternedRecGroupIndex



impl Unpin for EngineOrModuleTypeIndex



impl Unpin for EntityIndex



impl Unpin for EntityType



impl Unpin for wasmtime_environ::prelude::Error



impl Unpin for wasmtime_environ::__core::io::Error



impl Unpin for wasmtime_environ::__core::fmt::Error



impl Unpin for ErrorKind



impl Unpin for wasmtime_environ::__core::char::EscapeDebug



impl Unpin for wasmtime_environ::__core::ascii::EscapeDefault



impl Unpin for wasmtime_environ::__core::char::EscapeDefault



impl Unpin for wasmtime_environ::__core::char::EscapeUnicode



impl Unpin for Evaporation



impl Unpin for wasmtime_environ::component::Export



impl Unpin for wasmtime_environ::component::dfg::Export



impl Unpin for ExportIndex



impl Unpin for ExtractCallback



impl Unpin for ExtractMemory



impl Unpin for ExtractPostReturn



impl Unpin for ExtractRealloc



impl Unpin for ExtractTable



impl Unpin for FactInlineIntrinsic



impl Unpin for FieldId



impl Unpin for FilePos



impl Unpin for FixedEncoding



impl Unpin for FlatType



impl Unpin for FnPtr



impl Unpin for FormattingOptions



impl Unpin for FpCategory



impl Unpin for FrameInstPos



impl Unpin for FrameStackShape



impl Unpin for FrameStateSlotBuilder



impl Unpin for FrameStateSlotOffset



impl Unpin for FrameTableBuilder



impl Unpin for FrameTableDescriptorIndex



impl Unpin for FrameValType



impl Unpin for FromBytesUntilNulError



impl Unpin for FromBytesWithNulError



impl Unpin for FuncIndex



impl Unpin for FuncKey



impl Unpin for FuncKeyIndex



impl Unpin for FuncKeyKind



impl Unpin for FuncKeyNamespace



impl Unpin for FuncRefIndex



impl Unpin for FunctionLoc



impl Unpin for FunctionMetadata



impl Unpin for FunctionName



impl Unpin for FunctionType



impl Unpin for FutureInfo



impl Unpin for GcArrayLayout



impl Unpin for GcLayout



impl Unpin for GcStructLayout



impl Unpin for GcStructLayoutField



impl Unpin for Generic



impl Unpin for GenericType



impl Unpin for GetDisjointMutError



impl Unpin for Global



impl Unpin for GlobalConstValue



impl Unpin for GlobalIndex



impl Unpin for GlobalInitializer



impl Unpin for HostCall



impl Unpin for HostPtr



impl Unpin for Import



impl Unpin for ImportIndex



impl Unpin for IndexType



impl Unpin for Infallible



impl Unpin for Initializer



impl Unpin for InlineTraceInfo



impl Unpin for Inlining



impl Unpin for Instance



impl Unpin for InstanceId



impl Unpin for InstantiateModule



impl Unpin for InstructionAddressMap



impl Unpin for IntErrorKind



impl Unpin for InterfaceType



impl Unpin for IpAddr



impl Unpin for Ipv4Addr



impl Unpin for Ipv6Addr



impl Unpin for Ipv6MulticastScope



impl Unpin for KnownFunc



impl Unpin for KnownGlobal



impl Unpin for Last



impl Unpin for Layout



impl Unpin for LayoutError



impl Unpin for Lifetime



impl Unpin for Limits



impl Unpin for LinearMemoryOptions



impl Unpin for LocalDataModel



impl Unpin for Locality



impl Unpin for LoweredIndex



impl Unpin for Memory



impl Unpin for MemoryId



impl Unpin for MemoryIndex



impl Unpin for MemoryInitialization



impl Unpin for MemoryKind



impl Unpin for MemorySegmentOffset



impl Unpin for Metadata



impl Unpin for wasmtime_environ::Module



impl Unpin for ModuleIndex



impl Unpin for ModuleInstanceIndex



impl Unpin for ModuleInternedRecGroupIndex



impl Unpin for ModuleInternedTypeIndex



impl Unpin for ModulePC



impl Unpin for ModuleStartup



impl Unpin for ModuleTypes



impl Unpin for ModuleTypesBuilder



impl Unpin for ModuleUpvarIndex



impl Unpin for NameMapNoIntern



impl Unpin for NonMaxU8



impl Unpin for NonMaxU16



impl Unpin for NonMaxU32



impl Unpin for NonMaxU64



impl Unpin for NonMaxUsize



impl Unpin for NullTypeLayouts



impl Unpin for ObjectCrateErrorWrapper



impl Unpin for ObjectKind



impl Unpin for OneSidedRangeBound



impl Unpin for OperatorCost



impl Unpin for OperatorCostStrategy



impl Unpin for OptionsId



impl Unpin for OptionsIndex



impl Unpin for wasmtime_environ::__core::cmp::Ordering



impl Unpin for wasmtime_environ::__core::sync::atomic::Ordering



impl Unpin for OutOfMemory



impl Unpin for OwnedMemoryIndex



impl Unpin for ParseBoolError



impl Unpin for ParseCharError



impl Unpin for ParseFloatError



impl Unpin for ParseIntError



impl Unpin for PassiveElemIndex



impl Unpin for Pointer



impl Unpin for PostReturnId



impl Unpin for RandomState



impl Unpin for RangeFull



impl Unpin for RawWaker



impl Unpin for RawWakerVTable



impl Unpin for ReallocId



impl Unpin for RecGroupRelativeTypeIndex



impl Unpin for RecordField



impl Unpin for Reference



impl Unpin for wasmtime_environ::__core::io::Repeat



impl Unpin for wasmtime_environ::component::Resource



impl Unpin for wasmtime_environ::component::dfg::Resource



impl Unpin for ResourceIndex



impl Unpin for ResourcesBuilder



impl Unpin for ReturnToArg



impl Unpin for RuntimeCallbackIndex



impl Unpin for RuntimeComponentInstanceIndex



impl Unpin for RuntimeDataIndex



impl Unpin for RuntimeImportIndex



impl Unpin for RuntimeInstanceIndex



impl Unpin for RuntimeMemoryIndex



impl Unpin for RuntimePostReturnIndex



impl Unpin for RuntimeReallocIndex



impl Unpin for RuntimeTableIndex



impl Unpin for Scc



impl Unpin for SearchStep



impl Unpin for SeekFrom



impl Unpin for Setting



impl Unpin for SettingKind



impl Unpin for SideEffect



impl Unpin for Sign



impl Unpin for SimdAlign



impl Unpin for Sink



impl Unpin for SipHasher



impl Unpin for SizeOverflow



impl Unpin for Slice



impl Unpin for SocketAddr



impl Unpin for SocketAddrV4



impl Unpin for SocketAddrV6



impl Unpin for StackMapSection



impl Unpin for StaticComponentIndex



impl Unpin for StaticModuleIndex



impl Unpin for Str



impl Unpin for StreamInfo



impl Unpin for String



impl Unpin for StringEncoding



impl Unpin for StringPool



impl Unpin for Table



impl Unpin for TableId



impl Unpin for TableIndex



impl Unpin for TableInitialValue



impl Unpin for TableInitialization



impl Unpin for TableSegment



impl Unpin for TableSegmentElements



impl Unpin for Tag



impl Unpin for TagIndex



impl Unpin for ToCasefold



impl Unpin for ToLowercase



impl Unpin for ToTitlecase



impl Unpin for ToUppercase



impl Unpin for Trait



impl Unpin for wasmtime_environ::component::Trampoline



impl Unpin for wasmtime_environ::component::dfg::Trampoline



impl Unpin for TrampolineIndex



impl Unpin for Transcode



impl Unpin for Trap



impl Unpin for TrapEncodingBuilder



impl Unpin for TrapInformation



impl Unpin for TrapSentinel



impl Unpin for TryFromCharError



impl Unpin for TryFromFloatSecsError



impl Unpin for TryFromIntError



impl Unpin for TryFromSliceError



impl Unpin for TryString



impl Unpin for Tunables



impl Unpin for Type



impl Unpin for TypeComponent



impl Unpin for TypeComponentGlobalErrorContextTableIndex



impl Unpin for TypeComponentIndex



impl Unpin for TypeComponentInstance



impl Unpin for TypeComponentInstanceIndex



impl Unpin for TypeComponentLocalErrorContextTableIndex



impl Unpin for TypeDef



impl Unpin for TypeEnum



impl Unpin for TypeEnumIndex



impl Unpin for TypeErrorContextTable



impl Unpin for TypeFixedLengthList



impl Unpin for TypeFixedLengthListIndex



impl Unpin for TypeFlags



impl Unpin for TypeFlagsIndex



impl Unpin for TypeFunc



impl Unpin for TypeFuncIndex



impl Unpin for TypeFuture



impl Unpin for TypeFutureIndex



impl Unpin for TypeFutureTable



impl Unpin for TypeFutureTableIndex



impl Unpin for TypeId



impl Unpin for TypeIndex



impl Unpin for TypeKind



impl Unpin for TypeList



impl Unpin for TypeListIndex



impl Unpin for TypeMap



impl Unpin for TypeMapIndex



impl Unpin for TypeModule



impl Unpin for TypeModuleIndex



impl Unpin for TypeOption



impl Unpin for TypeOptionIndex



impl Unpin for TypeRecord



impl Unpin for TypeRecordIndex



impl Unpin for TypeResourceTable



impl Unpin for TypeResourceTableIndex



impl Unpin for TypeResult



impl Unpin for TypeResultIndex



impl Unpin for TypeStream



impl Unpin for TypeStreamIndex



impl Unpin for TypeStreamTable



impl Unpin for TypeStreamTableIndex



impl Unpin for TypeTuple



impl Unpin for TypeTupleIndex



impl Unpin for TypeVariant



impl Unpin for TypeVariantIndex



impl Unpin for UnsafeIntrinsic



impl Unpin for UnwindActionArg



impl Unpin for UnwindTerminateReason



impl Unpin for Utf8Error



impl Unpin for VMGcKind



impl Unpin for VMSharedTypeIndex



impl Unpin for VariableOperatorCost



impl Unpin for VariantId



impl Unpin for VariantInfo



impl Unpin for WasmArrayType



impl Unpin for WasmChecksum



impl Unpin for WasmCompositeInnerType



impl Unpin for WasmCompositeType



impl Unpin for WasmContType



impl Unpin for WasmError



impl Unpin for WasmExnType



impl Unpin for WasmFieldType



impl Unpin for WasmFileInfo



impl Unpin for WasmFuncType



impl Unpin for WasmHeapBottomType



impl Unpin for WasmHeapTopType



impl Unpin for WasmHeapType



impl Unpin for WasmRecGroup



impl Unpin for WasmRefType



impl Unpin for WasmStorageType



impl Unpin for WasmStructType



impl Unpin for WasmSubType



impl Unpin for WasmValType



impl Unpin for __m128



impl Unpin for __m256



impl Unpin for __m512



impl Unpin for __m128bh



impl Unpin for __m128d



impl Unpin for __m128h



impl Unpin for __m128i



impl Unpin for __m256bh



impl Unpin for __m256d



impl Unpin for __m256h



impl Unpin for __m256i



impl Unpin for __m512bh



impl Unpin for __m512d



impl Unpin for __m512h



impl Unpin for __m512i



impl Unpin for __tile1024i



impl Unpin for bf16



impl Unpin for c_void



impl<'a, 'b, const N: usize> Unpin for CharArrayRefSearcher<'a, 'b, N>
where <MultiCharEqPattern<&'b [char; N]> as Pattern>::Searcher<'a>: Unpin,



impl<'a, 'b> Unpin for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Unpin for DebugList<'a, 'b>



impl<'a, 'b> Unpin for DebugMap<'a, 'b>



impl<'a, 'b> Unpin for DebugSet<'a, 'b>



impl<'a, 'b> Unpin for DebugStruct<'a, 'b>



impl<'a, 'b> Unpin for DebugTuple<'a, 'b>



impl<'a, 'b> Unpin for StrSearcher<'a, 'b>



impl<'a, 'data> Unpin for ModuleEnvironment<'a, 'data>



impl<'a, 'data> Unpin for Translator<'a, 'data>



impl<'a, A> Unpin for wasmtime_environ::__core::option::Iter<'a, A>
where Item<&'a A>: Unpin,



impl<'a, A> Unpin for wasmtime_environ::__core::option::IterMut<'a, A>
where Item<&'a mut A>: Unpin,



impl<'a, B> Unpin for TryCow<'a, B>
where &'a B: Unpin, <B as TryToOwned>::Owned: Unpin, B: ?Sized,



impl<'a, F> Unpin for CharPredicateSearcher<'a, F>
where <MultiCharEqPattern<F> as Pattern>::Searcher<'a>: Unpin,



impl<'a, F> Unpin for WasmparserTypeConverter<'a, F>
where F: Unpin,



impl<'a, I, A> Unpin for Splice<'a, I, A>
where Drain<'a, <I as Iterator>::Item, A>: Unpin, I: Unpin,



impl<'a, I> Unpin for ByRefSized<'a, I>



impl<'a, K, A> Unpin for wasmtime_environ::collections::oom_abort::hash_set::Drain<'a, K, A>
where Drain<'a, K, A>: Unpin,



impl<'a, K, F, A> Unpin for wasmtime_environ::collections::oom_abort::hash_set::ExtractIf<'a, K, F, A>
where ExtractIf<'a, K, F, A>: Unpin,



impl<'a, K, V, A> Unpin for wasmtime_environ::collections::oom_abort::hash_map::Drain<'a, K, V, A>
where Drain<'a, K, V, A>: Unpin,



impl<'a, K, V, A> Unpin for wasmtime_environ::collections::oom_abort::hash_map::Entry<'a, K, V, A>
where OccupiedEntry<'a, K, V, A>: Unpin, VacantEntry<'a, K, V, A>: Unpin,



impl<'a, K, V, A> Unpin for wasmtime_environ::collections::oom_abort::hash_map::OccupiedEntry<'a, K, V, A>
where RustcOccupiedEntry<'a, K, V, A>: Unpin,



impl<'a, K, V, A> Unpin for OccupiedError<'a, K, V, A>
where OccupiedEntry<'a, K, V, A>: Unpin, K: Unpin, V: Unpin,



impl<'a, K, V, A> Unpin for wasmtime_environ::collections::oom_abort::hash_map::VacantEntry<'a, K, V, A>
where RustcVacantEntry<'a, K, V, A>: Unpin,



impl<'a, K, V, F, A> Unpin for wasmtime_environ::collections::oom_abort::hash_map::ExtractIf<'a, K, V, F, A>
where ExtractIf<'a, K, V, F, A>: Unpin,



impl<'a, K, V> Unpin for BTreeMapIter<'a, K, V>
where MapIter<'a, K, Id>: Unpin, &'a Slab<V>: Unpin,



impl<'a, K, V> Unpin for BTreeMapIterMut<'a, K, V>
where MapIter<'a, K, Id>: Unpin, &'a mut Slab<V>: Unpin,



impl<'a, K, V> Unpin for BTreeMapKeys<'a, K, V>
where BTreeMapIter<'a, K, V>: Unpin,



impl<'a, K, V> Unpin for BTreeMapRange<'a, K, V>
where MapRange<'a, K, Id, ()>: Unpin, &'a Slab<V>: Unpin,



impl<'a, K, V> Unpin for BTreeMapRangeMut<'a, K, V>
where MapRange<'a, K, Id, ()>: Unpin, &'a mut Slab<V>: Unpin,



impl<'a, K, V> Unpin for BTreeMapValues<'a, K, V>
where BTreeMapIter<'a, K, V>: Unpin,



impl<'a, K, V> Unpin for BTreeMapValuesMut<'a, K, V>
where BTreeMapIterMut<'a, K, V>: Unpin,



impl<'a, K, V> Unpin for wasmtime_environ::collections::btree_map::Entry<'a, K, V>
where OccupiedEntry<'a, K, V>: Unpin, VacantEntry<'a, K, V>: Unpin,



impl<'a, K, V> Unpin for wasmtime_environ::Iter<'a, K, V>
where Enumerate<Iter<'a, V>>: Unpin, PhantomData<K>: Unpin,



impl<'a, K, V> Unpin for wasmtime_environ::collections::oom_abort::hash_map::Iter<'a, K, V>
where Iter<'a, K, V>: Unpin,



impl<'a, K, V> Unpin for wasmtime_environ::IterMut<'a, K, V>
where Enumerate<IterMut<'a, V>>: Unpin, PhantomData<K>: Unpin,



impl<'a, K, V> Unpin for wasmtime_environ::collections::oom_abort::hash_map::IterMut<'a, K, V>
where IterMut<'a, K, V>: Unpin,



impl<'a, K, V> Unpin for wasmtime_environ::collections::oom_abort::hash_map::Keys<'a, K, V>
where Iter<'a, K, V>: Unpin,



impl<'a, K, V> Unpin for wasmtime_environ::collections::btree_map::OccupiedEntry<'a, K, V>
where MapCursorMut<'a, K, Id, ()>: Unpin, &'a mut Slab<V>: Unpin,



impl<'a, K, V> Unpin for wasmtime_environ::collections::btree_map::VacantEntry<'a, K, V>
where K: Unpin, MapCursorMut<'a, K, Id, ()>: Unpin, &'a mut Slab<V>: Unpin,



impl<'a, K, V> Unpin for Values<'a, K, V>
where Iter<'a, K, V>: Unpin,



impl<'a, K, V> Unpin for ValuesMut<'a, K, V>
where IterMut<'a, K, V>: Unpin,



impl<'a, K> Unpin for wasmtime_environ::collections::oom_abort::hash_set::Iter<'a, K>
where Iter<'a, K>: Unpin,



impl<'a, K> Unpin for SetIter<'a, K>
where PhantomData<K>: Unpin,



impl<'a, P> Unpin for MatchIndices<'a, P>
where MatchIndicesInternal<'a, P>: Unpin,



impl<'a, P> Unpin for Matches<'a, P>
where MatchesInternal<'a, P>: Unpin,



impl<'a, P> Unpin for RMatchIndices<'a, P>
where MatchIndicesInternal<'a, P>: Unpin,



impl<'a, P> Unpin for RMatches<'a, P>
where MatchesInternal<'a, P>: Unpin,



impl<'a, P> Unpin for wasmtime_environ::__core::str::RSplit<'a, P>
where SplitInternal<'a, P>: Unpin,



impl<'a, P> Unpin for wasmtime_environ::__core::str::RSplitN<'a, P>
where SplitNInternal<'a, P>: Unpin,



impl<'a, P> Unpin for RSplitTerminator<'a, P>
where SplitInternal<'a, P>: Unpin,



impl<'a, P> Unpin for wasmtime_environ::__core::str::Split<'a, P>
where SplitInternal<'a, P>: Unpin,



impl<'a, P> Unpin for wasmtime_environ::__core::str::SplitInclusive<'a, P>
where SplitInternal<'a, P>: Unpin,



impl<'a, P> Unpin for wasmtime_environ::__core::str::SplitN<'a, P>
where SplitNInternal<'a, P>: Unpin,



impl<'a, P> Unpin for SplitTerminator<'a, P>
where SplitInternal<'a, P>: Unpin,



impl<'a, T, A> Unpin for wasmtime_environ::prelude::vec::Drain<'a, T, A>
where Iter<'a, T>: Unpin, NonNull<Vec<T, A>>: Unpin,



impl<'a, T, A> Unpin for PeekMut<'a, T, A>
where &'a mut Vec<T, A>: Unpin,



impl<'a, T, F, A> Unpin for wasmtime_environ::prelude::vec::ExtractIf<'a, T, F, A>
where &'a mut Vec<T, A>: Unpin, F: Unpin,



impl<'a, T, P> Unpin for ChunkBy<'a, T, P>
where &'a [T]: Unpin, P: Unpin,



impl<'a, T, P> Unpin for ChunkByMut<'a, T, P>
where &'a mut [T]: Unpin, P: Unpin,



impl<'a, T, P> Unpin for wasmtime_environ::__core::slice::RSplit<'a, T, P>
where Split<'a, T, P>: Unpin,



impl<'a, T, P> Unpin for RSplitMut<'a, T, P>
where SplitMut<'a, T, P>: Unpin,



impl<'a, T, P> Unpin for wasmtime_environ::__core::slice::RSplitN<'a, T, P>
where GenericSplitN<RSplit<'a, T, P>>: Unpin,



impl<'a, T, P> Unpin for RSplitNMut<'a, T, P>
where GenericSplitN<RSplitMut<'a, T, P>>: Unpin,



impl<'a, T, P> Unpin for wasmtime_environ::__core::slice::Split<'a, T, P>
where &'a [T]: Unpin, P: Unpin,



impl<'a, T, P> Unpin for wasmtime_environ::__core::slice::SplitInclusive<'a, T, P>
where &'a [T]: Unpin, P: Unpin,



impl<'a, T, P> Unpin for SplitInclusiveMut<'a, T, P>
where &'a mut [T]: Unpin, P: Unpin,



impl<'a, T, P> Unpin for SplitMut<'a, T, P>
where &'a mut [T]: Unpin, P: Unpin,



impl<'a, T, P> Unpin for wasmtime_environ::__core::slice::SplitN<'a, T, P>
where GenericSplitN<Split<'a, T, P>>: Unpin,



impl<'a, T, P> Unpin for SplitNMut<'a, T, P>
where GenericSplitN<SplitMut<'a, T, P>>: Unpin,



impl<'a, T, S, A> Unpin for Difference<'a, T, S, A>
where Iter<'a, T>: Unpin, &'a HashSet<T, S, A>: Unpin,



impl<'a, T, S, A> Unpin for wasmtime_environ::collections::oom_abort::hash_set::Entry<'a, T, S, A>
where OccupiedEntry<'a, T, S, A>: Unpin, VacantEntry<'a, T, S, A>: Unpin,



impl<'a, T, S, A> Unpin for Intersection<'a, T, S, A>
where Iter<'a, T>: Unpin, &'a HashSet<T, S, A>: Unpin,



impl<'a, T, S, A> Unpin for wasmtime_environ::collections::oom_abort::hash_set::OccupiedEntry<'a, T, S, A>
where OccupiedEntry<'a, T, S, A>: Unpin,



impl<'a, T, S, A> Unpin for SymmetricDifference<'a, T, S, A>
where Chain<Difference<'a, T, S, A>, Difference<'a, T, S, A>>: Unpin,



impl<'a, T, S, A> Unpin for Union<'a, T, S, A>
where Chain<Iter<'a, T>, Difference<'a, T, S, A>>: Unpin,



impl<'a, T, S, A> Unpin for wasmtime_environ::collections::oom_abort::hash_set::VacantEntry<'a, T, S, A>
where VacantEntry<'a, T, S, A>: Unpin,



impl<'a, T, const N: usize> Unpin for ArrayWindows<'a, T, N>
where &'a [T]: Unpin,



impl<'a, T> Unpin for BorrowedCursor<'a, T>



impl<'a, T> Unpin for Chunks<'a, T>
where &'a [T]: Unpin,



impl<'a, T> Unpin for ChunksExact<'a, T>
where &'a [T]: Unpin,



impl<'a, T> Unpin for ChunksExactMut<'a, T>



impl<'a, T> Unpin for ChunksMut<'a, T>



impl<'a, T> Unpin for wasmtime_environ::__core::slice::Iter<'a, T>



impl<'a, T> Unpin for wasmtime_environ::__core::result::Iter<'a, T>
where Option<&'a T>: Unpin,



impl<'a, T> Unpin for wasmtime_environ::__core::slice::IterMut<'a, T>



impl<'a, T> Unpin for wasmtime_environ::__core::result::IterMut<'a, T>



impl<'a, T> Unpin for RChunks<'a, T>
where &'a [T]: Unpin,



impl<'a, T> Unpin for RChunksExact<'a, T>
where &'a [T]: Unpin,



impl<'a, T> Unpin for RChunksExactMut<'a, T>
where *mut [T]: Unpin, &'a mut [T]: Unpin,



impl<'a, T> Unpin for RChunksMut<'a, T>



impl<'a, T> Unpin for Windows<'a, T>
where &'a [T]: Unpin,



impl<'a, const N: usize> Unpin for CharArraySearcher<'a, N>
where <MultiCharEqPattern<[char; N]> as Pattern>::Searcher<'a>: Unpin,



impl<'a> !Unpin for Request<'a>



impl<'a> Unpin for AbstractInstantiations<'a>



impl<'a> Unpin for Arguments<'a>



impl<'a> Unpin for wasmtime_environ::__core::ffi::c_str::Bytes<'a>



impl<'a> Unpin for wasmtime_environ::__core::str::Bytes<'a>



impl<'a> Unpin for wasmtime_environ::error::Chain<'a>



impl<'a> Unpin for CharIndices<'a>



impl<'a> Unpin for CharSearcher<'a>



impl<'a> Unpin for Chars<'a>



impl<'a> Unpin for Context<'a>



impl<'a> Unpin for ContextBuilder<'a>



impl<'a> Unpin for DebugInfoData<'a>



impl<'a> Unpin for EncodeUtf16<'a>



impl<'a> Unpin for EscapeAscii<'a>



impl<'a> Unpin for wasmtime_environ::__core::str::EscapeDebug<'a>



impl<'a> Unpin for wasmtime_environ::__core::str::EscapeDefault<'a>



impl<'a> Unpin for wasmtime_environ::__core::str::EscapeUnicode<'a>



impl<'a> Unpin for FlagValue<'a>



impl<'a> Unpin for FlatTypes<'a>



impl<'a> Unpin for Formatter<'a>



impl<'a> Unpin for FrameStateSlot<'a>



impl<'a> Unpin for FrameTable<'a>



impl<'a> Unpin for FrameTableBreakpointData<'a>



impl<'a> Unpin for FunctionBodyData<'a>



impl<'a> Unpin for IoSlice<'a>



impl<'a> Unpin for IoSliceMut<'a>



impl<'a> Unpin for Lines<'a>



impl<'a> Unpin for LinesAny<'a>



impl<'a> Unpin for Location<'a>



impl<'a> Unpin for MemoryInit<'a>



impl<'a> Unpin for MemoryInitializer<'a>



impl<'a> Unpin for MemoryTunables<'a>



impl<'a> Unpin for wasmtime_environ::fact::Module<'a>



impl<'a> Unpin for NameSection<'a>



impl<'a> Unpin for ObjectBuilder<'a>



impl<'a> Unpin for PanicInfo<'a>



impl<'a> Unpin for PanicMessage<'a>



impl<'a> Unpin for PhantomContravariantLifetime<'a>



impl<'a> Unpin for PhantomCovariantLifetime<'a>



impl<'a> Unpin for PhantomInvariantLifetime<'a>



impl<'a> Unpin for Source<'a>



impl<'a> Unpin for SplitAsciiWhitespace<'a>



impl<'a> Unpin for SplitWhitespace<'a>



impl<'a> Unpin for StackMap<'a>



impl<'a> Unpin for Utf8Chunk<'a>



impl<'a> Unpin for Utf8Chunks<'a>



impl<'a> Unpin for Utf8Pattern<'a>



impl<'a> Unpin for VaList<'a>



impl<'b, T> Unpin for Ref<'b, T>
where NonNull<T>: Unpin, T: ?Sized,



impl<'b, T> Unpin for RefMut<'b, T>



impl<'data, T> Unpin for BorrowedBuf<'data, T>
where &'data mut [MaybeUninit<T>]: Unpin,



impl<'data> Unpin for ModuleTranslation<'data>



impl<A, B> Unpin for wasmtime_environ::__core::iter::Chain<A, B>
where Option<A>: Unpin, Option<B>: Unpin,



impl<A, B> Unpin for Zip<A, B>
where A: Unpin, B: Unpin,



impl<A> Unpin for wasmtime_environ::__core::option::IntoIter<A>
where Item<A>: Unpin,



impl<A> Unpin for OptionFlatten<A>
where Option<A>: Unpin,



impl<A> Unpin for RangeFromIter<A>
where A: Unpin,



impl<A> Unpin for RangeInclusiveIter<A>



impl<A> Unpin for RangeIter<A>
where Range<A>: Unpin,



impl<A> Unpin for wasmtime_environ::__core::iter::Repeat<A>
where A: Unpin,



impl<A> Unpin for RepeatN<A>
where Option<RepeatNInner<A>>: Unpin,



impl<B, C> Unpin for ControlFlow<B, C>
where C: Unpin, B: Unpin,



impl<E> Unpin for IterEntityRange<E>
where PhantomData<E>: Unpin,



impl<F> Unpin for wasmtime_environ::__core::iter::FromFn<F>
where F: Unpin,



impl<F> Unpin for wasmtime_environ::__core::fmt::FromFn<F>
where F: Unpin,



impl<F> Unpin for OnceWith<F>
where Option<F>: Unpin,



impl<F> Unpin for RepeatWith<F>
where F: Unpin,



impl<G, F> Unpin for FilterNodes<G, F>
where G: Unpin, F: Unpin,



impl<G> Unpin for FromCoroutine<G>
where G: Unpin,



impl<H> Unpin for BuildHasherDefault<H>
where PhantomData<fn() -> H>: Unpin,



impl<I, F, const N: usize> Unpin for MapWindows<I, F, N>
where F: Unpin, MapWindowsInner<I, N>: Unpin,



impl<I, F> Unpin for FilterMap<I, F>
where I: Unpin, F: Unpin,



impl<I, F> Unpin for Inspect<I, F>
where I: Unpin, F: Unpin,



impl<I, F> Unpin for Map<I, F>
where I: Unpin, F: Unpin,



impl<I, G> Unpin for IntersperseWith<I, G>
where G: Unpin, Option<<I as Iterator>::Item>: Unpin, I: Unpin,



impl<I, P> Unpin for Filter<I, P>
where I: Unpin, P: Unpin,



impl<I, P> Unpin for MapWhile<I, P>
where I: Unpin, P: Unpin,



impl<I, P> Unpin for SkipWhile<I, P>
where I: Unpin, P: Unpin,



impl<I, P> Unpin for TakeWhile<I, P>
where I: Unpin, P: Unpin,



impl<I, St, F> Unpin for Scan<I, St, F>
where I: Unpin, F: Unpin, St: Unpin,



impl<I, U, F> Unpin for FlatMap<I, U, F>
where FlattenCompat<Map<I, F>, <U as IntoIterator>::IntoIter>: Unpin,



impl<I, const N: usize> Unpin for ArrayChunks<I, N>
where I: Unpin, Option<IntoIter<<I as Iterator>::Item, N>>: Unpin,



impl<I> Unpin for ArrayOffsets<I>
where PhantomData<I>: Unpin,



impl<I> Unpin for Cloned<I>
where I: Unpin,



impl<I> Unpin for Copied<I>
where I: Unpin,



impl<I> Unpin for Cycle<I>
where I: Unpin,



impl<I> Unpin for DecodeUtf16<I>
where I: Unpin,



impl<I> Unpin for Enumerate<I>
where I: Unpin,



impl<I> Unpin for Flatten<I>
where FlattenCompat<I, <<I as Iterator>::Item as IntoIterator>::IntoIter>: Unpin,



impl<I> Unpin for Fuse<I>
where Option<I>: Unpin,



impl<I> Unpin for Intersperse<I>
where <I as Iterator>::Item: Sized + Unpin, Option<<I as Iterator>::Item>: Unpin, I: Unpin,



impl<I> Unpin for Peekable<I>
where I: Unpin, Option<Option<<I as Iterator>::Item>>: Unpin,



impl<I> Unpin for Skip<I>
where I: Unpin,



impl<I> Unpin for StepBy<I>
where I: Unpin,



impl<I> Unpin for wasmtime_environ::__core::iter::Take<I>
where I: Unpin,



impl<Idx> Unpin for Clamp<Idx>
where Idx: Unpin,



impl<Idx> Unpin for wasmtime_environ::__core::ops::Range<Idx>
where Idx: Unpin,



impl<Idx> Unpin for wasmtime_environ::__core::range::Range<Idx>
where Idx: Unpin,



impl<Idx> Unpin for wasmtime_environ::__core::ops::RangeFrom<Idx>
where Idx: Unpin,



impl<Idx> Unpin for wasmtime_environ::__core::range::RangeFrom<Idx>
where Idx: Unpin,



impl<Idx> Unpin for wasmtime_environ::__core::ops::RangeInclusive<Idx>
where Idx: Unpin,



impl<Idx> Unpin for wasmtime_environ::__core::range::RangeInclusive<Idx>
where Idx: Unpin,



impl<Idx> Unpin for RangeTo<Idx>
where Idx: Unpin,



impl<Idx> Unpin for wasmtime_environ::__core::ops::RangeToInclusive<Idx>
where Idx: Unpin,



impl<Idx> Unpin for wasmtime_environ::__core::range::RangeToInclusive<Idx>
where Idx: Unpin,



impl<K, A> Unpin for wasmtime_environ::collections::oom_abort::hash_set::IntoIter<K, A>
where IntoIter<K, A>: Unpin,



impl<K, V, A> Unpin for wasmtime_environ::collections::oom_abort::hash_map::IntoIter<K, V, A>
where IntoIter<K, V, A>: Unpin,



impl<K, V, A> Unpin for IntoKeys<K, V, A>
where IntoIter<K, V, A>: Unpin,



impl<K, V, A> Unpin for IntoValues<K, V, A>
where IntoIter<K, V, A>: Unpin,



impl<K, V, S, A> Unpin for HashMap<K, V, S, A>
where HashMap<K, V, S, A>: Unpin,



impl<K, V, S> Unpin for TryHashMap<K, V, S>
where HashMap<K, V, S>: Unpin,



impl<K, V, S> Unpin for TryIndexMap<K, V, S>
where IndexMap<K, V, S>: Unpin,



impl<K, V> Unpin for BTreeMapIntoIter<K, V>
where MapIntoIter<K, Id>: Unpin, Slab<V>: Unpin,



impl<K, V> Unpin for BoxedSlice<K, V>
where Box<[V]>: Unpin, PhantomData<K>: Unpin,



impl<K, V> Unpin for IndexMap<K, V>
where IndexMap<K, V, RandomState>: Unpin,



impl<K, V> Unpin for Intern<K, V>
where HashMap<V, K>: Unpin, PrimaryMap<K, V>: Unpin,



impl<K, V> Unpin for wasmtime_environ::IntoIter<K, V>



impl<K, V> Unpin for NameMap<K, V>
where TryIndexMap<K, V>: Unpin, TryIndexMap<K, (K, TryVersion)>: Unpin,



impl<K, V> Unpin for PrimaryMap<K, V>
where Vec<V>: Unpin, PhantomData<K>: Unpin,



impl<K, V> Unpin for SecondaryMap<K, V>
where Vec<V>: Unpin, V: Unpin, PhantomData<K>: Unpin,



impl<K, V> Unpin for SparseMap<K, V>
where SecondaryMap<K, u32>: Unpin, Vec<V>: Unpin,



impl<K, V> Unpin for TryBTreeMap<K, V>
where Slab<V>: Unpin, MapForest<K, Id>: Unpin, Map<K, Id>: Unpin,



impl<K, V> Unpin for TryPrimaryMap<K, V>
where PrimaryMap<K, V>: Unpin,



impl<K, V> Unpin for TrySecondaryMap<K, V>
where SecondaryMap<K, V>: Unpin,



impl<K> Unpin for EntitySet<K>
where PhantomData<K>: Unpin,



impl<K> Unpin for wasmtime_environ::Keys<K>
where PhantomData<K>: Unpin,



impl<K> Unpin for TryEntitySet<K>
where EntitySet<K>: Unpin,



impl<Node> Unpin for Dfs<Node>
where Vec<DfsEvent<Node>>: Unpin,



impl<Node> Unpin for DfsEvent<Node>
where Node: Unpin,



impl<Node> Unpin for EntityGraph<Node>
where SecondaryMap<Node, Range<u32>>: Unpin, Vec<Node>: Unpin,



impl<Node> Unpin for StronglyConnectedComponents<Node>
where Vec<Node>: Unpin,



impl<P> Unpin for MaybeDangling<P>
where P: Unpin + ?Sized,



impl<P> Unpin for VMCommonStackInformation<P>
where P: Unpin,



impl<P> Unpin for VMComponentContext<P>
where P: Unpin,



impl<P> Unpin for VMComponentOffsets<P>
where P: Unpin,



impl<P> Unpin for VMContRef<P>
where P: Unpin,



impl<P> Unpin for VMContext<P>
where P: Unpin,



impl<P> Unpin for VMCopyingHeapData<P>
where P: Unpin,



impl<P> Unpin for VMDeferredThread<P>
where P: Unpin,



impl<P> Unpin for VMDrcHeapData<P>
where P: Unpin,



impl<P> Unpin for VMFuncRef<P>
where P: Unpin,



impl<P> Unpin for VMFunctionImport<P>
where P: Unpin,



impl<P> Unpin for VMGlobalDefinition<P>
where P: Unpin,



impl<P> Unpin for VMGlobalImport<P>
where P: Unpin,



impl<P> Unpin for VMHostArray<P>
where P: Unpin,



impl<P> Unpin for VMLazyThread<P>
where P: Unpin,



impl<P> Unpin for VMMemoryDefinition<P>
where P: Unpin,



impl<P> Unpin for VMMemoryImport<P>
where P: Unpin,



impl<P> Unpin for VMNullHeapData<P>
where P: Unpin,



impl<P> Unpin for VMOffsets<P>
where P: Unpin,



impl<P> Unpin for VMOffsetsFields<P>
where P: Unpin,



impl<P> Unpin for VMStackLimits<P>
where P: Unpin,



impl<P> Unpin for VMStoreContext<P>
where P: Unpin,



impl<P> Unpin for VMTableDefinition<P>
where P: Unpin,



impl<P> Unpin for VMTableImport<P>
where P: Unpin,



impl<P> Unpin for VMTagDefinition<P>
where P: Unpin,



impl<P> Unpin for VMTagImport<P>
where P: Unpin,



impl<Ptr> Unpin for Pin<Ptr>
where Ptr: Unpin,



impl<T, A> Unpin for wasmtime_environ::prelude::vec::IntoIter<T, A>



impl<T, A> Unpin for Vec<T, A>
where RawVec<T, A>: Unpin,



impl<T, E> Unpin for Result<T, E>
where T: Unpin, E: Unpin,



impl<T, F> Unpin for DropGuard<T, F>



impl<T, F> Unpin for LazyCell<T, F>
where UnsafeCell<State<T, F>>: Unpin,



impl<T, F> Unpin for Successors<T, F>
where Option<T>: Unpin, F: Unpin,



impl<T, F> Unpin for Undo<T, F>



impl<T, S, A> Unpin for HashSet<T, S, A>
where HashSet<T, S, A>: Unpin,



impl<T, S> Unpin for TryHashSet<T, S>
where HashSet<T, S>: Unpin,



impl<T, U> Unpin for wasmtime_environ::__core::io::Chain<T, U>
where T: Unpin, U: Unpin,



impl<T, const N: usize> Unpin for wasmtime_environ::__core::array::IntoIter<T, N>
where ManuallyDrop<PolymorphicIter<[MaybeUninit<T>; N]>>: Unpin,



impl<T, const N: usize> Unpin for Mask<T, N>
where Simd<T, N>: Unpin,



impl<T, const N: usize> Unpin for Simd<T, N>
where [T; N]: Unpin,



impl<T, const VARIANT: u32, const FIELD: u32> Unpin for FieldRepresentingType<T, VARIANT, FIELD>
where PhantomData<fn(T) -> T>: Unpin, T: ?Sized,



impl<T> Unpin for AssertUnwindSafe<T>
where T: Unpin,



impl<T> Unpin for Atomic<T>



impl<T> Unpin for Bound<T>
where T: Unpin,



impl<T> Unpin for Cell<T>
where UnsafeCell<T>: Unpin, T: ?Sized,



impl<T> Unpin for Complex<T>
where T: Unpin,



impl<T> Unpin for wasmtime_environ::component::CoreExport<T>
where ExportItem<T>: Unpin,



impl<T> Unpin for wasmtime_environ::component::dfg::CoreExport<T>
where ExportItem<T>: Unpin,



impl<T> Unpin for CovariantUnsafeCell<T>
where UnsafeCell<T>: Unpin, T: ?Sized,



impl<T> Unpin for Cursor<T>
where T: Unpin,



impl<T> Unpin for Discriminant<T>



impl<T> Unpin for wasmtime_environ::__core::iter::Empty<T>
where PhantomData<fn() -> T>: Unpin,



impl<T> Unpin for EntityList<T>
where PhantomData<T>: Unpin,



impl<T> Unpin for ExportItem<T>
where T: Unpin,



impl<T> Unpin for IndexSet<T>
where IndexMap<T, ()>: Unpin,



impl<T> Unpin for wasmtime_environ::__core::result::IntoIter<T>
where Option<T>: Unpin,



impl<T> Unpin for KnownEntity<T>
where T: Unpin,



impl<T> Unpin for ListPool<T>
where Vec<T>: Unpin,



impl<T> Unpin for ManuallyDrop<T>
where MaybeDangling<T>: Unpin, T: ?Sized,



impl<T> Unpin for MaybeUninit<T>
where ManuallyDrop<T>: Unpin,



impl<T> Unpin for NonNull<T>
where *const T is !null: Unpin, T: ?Sized,



impl<T> Unpin for NumBuffer<T>



impl<T> Unpin for Once<T>
where IntoIter<T>: Unpin,



impl<T> Unpin for OnceCell<T>
where UnsafeCell<Option<T>>: Unpin,



impl<T> Unpin for Option<T>
where T: Unpin,



impl<T> Unpin for PackedOption<T>
where T: Unpin,



impl<T> Unpin for Pending<T>
where PhantomData<fn() -> T>: Unpin,



impl<T> Unpin for PhantomContravariant<T>
where PhantomData<fn(T)>: Unpin, T: ?Sized,



impl<T> Unpin for PhantomCovariant<T>
where PhantomData<fn() -> T>: Unpin, T: ?Sized,



impl<T> Unpin for PhantomData<T>
where T: ?Sized,



impl<T> Unpin for PhantomInvariant<T>
where PhantomData<fn(T) -> T>: Unpin, T: ?Sized,



impl<T> Unpin for Poll<T>
where T: Unpin,



impl<T> Unpin for RefCell<T>
where UnsafeCell<T>: Unpin, T: ?Sized,



impl<T> Unpin for Rev<T>
where T: Unpin,



impl<T> Unpin for Reverse<T>
where T: Unpin,



impl<T> Unpin for Saturating<T>
where T: Unpin,



impl<T> Unpin for ScopeVec<T>
where RefCell<Vec<Box<[T]>>>: Unpin,



impl<T> Unpin for SyncUnsafeCell<T>
where UnsafeCell<T>: Unpin, T: ?Sized,



impl<T> Unpin for SyncView<T>
where T: Unpin + ?Sized,



impl<T> Unpin for wasmtime_environ::__core::io::Take<T>
where T: Unpin,



impl<T> Unpin for TraitImpl<T>
where DynMetadata<T>: Unpin, T: ?Sized,



impl<T> Unpin for TryVec<T>
where Vec<T>: Unpin,



impl<T> Unpin for UnsafeCell<T>
where T: Unpin + ?Sized,



impl<T> Unpin for Wrapping<T>
where T: Unpin,



impl<T> Unpin for Yeet<T>
where T: Unpin,



impl<Y, R> Unpin for CoroutineState<Y, R>
where Y: Unpin, R: Unpin,