Index

Trait Index 

1.6.0 (const: unstable) · Source
pub trait Index<Idx>
where Idx: ?Sized,
{ type Output: ?Sized; // Required method fn index(&self, index: Idx) -> &Self::Output; }
Used for indexing operations (container[index]) in immutable contexts.

container[index] is actually syntactic sugar for *container.index(index), but only when used as an immutable value. If a mutable value is requested, IndexMut is used instead. This allows nice things such as let value = v[index] if the type of value implements Copy.

Examples

The following example implements Index on a read-only NucleotideCount container, enabling individual counts to be retrieved with index syntax.

use std::ops::Index;

enum Nucleotide {
    A,
    C,
    G,
    T,
}

struct NucleotideCount {
    a: usize,
    c: usize,
    g: usize,
    t: usize,
}

impl Index<Nucleotide> for NucleotideCount {
    type Output = usize;

    fn index(&self, nucleotide: Nucleotide) -> &Self::Output {
        match nucleotide {
            Nucleotide::A => &self.a,
            Nucleotide::C => &self.c,
            Nucleotide::G => &self.g,
            Nucleotide::T => &self.t,
        }
    }
}

let nucleotide_count = NucleotideCount {a: 14, c: 9, g: 10, t: 12};
assert_eq!(nucleotide_count[Nucleotide::A], 14);
assert_eq!(nucleotide_count[Nucleotide::C], 9);
assert_eq!(nucleotide_count[Nucleotide::G], 10);
assert_eq!(nucleotide_count[Nucleotide::T], 12);

Required Associated Types

1.0.0 (const: unstable) · Source

type Output: ?Sized

The returned type after indexing.

Required Methods

1.0.0 (const: unstable) · Source

fn index(&self, index: Idx) -> &Self::Output

Performs the indexing (container[index]) operation.

Panics

May panic if the index is out of bounds.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Index<&Atom> for StringPool

Source

impl Index<Atom> for StringPool

Source

impl Index<ModuleInternedTypeIndex> for ModuleTypes

Source

impl Index<Range<usize>> for ByteString

Source

impl Index<RangeFrom<usize>> for ByteString

1.47.0 · Source

impl Index<RangeFrom<usize>> for CStr

1.96.0 · Source

impl Index<RangeFrom<usize>> for CStr

Source

impl Index<RangeFull> for ByteString

1.7.0 · Source

impl Index<RangeFull> for CString

1.0.0 · Source

impl Index<RangeFull> for OsString

Source

impl Index<RangeInclusive<usize>> for ByteString

Source

impl Index<RangeTo<usize>> for ByteString

Source

impl Index<RangeToInclusive<usize>> for ByteString

Source

impl Index<TypeComponentIndex> for ComponentTypes

Source

impl Index<TypeComponentIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeComponentInstanceIndex> for ComponentTypes

Source

impl Index<TypeComponentInstanceIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeComponentLocalErrorContextTableIndex> for ComponentTypes

Source

impl Index<TypeComponentLocalErrorContextTableIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeEnumIndex> for ComponentTypes

Source

impl Index<TypeEnumIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeFixedLengthListIndex> for ComponentTypes

Source

impl Index<TypeFixedLengthListIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeFlagsIndex> for ComponentTypes

Source

impl Index<TypeFlagsIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeFuncIndex> for ComponentTypes

Source

impl Index<TypeFuncIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeFutureIndex> for ComponentTypes

Source

impl Index<TypeFutureIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeFutureTableIndex> for ComponentTypes

Source

impl Index<TypeFutureTableIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeListIndex> for ComponentTypes

Source

impl Index<TypeListIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeMapIndex> for ComponentTypes

Source

impl Index<TypeMapIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeModuleIndex> for ComponentTypes

Source

impl Index<TypeModuleIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeOptionIndex> for ComponentTypes

Source

impl Index<TypeOptionIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeRecordIndex> for ComponentTypes

Source

impl Index<TypeRecordIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeResourceTableIndex> for ComponentTypes

Source

impl Index<TypeResourceTableIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeResultIndex> for ComponentTypes

Source

impl Index<TypeResultIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeStreamIndex> for ComponentTypes

Source

impl Index<TypeStreamIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeStreamTableIndex> for ComponentTypes

Source

impl Index<TypeStreamTableIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeTupleIndex> for ComponentTypes

Source

impl Index<TypeTupleIndex> for ComponentTypesBuilder

Available on crate feature compile only.
Source

impl Index<TypeVariantIndex> for ComponentTypes

Source

impl Index<TypeVariantIndex> for ComponentTypesBuilder

Available on crate feature compile only.


impl Index<usize> for AllocVec



type Output = u8

Source

impl Index<usize> for ByteString



impl Index<usize> for Slice<'_>



type Output = u8



impl<A, I> Index<I> for SmallVec<A>
where A: Array, I: SliceIndex<[<A as Array>::Item]>,



type Output = <I as SliceIndex<[<A as Array>::Item]>>::Output

Source

impl<I, T, const N: usize> Index<I> for Simd<T, N>
where T: SimdElement, I: SliceIndex<[T]>,

Source

impl<I> Index<I> for ByteStr
where I: SliceIndex<ByteStr>,

1.0.0 · Source

impl<I> Index<I> for String
where I: SliceIndex<str>,

1.0.0 (const: unstable) · Source

impl<I> Index<I> for str
where I: SliceIndex<str>,

1.0.0 · Source

impl<K, Q, V, A> Index<&Q> for BTreeMap<K, V, A>
where A: Allocator + Clone, K: Borrow<Q> + Ord, Q: Ord + ?Sized,

1.0.0 · Source

impl<K, Q, V, S, A> Index<&Q> for wasmtime_environ::collections::oom_abort::HashMap<K, V, S, A>
where K: Eq + Hash + Borrow<Q>, Q: Eq + Hash + ?Sized, S: BuildHasher, A: Allocator,



impl<K, Q, V, S, A> Index<&Q> for HashMap<K, V, S, A>
where K: Eq + Hash, Q: Hash + Equivalent<K> + ?Sized, S: BuildHasher, A: Allocator,



type Output = V



impl<K, Q, V, S, A> Index<&Q> for HashMap<K, V, S, A>
where K: Eq + Hash, Q: Hash + Equivalent<K> + ?Sized, S: BuildHasher, A: Allocator,



type Output = V



impl<K, Q, V> Index<&Q> for wasmtime_environ::prelude::IndexMap<K, V>
where K: Borrow<Q> + Hash + Eq + Ord, Q: Hash + Eq + Ord + ?Sized,



type Output = V



impl<K, Q, V> Index<&Q> for Map<K, V>
where K: Borrow<Q> + Hash + Eq + Ord, Q: Hash + Eq + Ord + ?Sized,



type Output = V



impl<K, V, Q, S> Index<&Q> for IndexMap<K, V, S>
where Q: Hash + Equivalent<K> + ?Sized, S: BuildHasher,

Access [IndexMap] values corresponding to a key.

Examples

use indexmap::IndexMap;

let mut map = IndexMap::new();
for word in "Lorem ipsum dolor sit amet".split_whitespace() {
    map.insert(word.to_lowercase(), word.to_uppercase());
}
assert_eq!(map["lorem"], "LOREM");
assert_eq!(map["ipsum"], "IPSUM");
use indexmap::IndexMap;

let mut map = IndexMap::new();
map.insert("foo", 1);
println!("{:?}", map["bar"]); // panics!


type Output = V

Source

impl<K, V, Q, S> Index<&Q> for TryIndexMap<K, V, S>
where Q: ?Sized + Hash + Eq, K: Borrow<Q>, S: BuildHasher,



impl<K, V, S> Index<(Bound<usize>, Bound<usize>)> for IndexMap<K, V, S>



type Output = Slice<K, V>



impl<K, V, S> Index<Range<usize>> for IndexMap<K, V, S>



type Output = Slice<K, V>



impl<K, V, S> Index<RangeFrom<usize>> for IndexMap<K, V, S>



type Output = Slice<K, V>



impl<K, V, S> Index<RangeFull> for IndexMap<K, V, S>



type Output = Slice<K, V>



impl<K, V, S> Index<RangeInclusive<usize>> for IndexMap<K, V, S>



type Output = Slice<K, V>



impl<K, V, S> Index<RangeTo<usize>> for IndexMap<K, V, S>



type Output = Slice<K, V>



impl<K, V, S> Index<RangeToInclusive<usize>> for IndexMap<K, V, S>



type Output = Slice<K, V>



impl<K, V, S> Index<usize> for IndexMap<K, V, S>

Access [IndexMap] values at indexed positions.

See Index<usize> for Keys to access a map’s keys instead.

Examples

use indexmap::IndexMap;

let mut map = IndexMap::new();
for word in "Lorem ipsum dolor sit amet".split_whitespace() {
    map.insert(word.to_lowercase(), word.to_uppercase());
}
assert_eq!(map[0], "LOREM");
assert_eq!(map[1], "IPSUM");
map.reverse();
assert_eq!(map[0], "AMET");
assert_eq!(map[1], "SIT");
map.sort_keys();
assert_eq!(map[0], "AMET");
assert_eq!(map[1], "DOLOR");
use indexmap::IndexMap;

let mut map = IndexMap::new();
map.insert("foo", 1);
println!("{:?}", map[10]); // panics!


type Output = V

Source

impl<K, V, S> Index<usize> for TryIndexMap<K, V, S>



impl<K, V> Index<(Bound<usize>, Bound<usize>)> for Slice<K, V>



type Output = Slice<K, V>



impl<K, V> Index<K> for BoxedSlice<K, V>
where K: EntityRef,

Immutable indexing into a BoxedSlice. The indexed value must be in the map.



type Output = V



impl<K, V> Index<K> for PrimaryMap<K, V>
where K: EntityRef,

Immutable indexing into an PrimaryMap. The indexed value must be in the map.



type Output = V



impl<K, V> Index<K> for SecondaryMap<K, V>
where K: EntityRef, V: Clone,

Immutable indexing into an SecondaryMap.

All keys are permitted. Untouched entries have the default value.



type Output = V

Source

impl<K, V> Index<K> for TryPrimaryMap<K, V>
where K: EntityRef,

Source

impl<K, V> Index<K> for TrySecondaryMap<K, V>
where K: EntityRef, V: Clone,



impl<K, V> Index<Range<usize>> for Slice<K, V>



type Output = Slice<K, V>



impl<K, V> Index<RangeFrom<usize>> for Slice<K, V>



type Output = Slice<K, V>



impl<K, V> Index<RangeFull> for Slice<K, V>



type Output = Slice<K, V>



impl<K, V> Index<RangeInclusive<usize>> for Slice<K, V>



type Output = Slice<K, V>



impl<K, V> Index<RangeTo<usize>> for Slice<K, V>



type Output = Slice<K, V>



impl<K, V> Index<RangeToInclusive<usize>> for Slice<K, V>



type Output = Slice<K, V>



impl<K, V> Index<usize> for wasmtime_environ::prelude::IndexMap<K, V>
where K: Hash + Eq + Ord,



type Output = V



impl<K, V> Index<usize> for Keys<'_, K, V>

Access [IndexMap] keys at indexed positions.

While Index<usize> for IndexMap accesses a map’s values, indexing through [IndexMap::keys] offers an alternative to access a map’s keys instead.

Since Keys is also an iterator, consuming items from the iterator will offset the effective indices. Similarly, if Keys is obtained from [Slice::keys], indices will be interpreted relative to the position of that slice.

Examples

use indexmap::IndexMap;

let mut map = IndexMap::new();
for word in "Lorem ipsum dolor sit amet".split_whitespace() {
    map.insert(word.to_lowercase(), word.to_uppercase());
}

assert_eq!(map[0], "LOREM");
assert_eq!(map.keys()[0], "lorem");
assert_eq!(map[1], "IPSUM");
assert_eq!(map.keys()[1], "ipsum");

map.reverse();
assert_eq!(map.keys()[0], "amet");
assert_eq!(map.keys()[1], "sit");

map.sort_keys();
assert_eq!(map.keys()[0], "amet");
assert_eq!(map.keys()[1], "dolor");

// Advancing the iterator will offset the indexing
let mut keys = map.keys();
assert_eq!(keys[0], "amet");
assert_eq!(keys.next().map(|s| &**s), Some("amet"));
assert_eq!(keys[0], "dolor");
assert_eq!(keys[1], "ipsum");

// Slices may have an offset as well
let slice = &map[2..];
assert_eq!(slice[0], "IPSUM");
assert_eq!(slice.keys()[0], "ipsum");
use indexmap::IndexMap;

let mut map = IndexMap::new();
map.insert("foo", 1);
println!("{:?}", map.keys()[10]); // panics!


type Output = K



impl<K, V> Index<usize> for Slice<K, V>



type Output = V

Source

impl<K: EntityRef, V> Index<K> for Intern<K, V>

1.0.0 · Source

impl<T, A> Index<usize> for VecDeque<T, A>
where A: Allocator,

1.0.0 (const: unstable) · Source

impl<T, I, A> Index<I> for Vec<T, A>
where I: SliceIndex<[T]>, A: Allocator,

1.50.0 (const: unstable) · Source

impl<T, I, const N: usize> Index<I> for [T; N]
where [T]: Index<I>,

Source

type Output = <[T] as Index<I>>::Output



impl<T, I> Index<I> for TryVec<T>
where I: SliceIndex<[T]>,



type Output = <I as SliceIndex<[T]>>::Output

1.0.0 (const: unstable) · Source

impl<T, I> Index<I> for [T]
where I: SliceIndex<[T]>,



impl<T, S> Index<(Bound<usize>, Bound<usize>)> for IndexSet<T, S>



type Output = Slice<T>



impl<T, S> Index<Range<usize>> for IndexSet<T, S>



type Output = Slice<T>



impl<T, S> Index<RangeFrom<usize>> for IndexSet<T, S>



type Output = Slice<T>



impl<T, S> Index<RangeFull> for IndexSet<T, S>



type Output = Slice<T>



impl<T, S> Index<RangeInclusive<usize>> for IndexSet<T, S>



type Output = Slice<T>



impl<T, S> Index<RangeTo<usize>> for IndexSet<T, S>



type Output = Slice<T>



impl<T, S> Index<RangeToInclusive<usize>> for IndexSet<T, S>



type Output = Slice<T>



impl<T, S> Index<usize> for IndexSet<T, S>

Access [IndexSet] values at indexed positions.

Examples

use indexmap::IndexSet;

let mut set = IndexSet::new();
for word in "Lorem ipsum dolor sit amet".split_whitespace() {
    set.insert(word.to_string());
}
assert_eq!(set[0], "Lorem");
assert_eq!(set[1], "ipsum");
set.reverse();
assert_eq!(set[0], "amet");
assert_eq!(set[1], "sit");
set.sort();
assert_eq!(set[0], "Lorem");
assert_eq!(set[1], "amet");
use indexmap::IndexSet;

let mut set = IndexSet::new();
set.insert("foo");
println!("{:?}", set[10]); // panics!


type Output = T



impl<T> Index<(Bound<usize>, Bound<usize>)> for Slice<T>



type Output = Slice<T>



impl<T> Index<Id> for Slab<T>



type Output = T



impl<T> Index<Range<usize>> for Slice<T>



type Output = Slice<T>



impl<T> Index<RangeFrom<usize>> for Slice<T>



type Output = Slice<T>



impl<T> Index<RangeFull> for Slice<T>



type Output = Slice<T>



impl<T> Index<RangeInclusive<usize>> for Slice<T>



type Output = Slice<T>



impl<T> Index<RangeTo<usize>> for Slice<T>



type Output = Slice<T>



impl<T> Index<RangeToInclusive<usize>> for Slice<T>



type Output = Slice<T>

Source

impl<T> Index<T> for ComponentTypes
where ModuleTypes: Index<T>,

Source

impl<T> Index<T> for ComponentTypesBuilder
where ModuleTypes: Index<T>,

Source

impl<T> Index<T> for ModuleTypesBuilder
where ModuleTypes: Index<T>,



impl<T> Index<T> for SubtypeArena<'_>
where T: TypeIdentifier,



type Output = <T as TypeIdentifier>::Data



impl<T> Index<T> for Types
where T: TypeIdentifier,



type Output = <T as TypeIdentifier>::Data



impl<T> Index<T> for TypesRef<'_>
where T: TypeIdentifier,



type Output = <T as TypeIdentifier>::Data



impl<T> Index<usize> for wasmtime_environ::prelude::IndexSet<T>
where T: Hash + Eq + Ord,



type Output = T



impl<T> Index<usize> for Slice<T>



type Output = T