PartialOrd

Trait PartialOrd 

1.55.0 (const: unstable) · Source
pub trait PartialOrd<Rhs = Self>: PartialEq<Rhs>
where Rhs: ?Sized,
{ // Required method fn partial_cmp(&self, other: &Rhs) -> Option<Ordering>; // Provided methods fn lt(&self, other: &Rhs) -> bool { ... } fn le(&self, other: &Rhs) -> bool { ... } fn gt(&self, other: &Rhs) -> bool { ... } fn ge(&self, other: &Rhs) -> bool { ... } }
Trait for types that form a partial order.

The lt, le, gt, and ge methods of this trait can be called using the <, <=, >, and >= operators, respectively.

This trait should only contain the comparison logic for a type if one plans on only implementing PartialOrd but not Ord. Otherwise the comparison logic should be in Ord and this trait implemented with Some(self.cmp(other)).

The methods of this trait must be consistent with each other and with those of PartialEq. The following conditions must hold:

  1. a == b if and only if partial_cmp(a, b) == Some(Equal).
  2. a < b if and only if partial_cmp(a, b) == Some(Less)
  3. a > b if and only if partial_cmp(a, b) == Some(Greater)
  4. a <= b if and only if a < b || a == b
  5. a >= b if and only if a > b || a == b
  6. a != b if and only if !(a == b).

Conditions 2–5 above are ensured by the default implementation. Condition 6 is already ensured by PartialEq.

If Ord is also implemented for Self and Rhs, it must also be consistent with partial_cmp (see the documentation of that trait for the exact requirements). It’s easy to accidentally make them disagree by deriving some of the traits and manually implementing others.

The comparison relations must satisfy the following conditions (for all a, b, c of type A, B, C):

  • Transitivity: if A: PartialOrd<B> and B: PartialOrd<C> and A: PartialOrd<C>, then a < b and b < c implies a < c. The same must hold for both == and >. This must also work for longer chains, such as when A: PartialOrd<B>, B: PartialOrd<C>, C: PartialOrd<D>, and A: PartialOrd<D> all exist.
  • Duality: if A: PartialOrd<B> and B: PartialOrd<A>, then a < b if and only if b > a.

Note that the B: PartialOrd<A> (dual) and A: PartialOrd<C> (transitive) impls are not forced to exist, but these requirements apply whenever they do exist.

Violating these requirements is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Cross-crate considerations

Upholding the requirements stated above can become tricky when one crate implements PartialOrd for a type of another crate (i.e., to allow comparing one of its own types with a type from the standard library). The recommendation is to never implement this trait for a foreign type. In other words, such a crate should do impl PartialOrd<ForeignType> for LocalType, but it should not do impl PartialOrd<LocalType> for ForeignType.

This avoids the problem of transitive chains that criss-cross crate boundaries: for all local types T, you may assume that no other crate will add impls that allow comparing T < U. In other words, if other crates add impls that allow building longer transitive chains U1 < ... < T < V1 < ..., then all the types that appear to the right of T must be types that the crate defining T already knows about. This rules out transitive chains where downstream crates can add new impls that “stitch together” comparisons of foreign types in ways that violate transitivity.

Not having such foreign impls also avoids forward compatibility issues where one crate adding more PartialOrd implementations can cause build failures in downstream crates.

Corollaries

The following corollaries follow from the above requirements:

  • irreflexivity of < and >: !(a < a), !(a > a)
  • transitivity of >: if a > b and b > c then a > c
  • duality of partial_cmp: partial_cmp(a, b) == partial_cmp(b, a).map(Ordering::reverse)

Strict and non-strict partial orders

The < and > operators behave according to a strict partial order. However, <= and >= do not behave according to a non-strict partial order. That is because mathematically, a non-strict partial order would require reflexivity, i.e. a <= a would need to be true for every a. This isn’t always the case for types that implement PartialOrd, for example:

let a = f64::NAN;
assert_eq!(a <= a, false);

Derivable

This trait can be used with #[derive].

When derived on structs, it will produce a lexicographic ordering based on the top-to-bottom declaration order of the struct’s members.

When derived on enums, variants are primarily ordered by their discriminants. Secondarily, they are ordered by their fields. By default, the discriminant is smallest for variants at the top, and largest for variants at the bottom. Here’s an example:

#[derive(PartialEq, PartialOrd)]
enum E {
    Top,
    Bottom,
}

assert!(E::Top < E::Bottom);

However, manually setting the discriminants can override this default behavior:

#[derive(PartialEq, PartialOrd)]
enum E {
    Top = 2,
    Bottom = 1,
}

assert!(E::Bottom < E::Top);

How can I implement PartialOrd?

PartialOrd only requires implementation of the partial_cmp method, with the others generated from default implementations.

However it remains possible to implement the others separately for types which do not have a total order. For example, for floating point numbers, NaN < 0 == false and NaN >= 0 == false (cf. IEEE 754-2008 section 5.11).

PartialOrd requires your type to be PartialEq.

If your type is Ord, you can implement partial_cmp by using cmp:

use std::cmp::Ordering;

struct Person {
    id: u32,
    name: String,
    height: u32,
}

impl PartialOrd for Person {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl Ord for Person {
    fn cmp(&self, other: &Self) -> Ordering {
        self.height.cmp(&other.height)
    }
}

impl PartialEq for Person {
    fn eq(&self, other: &Self) -> bool {
        self.height == other.height
    }
}

impl Eq for Person {}

You may also find it useful to use partial_cmp on your type’s fields. Here is an example of Person types who have a floating-point height field that is the only field to be used for sorting:

use std::cmp::Ordering;

struct Person {
    id: u32,
    name: String,
    height: f64,
}

impl PartialOrd for Person {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        self.height.partial_cmp(&other.height)
    }
}

impl PartialEq for Person {
    fn eq(&self, other: &Self) -> bool {
        self.height == other.height
    }
}

Examples of incorrect PartialOrd implementations

use std::cmp::Ordering;

#[derive(PartialEq, Debug)]
struct Character {
    health: u32,
    experience: u32,
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.health.cmp(&other.health))
    }
}

let a = Character {
    health: 10,
    experience: 5,
};
let b = Character {
    health: 10,
    experience: 77,
};

// Mistake: `PartialEq` and `PartialOrd` disagree with each other.

assert_eq!(a.partial_cmp(&b).unwrap(), Ordering::Equal); // a == b according to `PartialOrd`.
assert_ne!(a, b); // a != b according to `PartialEq`.

Examples

let x: u32 = 0;
let y: u32 = 1;

assert_eq!(x < y, true);
assert_eq!(x.lt(&y), true);

Required Methods

1.0.0 (const: unstable) · Source

fn partial_cmp(&self, other: &Rhs) -> Option<Ordering>

This method returns an ordering between self and other values if one exists.

Examples
use std::cmp::Ordering;

let result = 1.0.partial_cmp(&2.0);
assert_eq!(result, Some(Ordering::Less));

let result = 1.0.partial_cmp(&1.0);
assert_eq!(result, Some(Ordering::Equal));

let result = 2.0.partial_cmp(&1.0);
assert_eq!(result, Some(Ordering::Greater));

When comparison is impossible:

let result = f64::NAN.partial_cmp(&1.0);
assert_eq!(result, None);

Provided Methods

1.0.0 (const: unstable) · Source

fn lt(&self, other: &Rhs) -> bool

Tests less than (for self and other) and is used by the < operator.

Examples
assert_eq!(1.0 < 1.0, false);
assert_eq!(1.0 < 2.0, true);
assert_eq!(2.0 < 1.0, false);
1.0.0 (const: unstable) · Source

fn le(&self, other: &Rhs) -> bool

Tests less than or equal to (for self and other) and is used by the <= operator.

Examples
assert_eq!(1.0 <= 1.0, true);
assert_eq!(1.0 <= 2.0, true);
assert_eq!(2.0 <= 1.0, false);
1.0.0 (const: unstable) · Source

fn gt(&self, other: &Rhs) -> bool

Tests greater than (for self and other) and is used by the > operator.

Examples
assert_eq!(1.0 > 1.0, false);
assert_eq!(1.0 > 2.0, false);
assert_eq!(2.0 > 1.0, true);
1.0.0 (const: unstable) · Source

fn ge(&self, other: &Rhs) -> bool

Tests greater than or equal to (for self and other) and is used by the >= operator.

Examples
assert_eq!(1.0 >= 1.0, true);
assert_eq!(1.0 >= 2.0, false);
assert_eq!(2.0 >= 1.0, true);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl PartialOrd for !

1.0.0 (const: unstable) · Source

impl PartialOrd for ()

Source

impl PartialOrd for ATerm

Source

impl PartialOrd for Abi



impl PartialOrd for AbstractHeapType

Source

impl PartialOrd for AbstractResourceIndex



impl PartialOrd for AliasableResourceId

Source

impl PartialOrd for Alignment



impl PartialOrd for AnyTypeId



impl PartialOrd for ArangeEntry



impl PartialOrd for ArrayType

Source

impl PartialOrd for AsciiChar

Source

impl PartialOrd for Atom

Source

impl PartialOrd for B0

Source

impl PartialOrd for B1

Source

impl PartialOrd for BuildMetadata

Source

impl PartialOrd for BuiltinFunctionIndex

Source

impl PartialOrd for ByteStr

Source

impl PartialOrd for ByteString

1.0.0 · Source

impl PartialOrd for CStr

1.64.0 · Source

impl PartialOrd for CString

Source

impl PartialOrd for CharCase



impl PartialOrd for ColumnType



impl PartialOrd for ComdatId



impl PartialOrd for ComponentAnyTypeId

Source

impl PartialOrd for ComponentBuiltinFunctionIndex



impl PartialOrd for ComponentCoreInstanceTypeId



impl PartialOrd for ComponentCoreModuleTypeId



impl PartialOrd for ComponentCoreTypeId



impl PartialOrd for ComponentDefinedTypeId

Source

impl PartialOrd for ComponentFuncIndex



impl PartialOrd for ComponentFuncTypeId

Source

impl PartialOrd for ComponentIndex

Source

impl PartialOrd for ComponentInstanceIndex



impl PartialOrd for ComponentInstanceTypeId



impl PartialOrd for ComponentName



impl PartialOrd for ComponentNameKind<'_>

Source

impl PartialOrd for ComponentPC



impl PartialOrd for ComponentSectionId



impl PartialOrd for ComponentTypeId

Source

impl PartialOrd for ComponentTypeIndex

Source

impl PartialOrd for ComponentUpvarIndex



impl PartialOrd for ComponentValueTypeId



impl PartialOrd for CompositeInnerType



impl PartialOrd for CompositeType



impl PartialOrd for ContType



impl PartialOrd for CoreTypeId

1.27.0 · Source

impl PartialOrd for CpuidResult

Source

impl PartialOrd for DataIndex

Source

impl PartialOrd for DefinedFuncIndex

Source

impl PartialOrd for DefinedGlobalIndex

Source

impl PartialOrd for DefinedMemoryIndex

Source

impl PartialOrd for DefinedResourceIndex

Source

impl PartialOrd for DefinedTableIndex

Source

impl PartialOrd for DefinedTagIndex



impl PartialOrd for DemangleNodeType



impl PartialOrd for DeploymentTarget

1.3.0 · Source

impl PartialOrd for Duration



impl PartialOrd for DwAccess



impl PartialOrd for DwAddr



impl PartialOrd for DwAt



impl PartialOrd for DwAte



impl PartialOrd for DwCc



impl PartialOrd for DwCfa



impl PartialOrd for DwChildren



impl PartialOrd for DwDefaulted



impl PartialOrd for DwDs



impl PartialOrd for DwDsc



impl PartialOrd for DwEhPe



impl PartialOrd for DwEnd



impl PartialOrd for DwForm



impl PartialOrd for DwId



impl PartialOrd for DwIdx



impl PartialOrd for DwInl



impl PartialOrd for DwLang



impl PartialOrd for DwLle



impl PartialOrd for DwLnct



impl PartialOrd for DwLne



impl PartialOrd for DwLns



impl PartialOrd for DwMacinfo



impl PartialOrd for DwMacro



impl PartialOrd for DwOp



impl PartialOrd for DwOrd



impl PartialOrd for DwRle



impl PartialOrd for DwSect



impl PartialOrd for DwSectV2



impl PartialOrd for DwTag



impl PartialOrd for DwUt



impl PartialOrd for DwVirtuality



impl PartialOrd for DwVis

Source

impl PartialOrd for ElemIndex

Source

impl PartialOrd for EngineInternedRecGroupIndex

Source

impl PartialOrd for EntityIndex

Source

impl PartialOrd for Equal

1.0.0 · Source

impl PartialOrd for Error

1.0.0 · Source

impl PartialOrd for ErrorKind

Source

impl PartialOrd for ExportIndex

Source

impl PartialOrd for FieldId



impl PartialOrd for FieldType



impl PartialOrd for FieldType

Source

impl PartialOrd for FrameValType

Source

impl PartialOrd for FuncIndex

Source

impl PartialOrd for FuncKey

Source

impl PartialOrd for FuncKeyIndex

Source

impl PartialOrd for FuncKeyKind

Source

impl PartialOrd for FuncKeyNamespace

Source

impl PartialOrd for FuncRefIndex



impl PartialOrd for FuncType

Source

impl PartialOrd for GlobalIndex

Source

impl PartialOrd for Greater



impl PartialOrd for HeapType

Source

impl PartialOrd for HostCall



impl PartialOrd for Id

Source

impl PartialOrd for ImportIndex

1.34.0 (const: unstable) · Source

impl PartialOrd for Infallible

1.8.0 · Source

impl PartialOrd for Instant

1.7.0 · Source

impl PartialOrd for IpAddr

1.0.0 (const: unstable) · Source

impl PartialOrd for Ipv4Addr

1.0.0 (const: unstable) · Source

impl PartialOrd for Ipv6Addr

Source

impl PartialOrd for Ipv6MulticastScope



impl PartialOrd for KebabStr



impl PartialOrd for KebabString

Source

impl PartialOrd for Less

Source

impl PartialOrd for Level

Source

impl PartialOrd for LevelFilter

1.10.0 · Source

impl PartialOrd for Location<'_>

Source

impl PartialOrd for LoweredIndex

Source

impl PartialOrd for MemoryIndex

Source

impl PartialOrd for ModuleIndex

Source

impl PartialOrd for ModuleInstanceIndex

Source

impl PartialOrd for ModuleInternedRecGroupIndex

Source

impl PartialOrd for ModuleInternedTypeIndex

Source

impl PartialOrd for ModulePC

Source

impl PartialOrd for ModuleUpvarIndex



impl PartialOrd for NonMaxU8



impl PartialOrd for NonMaxU16



impl PartialOrd for NonMaxU32



impl PartialOrd for NonMaxU64



impl PartialOrd for NonMaxUsize

Source

impl PartialOrd for OptionsIndex

1.0.0 (const: unstable) · Source

impl PartialOrd for Ordering

1.0.0 · Source

impl PartialOrd for OsStr

1.0.0 · Source

impl PartialOrd for OsString

Source

impl PartialOrd for OwnedMemoryIndex



impl PartialOrd for PackedIndex

Source

impl PartialOrd for PassiveElemIndex

1.0.0 · Source

impl PartialOrd for Path

1.0.0 · Source

impl PartialOrd for PathBuf

1.33.0 · Source

impl PartialOrd for PhantomPinned

Source

impl PartialOrd for Prerelease



impl PartialOrd for Range



impl PartialOrd for RecGroup



impl PartialOrd for RecGroupId

Source

impl PartialOrd for RecGroupRelativeTypeIndex



impl PartialOrd for RefType



impl PartialOrd for RefType



impl PartialOrd for Register



impl PartialOrd for ResourceId

Source

impl PartialOrd for ResourceIndex

Source

impl PartialOrd for RuntimeCallbackIndex

Source

impl PartialOrd for RuntimeComponentInstanceIndex

Source

impl PartialOrd for RuntimeDataIndex

Source

impl PartialOrd for RuntimeImportIndex

Source

impl PartialOrd for RuntimeInstanceIndex

Source

impl PartialOrd for RuntimeMemoryIndex

Source

impl PartialOrd for RuntimePostReturnIndex

Source

impl PartialOrd for RuntimeReallocIndex

Source

impl PartialOrd for RuntimeTableIndex

Source

impl PartialOrd for Scc



impl PartialOrd for SectionId



impl PartialOrd for SectionId



impl PartialOrd for SectionId



impl PartialOrd for SectionIndex

1.0.0 · Source

impl PartialOrd for SocketAddr

1.0.0 · Source

impl PartialOrd for SocketAddrV4

1.0.0 · Source

impl PartialOrd for SocketAddrV6



impl PartialOrd for StandardSection



impl PartialOrd for StandardSegment

Source

impl PartialOrd for StaticComponentIndex

Source

impl PartialOrd for StaticModuleIndex



impl PartialOrd for StorageType



impl PartialOrd for StorageType

1.0.0 · Source

impl PartialOrd for String



impl PartialOrd for StructType



impl PartialOrd for SubType



impl PartialOrd for SymbolFlags



impl PartialOrd for SymbolId



impl PartialOrd for SymbolIndex

1.8.0 · Source

impl PartialOrd for SystemTime

Source

impl PartialOrd for TableIndex

Source

impl PartialOrd for TagIndex

Source

impl PartialOrd for TrampolineIndex



impl PartialOrd for TryString

Source

impl PartialOrd for TypeComponentGlobalErrorContextTableIndex

Source

impl PartialOrd for TypeComponentIndex

Source

impl PartialOrd for TypeComponentInstanceIndex

Source

impl PartialOrd for TypeComponentLocalErrorContextTableIndex

Source

impl PartialOrd for TypeEnumIndex

Source

impl PartialOrd for TypeFixedLengthListIndex

Source

impl PartialOrd for TypeFlagsIndex

Source

impl PartialOrd for TypeFuncIndex

Source

impl PartialOrd for TypeFutureIndex

Source

impl PartialOrd for TypeFutureTableIndex

1.0.0 · Source

impl PartialOrd for TypeId

Source

impl PartialOrd for TypeIndex

Source

impl PartialOrd for TypeListIndex

Source

impl PartialOrd for TypeMapIndex

Source

impl PartialOrd for TypeModuleIndex

Source

impl PartialOrd for TypeOptionIndex

Source

impl PartialOrd for TypeRecordIndex

Source

impl PartialOrd for TypeResourceTableIndex

Source

impl PartialOrd for TypeResultIndex

Source

impl PartialOrd for TypeStreamIndex

Source

impl PartialOrd for TypeStreamTableIndex

Source

impl PartialOrd for TypeTupleIndex

Source

impl PartialOrd for TypeVariantIndex

Source

impl PartialOrd for UTerm



impl PartialOrd for UnpackedIndex

Source

impl PartialOrd for UnsafeIntrinsic

Source

impl PartialOrd for VMSharedTypeIndex



impl PartialOrd for ValType



impl PartialOrd for ValType



impl PartialOrd for ValidatorId

Source

impl PartialOrd for Version

Source

impl PartialOrd for WasmChecksum

Source

impl PartialOrd for Z0

1.0.0 (const: unstable) · Source

impl PartialOrd for bool

1.0.0 (const: unstable) · Source

impl PartialOrd for char

1.0.0 (const: unstable) · Source

impl PartialOrd for f16

1.0.0 (const: unstable) · Source

impl PartialOrd for f32

1.0.0 (const: unstable) · Source

impl PartialOrd for f64

1.0.0 (const: unstable) · Source

impl PartialOrd for f128

1.0.0 (const: unstable) · Source

impl PartialOrd for i8

1.0.0 (const: unstable) · Source

impl PartialOrd for i16

1.0.0 (const: unstable) · Source

impl PartialOrd for i32

1.0.0 (const: unstable) · Source

impl PartialOrd for i64

1.0.0 (const: unstable) · Source

impl PartialOrd for i128

1.0.0 (const: unstable) · Source

impl PartialOrd for isize

1.0.0 · Source

impl PartialOrd for str

Implements comparison operations on strings.

Strings are compared lexicographically by their byte values. This compares Unicode code points based on their positions in the code charts. This is not necessarily the same as “alphabetical” order, which varies by language and locale. Comparing strings according to culturally-accepted standards requires locale-specific data that is outside the scope of the str type.

1.0.0 (const: unstable) · Source

impl PartialOrd for u8

1.0.0 (const: unstable) · Source

impl PartialOrd for u16

1.0.0 (const: unstable) · Source

impl PartialOrd for u32

1.0.0 (const: unstable) · Source

impl PartialOrd for u64

1.0.0 (const: unstable) · Source

impl PartialOrd for u128

1.0.0 (const: unstable) · Source

impl PartialOrd for usize

Source

impl PartialOrd<&ByteStr> for ByteString

Source

impl PartialOrd<&ByteStr> for Cow<'_, ByteStr>

Source

impl PartialOrd<&ByteStr> for Cow<'_, [u8]>

Source

impl PartialOrd<&ByteStr> for Cow<'_, str>

1.8.0 · Source

impl PartialOrd<&OsStr> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<&OsStr> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<&OsStr> for OsString

1.8.0 · Source

impl PartialOrd<&OsStr> for Path

1.8.0 · Source

impl PartialOrd<&OsStr> for PathBuf

1.8.0 · Source

impl PartialOrd<&Path> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<&Path> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<&Path> for OsStr

1.8.0 · Source

impl PartialOrd<&Path> for OsString

1.8.0 · Source

impl PartialOrd<&Path> for PathBuf

Source

impl PartialOrd<ByteStr> for ByteString

Source

impl PartialOrd<ByteString> for &ByteStr

Source

impl PartialOrd<ByteString> for ByteStr

Source

impl PartialOrd<ByteString> for Cow<'_, ByteStr>

Source

impl PartialOrd<ByteString> for Cow<'_, [u8]>

Source

impl PartialOrd<ByteString> for Cow<'_, str>

Source

impl PartialOrd<Cow<'_, ByteStr>> for &ByteStr

Source

impl PartialOrd<Cow<'_, ByteStr>> for ByteString

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for &OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for &Path

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for OsString

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for Path

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for PathBuf

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for &OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for &Path

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for OsString

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for Path

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for PathBuf

Source

impl PartialOrd<Cow<'_, [u8]>> for &ByteStr

Source

impl PartialOrd<Cow<'_, [u8]>> for ByteString

Source

impl PartialOrd<Cow<'_, str>> for &ByteStr

Source

impl PartialOrd<Cow<'_, str>> for ByteString

1.16.0 · Source

impl PartialOrd<IpAddr> for Ipv4Addr

1.16.0 · Source

impl PartialOrd<IpAddr> for Ipv6Addr

1.16.0 · Source

impl PartialOrd<Ipv4Addr> for IpAddr

1.16.0 · Source

impl PartialOrd<Ipv6Addr> for IpAddr

Source

impl PartialOrd<Level> for LevelFilter

Source

impl PartialOrd<LevelFilter> for Level

1.8.0 · Source

impl PartialOrd<OsStr> for &Path

1.8.0 · Source

impl PartialOrd<OsStr> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<OsStr> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<OsStr> for OsString

1.8.0 · Source

impl PartialOrd<OsStr> for Path

1.8.0 · Source

impl PartialOrd<OsStr> for PathBuf

1.8.0 · Source

impl PartialOrd<OsString> for &OsStr

1.8.0 · Source

impl PartialOrd<OsString> for &Path

1.8.0 · Source

impl PartialOrd<OsString> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<OsString> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<OsString> for OsStr

1.8.0 · Source

impl PartialOrd<OsString> for Path

1.8.0 · Source

impl PartialOrd<OsString> for PathBuf

1.8.0 · Source

impl PartialOrd<Path> for &OsStr

1.8.0 · Source

impl PartialOrd<Path> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<Path> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<Path> for OsStr

1.8.0 · Source

impl PartialOrd<Path> for OsString

1.8.0 · Source

impl PartialOrd<Path> for PathBuf

1.8.0 · Source

impl PartialOrd<PathBuf> for &OsStr

1.8.0 · Source

impl PartialOrd<PathBuf> for &Path

1.8.0 · Source

impl PartialOrd<PathBuf> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<PathBuf> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<PathBuf> for OsStr

1.8.0 · Source

impl PartialOrd<PathBuf> for OsString

1.8.0 · Source

impl PartialOrd<PathBuf> for Path

1.0.0 · Source

impl PartialOrd<str> for OsStr

1.0.0 · Source

impl PartialOrd<str> for OsString

1.0.0 · Source

impl<'a, B> PartialOrd for Cow<'a, B>
where B: PartialOrd + ToOwned + ?Sized,

1.0.0 · Source

impl<'a> PartialOrd for Component<'a>

1.0.0 · Source

impl<'a> PartialOrd for Components<'a>



impl<'a> PartialOrd for DependencyName<'a>



impl<'a> PartialOrd for HashName<'a>



impl<'a> PartialOrd for InterfaceName<'a>

Source

impl<'a> PartialOrd for Metadata<'a>

Source

impl<'a> PartialOrd for MetadataBuilder<'a>

Source

impl<'a> PartialOrd for PhantomContravariantLifetime<'a>

Source

impl<'a> PartialOrd for PhantomCovariantLifetime<'a>

Source

impl<'a> PartialOrd for PhantomInvariantLifetime<'a>

1.0.0 · Source

impl<'a> PartialOrd for Prefix<'a>

1.0.0 · Source

impl<'a> PartialOrd for PrefixComponent<'a>



impl<'a> PartialOrd for ResourceFunc<'a>



impl<'a> PartialOrd for UrlName<'a>

1.0.0 (const: unstable) · Source

impl<A, B> PartialOrd<&B> for &A
where A: PartialOrd<B> + ?Sized, B: ?Sized,

1.0.0 (const: unstable) · Source

impl<A, B> PartialOrd<&mut B> for &mut A
where A: PartialOrd<B> + ?Sized, B: ?Sized,



impl<A> PartialOrd for SmallVec<A>
where A: Array, <A as Array>::Item: PartialOrd,



impl<B> PartialOrd for TryCow<'_, B>
where B: PartialOrd + TryToOwned + ?Sized,

Source

impl<Dyn> PartialOrd for DynMetadata<Dyn>
where Dyn: ?Sized,



impl<E> PartialOrd for I16<E>
where E: PartialOrd + Endian,



impl<E> PartialOrd for I32<E>
where E: PartialOrd + Endian,



impl<E> PartialOrd for I64<E>
where E: PartialOrd + Endian,



impl<E> PartialOrd for U16<E>
where E: PartialOrd + Endian,



impl<E> PartialOrd for U32<E>
where E: PartialOrd + Endian,



impl<E> PartialOrd for U64<E>
where E: PartialOrd + Endian,

1.4.0 · Source

impl<F> PartialOrd for F
where F: FnPtr,

1.0.0 · Source

impl<K, V, A> PartialOrd for BTreeMap<K, V, A>
where K: PartialOrd, V: PartialOrd, A: Allocator + Clone,



impl<K, V> PartialOrd for Slice<K, V>
where K: PartialOrd, V: PartialOrd,

1.41.0 · Source

impl<Ptr, Q> PartialOrd<Pin<Q>> for Pin<Ptr>
where Ptr: Deref, Q: Deref, <Ptr as Deref>::Target: PartialOrd<<Q as Deref>::Target>,

1.0.0 · Source

impl<T, A1, A2> PartialOrd<Vec<T, A2>> for Vec<T, A1>
where T: PartialOrd, A1: Allocator, A2: Allocator,

Implements comparison of vectors, lexicographically.

1.0.0 · Source

impl<T, A> PartialOrd for Arc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for BTreeSet<T, A>
where T: PartialOrd, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> PartialOrd for Box<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for LinkedList<T, A>
where T: PartialOrd, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for Rc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

Source

impl<T, A> PartialOrd for UniqueArc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

Source

impl<T, A> PartialOrd for UniqueRc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for VecDeque<T, A>
where T: PartialOrd, A: Allocator,

1.0.0 (const: unstable) · Source

impl<T, E> PartialOrd for Result<T, E>
where T: PartialOrd, E: PartialOrd,



impl<T, N> PartialOrd for GenericArray<T, N>
where T: PartialOrd, N: ArrayLength<T>,

Source

impl<T, U> PartialOrd<SyncView<U>> for SyncView<T>
where T: Sync + PartialOrd<U> + ?Sized, U: Sync + ?Sized,

Source

impl<T, const N: usize> PartialOrd for Mask<T, N>

Source

impl<T, const N: usize> PartialOrd for Simd<T, N>

Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.

1.0.0 (const: unstable) · Source

impl<T, const N: usize> PartialOrd for [T; N]
where T: PartialOrd,

Implements comparison of arrays lexicographically.

Source

impl<T, const VARIANT: u32, const FIELD: u32> PartialOrd for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,

1.0.0 (const: unstable) · Source

impl<T> PartialOrd for (T₁, T₂, …, Tₙ)
where T: PartialOrd,

This trait is implemented for tuples up to twelve items long.

1.0.0 · Source

impl<T> PartialOrd for *const T
where T: ?Sized,

Pointer comparison is by address, as produced by the [<*const T>::addr](pointer::addr) method.

1.0.0 · Source

impl<T> PartialOrd for *mut T
where T: ?Sized,

Pointer comparison is by address, as produced by the <*mut T>::addr method.

1.10.0 · Source

impl<T> PartialOrd for Cell<T>
where T: PartialOrd + Copy,



impl<T> PartialOrd for DebugInfoOffset<T>
where T: PartialOrd,



impl<T> PartialOrd for DebugTypesOffset<T>
where T: PartialOrd,

1.20.0 · Source

impl<T> PartialOrd for ManuallyDrop<T>
where T: PartialOrd + ?Sized,



impl<T> PartialOrd for NameEntryOffset<T>
where T: PartialOrd,

1.25.0 · Source

impl<T> PartialOrd for NonNull<T>
where T: ?Sized,

1.28.0 (const: unstable) · Source

impl<T> PartialOrd for NonZero<T>

1.0.0 (const: unstable) · Source

impl<T> PartialOrd for Option<T>
where T: PartialOrd,



impl<T> PartialOrd for PackedOption<T>

Source

impl<T> PartialOrd for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> PartialOrd for PhantomCovariant<T>
where T: ?Sized,

1.0.0 · Source

impl<T> PartialOrd for PhantomData<T>
where T: ?Sized,

Source

impl<T> PartialOrd for PhantomInvariant<T>
where T: ?Sized,

1.36.0 · Source

impl<T> PartialOrd for Poll<T>
where T: PartialOrd,

1.10.0 · Source

impl<T> PartialOrd for RefCell<T>
where T: PartialOrd + ?Sized,

1.19.0 (const: unstable) · Source

impl<T> PartialOrd for Reverse<T>
where T: PartialOrd,

1.74.0 · Source

impl<T> PartialOrd for Saturating<T>
where T: PartialOrd,



impl<T> PartialOrd for Slice<T>
where T: PartialOrd,



impl<T> PartialOrd for TryVec<T>
where T: PartialOrd,



impl<T> PartialOrd for UnitOffset<T>
where T: PartialOrd,



impl<T> PartialOrd for UnitSectionOffset<T>
where T: PartialOrd,

1.0.0 · Source

impl<T> PartialOrd for Wrapping<T>
where T: PartialOrd,

1.0.0 (const: unstable) · Source

impl<T> PartialOrd for [T]
where T: PartialOrd,

Implements comparison of slices lexicographically.

Source

impl<U, B> PartialOrd for UInt<U, B>
where U: PartialOrd, B: PartialOrd,

Source

impl<U> PartialOrd for NInt<U>

Source

impl<U> PartialOrd for PInt<U>

Source

impl<V, A> PartialOrd for TArr<V, A>
where V: PartialOrd, A: PartialOrd,

Source

impl<Y, R> PartialOrd for CoroutineState<Y, R>
where Y: PartialOrd, R: PartialOrd,