Sync

Trait Sync 

1.55.0 · Source
pub unsafe auto trait Sync { }
Types for which it is safe to share references between threads.

This trait is automatically implemented when the compiler determines it’s appropriate.

The precise definition is: a type T is Sync if and only if &T is Send. In other words, if there is no possibility of undefined behavior (including data races) when passing &T references between threads.

As one would expect, primitive types like u8 and f64 are all Sync, and so are simple aggregate types containing them, like tuples, structs and enums. More examples of basic Sync types include “immutable” types like &T, and those with simple inherited mutability, such as Box<T>, Vec<T> and most other collection types. (Generic parameters need to be Sync for their container to be Sync.)

A somewhat surprising consequence of the definition is that &mut T is Sync (if T is Sync) even though it seems like that might provide unsynchronized mutation. The trick is that a mutable reference behind a shared reference (that is, & &mut T) becomes read-only, as if it were a & &T. Hence there is no risk of a data race.

A shorter overview of how Sync and Send relate to referencing:

  • &T is Send if and only if T is Sync
  • &mut T is Send if and only if T is Send
  • &T and &mut T are Sync if and only if T is Sync

Types that are not Sync are those that have “interior mutability” in a non-thread-safe form, such as Cell and RefCell. These types allow for mutation of their contents even through an immutable, shared reference. For example the set method on Cell<T> takes &self, so it requires only a shared reference &Cell<T>. The method performs no synchronization, thus Cell cannot be Sync.

Another example of a non-Sync type is the reference-counting pointer Rc. Given any reference &Rc<T>, you can clone a new Rc<T>, modifying the reference counts in a non-atomic way.

For cases when one does need thread-safe interior mutability, Rust provides atomic data types, as well as explicit locking via sync::Mutex and sync::RwLock. These types ensure that any mutation cannot cause data races, hence the types are Sync. Likewise, sync::Arc provides a thread-safe analogue of Rc.

Any types with interior mutability must also use the cell::UnsafeCell wrapper around the value(s) which can be mutated through a shared reference. Failing to doing this is undefined behavior. For example, transmute-ing from &T to &mut T is invalid.

See the Nomicon for more details about Sync.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.26.0 · Source

impl !Sync for Args

1.26.0 · Source

impl !Sync for ArgsOs

1.0.0 · Source

impl !Sync for Arguments<'_>

Source

impl !Sync for LocalWaker

Source

impl Sync for wasmtime_environ::__core::ffi::c_str::Bytes<'_>

1.6.0 · Source

impl Sync for alloc::string::Drain<'_>

1.10.0 · Source

impl Sync for Location<'_>



impl Sync for OutOfMemory

1.0.0 · Source

impl Sync for TypeId

1.36.0 · Source

impl Sync for Waker



impl<'a, T> Sync for Drain<'a, T>
where T: Sync + Array,

1.44.0 · Source

impl<'a> Sync for IoSlice<'a>

1.44.0 · Source

impl<'a> Sync for IoSliceMut<'a>

Source

impl<Dyn> Sync for DynMetadata<Dyn>
where Dyn: ?Sized,



impl<K, V, S, A> Sync for OccupiedEntry<'_, K, V, S, A>
where K: Sync, V: Sync, S: Sync, A: Sync + Allocator,



impl<K, V, S, A> Sync for OccupiedEntry<'_, K, V, S, A>
where K: Sync, V: Sync, S: Sync, A: Sync + Allocator,

1.0.0 · Source

impl<T, A> !Sync for Rc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> !Sync for UniqueRc<T, A>
where A: Allocator, T: ?Sized,

1.4.0 · Source

impl<T, A> !Sync for alloc::rc::Weak<T, A>
where A: Allocator, T: ?Sized,

1.0.0 · Source

impl<T, A> Sync for Arc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Sync,

Source

impl<T, A> Sync for alloc::collections::linked_list::Cursor<'_, T, A>
where T: Sync, A: Allocator + Sync,

Source

impl<T, A> Sync for CursorMut<'_, T, A>
where T: Sync, A: Allocator + Sync,

1.6.0 · Source

impl<T, A> Sync for alloc::collections::vec_deque::drain::Drain<'_, T, A>
where T: Sync, A: Allocator + Sync,

1.6.0 · Source

impl<T, A> Sync for wasmtime_environ::prelude::vec::Drain<'_, T, A>
where T: Sync, A: Sync + Allocator,

1.0.0 · Source

impl<T, A> Sync for wasmtime_environ::prelude::vec::IntoIter<T, A>
where T: Sync, A: Allocator + Sync,

1.0.0 · Source

impl<T, A> Sync for LinkedList<T, A>
where T: Sync, A: Allocator + Sync,



impl<T, A> Sync for OccupiedEntry<'_, T, A>
where T: Sync, A: Sync + Allocator,



impl<T, A> Sync for OccupiedEntry<'_, T, A>
where T: Sync, A: Sync + Allocator,

Source

impl<T, A> Sync for UniqueArc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Sync,

1.4.0 · Source

impl<T, A> Sync for alloc::sync::Weak<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Sync,

1.80.0 · Source

impl<T, F> Sync for LazyLock<T, F>
where T: Sync + Send, F: Send,



impl<T, N> Sync for GenericArray<T, N>
where T: Sync, N: ArrayLength<T>,

1.0.0 · Source

impl<T> !Sync for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> !Sync for *mut T
where T: ?Sized,

1.0.0 · Source

impl<T> !Sync for Cell<T>
where T: ?Sized,

1.25.0 · Source

impl<T> !Sync for NonNull<T>
where T: ?Sized,

NonNull pointers are not Sync because the data they reference may be aliased.

1.70.0 · Source

impl<T> !Sync for OnceCell<T>

1.0.0 · Source

impl<T> !Sync for std::sync::mpsc::Receiver<T>

1.0.0 · Source

impl<T> !Sync for RefCell<T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Sync for UnsafeCell<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Sync for Atomic<T>
where T: AtomicPrimitive,

1.31.0 · Source

impl<T> Sync for ChunksExactMut<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for ChunksMut<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for wasmtime_environ::__core::slice::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for alloc::collections::linked_list::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for wasmtime_environ::__core::slice::IterMut<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for alloc::collections::linked_list::IterMut<'_, T>
where T: Sync,

1.29.0 · Source

impl<T> Sync for JoinHandle<T>

Source

impl<T> Sync for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for std::sync::nonpoison::mutex::Mutex<T>
where T: Send + ?Sized,

T must be Send for Mutex to be Sync. This ensures that the protected data can be accessed safely from multiple threads without causing data races or other unsafe behavior.

Mutex<T> provides mutable access to T to one thread at a time. However, it’s essential for T to be Send because it’s not safe for non-Send structures to be accessed in this manner. For instance, consider Rc, a non-atomic reference counted smart pointer, which is not Send. With Rc, we can have multiple copies pointing to the same heap allocation with a non-atomic reference count. If we were to use Mutex<Rc<_>>, it would only protect one instance of Rc from shared access, leaving other copies vulnerable to potential data races.

Also note that it is not necessary for T to be Sync as &T is only made available to one thread at a time if T is not Sync.

1.0.0 · Source

impl<T> Sync for std::sync::poison::mutex::Mutex<T>
where T: Send + ?Sized,

T must be Send for Mutex to be Sync. This ensures that the protected data can be accessed safely from multiple threads without causing data races or other unsafe behavior.

Mutex<T> provides mutable access to T to one thread at a time. However, it’s essential for T to be Send because it’s not safe for non-Send structures to be accessed in this manner. For instance, consider Rc, a non-atomic reference counted smart pointer, which is not Send. With Rc, we can have multiple copies pointing to the same heap allocation with a non-atomic reference count. If we were to use Mutex<Rc<_>>, it would only protect one instance of Rc from shared access, leaving other copies vulnerable to potential data races.

Also note that it is not necessary for T to be Sync as &T is only made available to one thread at a time if T is not Sync.

Source

impl<T> Sync for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Sync + ?Sized,

T must be Sync for a MutexGuard<T> to be Sync because it is possible to get a &T from &MutexGuard (via Deref).

1.19.0 · Source

impl<T> Sync for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Sync + ?Sized,

T must be Sync for a MutexGuard<T> to be Sync because it is possible to get a &T from &MutexGuard (via Deref).

1.28.0 · Source

impl<T> Sync for NonZero<T>

1.70.0 · Source

impl<T> Sync for OnceLock<T>
where T: Sync + Send,

1.31.0 · Source

impl<T> Sync for RChunksExactMut<'_, T>
where T: Sync,

1.31.0 · Source

impl<T> Sync for RChunksMut<'_, T>
where T: Sync,

Source

impl<T> Sync for std::sync::oneshot::Receiver<T>

Source

impl<T> Sync for std::sync::mpmc::Receiver<T>
where T: Send,

Source

impl<T> Sync for ReentrantLock<T>
where T: Send + ?Sized,

Source

impl<T> Sync for ReentrantLockGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for std::sync::nonpoison::rwlock::RwLock<T>
where T: Send + Sync + ?Sized,

1.0.0 · Source

impl<T> Sync for std::sync::poison::rwlock::RwLock<T>
where T: Send + Sync + ?Sized,

Source

impl<T> Sync for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Sync + ?Sized,

1.23.0 · Source

impl<T> Sync for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Sync + ?Sized,

1.23.0 · Source

impl<T> Sync for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for std::sync::oneshot::Sender<T>

Source

impl<T> Sync for std::sync::mpmc::Sender<T>
where T: Send,

1.72.0 · Source

impl<T> Sync for std::sync::mpsc::Sender<T>
where T: Send,

Source

impl<T> Sync for SyncUnsafeCell<T>
where T: Sync + ?Sized,

Source

impl<T> Sync for SyncView<T>
where T: ?Sized,

Source

impl<T> Sync for ThinBox<T>
where T: Sync + ?Sized,

ThinBox<T> is Sync if T is Sync because the data is owned.

Source

impl<T> Sync for UnsafePinned<T>
where T: Sync + ?Sized,

Auto implementors



impl !Sync for RawWaker



impl Sync for wasmtime_environ::Abi



impl Sync for wasmtime_environ::__core::mem::type_info::Abi



impl Sync for AbstractResourceIndex



impl Sync for Adapter



impl Sync for AdapterId



impl Sync for AdapterModuleId



impl Sync for AdapterOptions



impl Sync for AddrParseError



impl Sync for AddressMapSection



impl Sync for wasmtime_environ::__core::mem::Alignment



impl Sync for wasmtime_environ::__core::fmt::Alignment



impl Sync for AllocError



impl Sync for AnyhowCtor



impl Sync for Array



impl Sync for AsciiChar



impl Sync for Assume



impl Sync for Atom



impl Sync for AtomicOrdering



impl Sync for BasicBlock



impl Sync for Big8x3



impl Sync for Big32x40



impl Sync for Bool



impl Sync for BorrowError



impl Sync for BorrowMutError



impl Sync for BuiltinFunctionIndex



impl Sync for ByteStr



impl Sync for CStr



impl Sync for CallbackId



impl Sync for CanonicalAbiInfo



impl Sync for wasmtime_environ::component::CanonicalOptions



impl Sync for wasmtime_environ::component::dfg::CanonicalOptions



impl Sync for wasmtime_environ::component::CanonicalOptionsDataModel



impl Sync for wasmtime_environ::component::dfg::CanonicalOptionsDataModel



impl Sync for Char



impl Sync for CharCase



impl Sync for CharTryFromError



impl Sync for CodePointInner



impl Sync for Collector



impl Sync for CompileError



impl Sync for CompiledComponentInfo



impl Sync for CompiledFunctionBody



impl Sync for CompiledFunctionsTable



impl Sync for CompiledFunctionsTableBuilder



impl Sync for CompiledModuleInfo



impl Sync for CompiledTrap



impl Sync for Component



impl Sync for ComponentArtifacts



impl Sync for ComponentBuiltinFunctionIndex



impl Sync for ComponentDfg



impl Sync for ComponentExtern



impl Sync for ComponentExternData



impl Sync for ComponentFuncIndex



impl Sync for ComponentIndex



impl Sync for ComponentInstanceIndex



impl Sync for ComponentItem



impl Sync for ComponentPC



impl Sync for ComponentTranslation



impl Sync for ComponentTypeIndex



impl Sync for ComponentTypes



impl Sync for ComponentTypesBuilder



impl Sync for ComponentUpvarIndex



impl Sync for ConfigTunables



impl Sync for Const



impl Sync for ConstExpr



impl Sync for ConstOp



impl Sync for CopyingTypeLayouts



impl Sync for wasmtime_environ::component::CoreDef



impl Sync for wasmtime_environ::component::dfg::CoreDef



impl Sync for CpuidResult



impl Sync for DataIndex



impl Sync for DataModel



impl Sync for DebugAsHex



impl Sync for Decimal



impl Sync for DecimalSeq



impl Sync for DecodeUtf16Error



impl Sync for Decoded



impl Sync for DefaultHasher



impl Sync for DefinedFuncIndex



impl Sync for DefinedGlobalIndex



impl Sync for DefinedMemoryIndex



impl Sync for DefinedResourceIndex



impl Sync for DefinedTableIndex



impl Sync for DefinedTagIndex



impl Sync for DrcTypeLayouts



impl Sync for Duration



impl Sync for DynTrait



impl Sync for DynTraitPredicate



impl Sync for ElemIndex



impl Sync for wasmtime_environ::__core::io::Empty



impl Sync for EngineInternedRecGroupIndex



impl Sync for EngineOrModuleTypeIndex



impl Sync for EntityIndex



impl Sync for EntityType



impl Sync for Enum



impl Sync for wasmtime_environ::prelude::Error



impl Sync for wasmtime_environ::__core::fmt::Error



impl Sync for ErrorKind



impl Sync for wasmtime_environ::__core::char::EscapeDebug



impl Sync for wasmtime_environ::__core::ascii::EscapeDefault



impl Sync for wasmtime_environ::__core::char::EscapeDefault



impl Sync for wasmtime_environ::__core::char::EscapeUnicode



impl Sync for Evaporation



impl Sync for wasmtime_environ::component::Export



impl Sync for wasmtime_environ::component::dfg::Export



impl Sync for ExportIndex



impl Sync for ExtractCallback



impl Sync for ExtractMemory



impl Sync for ExtractPostReturn



impl Sync for ExtractRealloc



impl Sync for ExtractTable



impl Sync for Field



impl Sync for FieldId



impl Sync for FilePos



impl Sync for FixedEncoding



impl Sync for FlatType



impl Sync for Float



impl Sync for FnPtr



impl Sync for FormattingOptions



impl Sync for FpCategory



impl Sync for FrameInstPos



impl Sync for FrameStackShape



impl Sync for FrameStateSlotBuilder



impl Sync for FrameStateSlotOffset



impl Sync for FrameTableBuilder



impl Sync for FrameTableDescriptorIndex



impl Sync for FrameValType



impl Sync for FromBytesUntilNulError



impl Sync for FromBytesWithNulError



impl Sync for FullDecoded



impl Sync for FuncIndex



impl Sync for FuncKey



impl Sync for FuncKeyIndex



impl Sync for FuncKeyKind



impl Sync for FuncKeyNamespace



impl Sync for FuncRefIndex



impl Sync for FunctionLoc



impl Sync for FunctionMetadata



impl Sync for FunctionName



impl Sync for FunctionType



impl Sync for FutureInfo



impl Sync for GcArrayLayout



impl Sync for GcLayout



impl Sync for GcStructLayout



impl Sync for GcStructLayoutField



impl Sync for Generic



impl Sync for GenericType



impl Sync for GetDisjointMutError



impl Sync for Global



impl Sync for GlobalConstValue



impl Sync for GlobalIndex



impl Sync for GlobalInitializer



impl Sync for HostCall



impl Sync for HostPtr



impl Sync for I32NotAllOnes



impl Sync for I64NotAllOnes



impl Sync for Import



impl Sync for ImportIndex



impl Sync for IndexType



impl Sync for Infallible



impl Sync for Initializer



impl Sync for InlineTraceInfo



impl Sync for Inlining



impl Sync for Instance



impl Sync for InstanceId



impl Sync for InstantiateModule



impl Sync for InstructionAddressMap



impl Sync for Int



impl Sync for IntErrorKind



impl Sync for InterfaceType



impl Sync for IpAddr



impl Sync for Ipv4Addr



impl Sync for Ipv6Addr



impl Sync for Ipv6MulticastScope



impl Sync for Last



impl Sync for Layout



impl Sync for LayoutError



impl Sync for Lifetime



impl Sync for Limits



impl Sync for LinearMemoryOptions



impl Sync for LocalDataModel



impl Sync for Locality



impl Sync for LoweredIndex



impl Sync for Memory



impl Sync for MemoryId



impl Sync for MemoryIndex



impl Sync for MemoryInitialization



impl Sync for MemoryKind



impl Sync for MemorySegmentOffset



impl Sync for Metadata



impl Sync for wasmtime_environ::Module



impl Sync for ModuleIndex



impl Sync for ModuleInstanceIndex



impl Sync for ModuleInternedRecGroupIndex



impl Sync for ModuleInternedTypeIndex



impl Sync for ModulePC



impl Sync for ModuleStartup



impl Sync for ModuleTypes



impl Sync for ModuleTypesBuilder



impl Sync for ModuleUpvarIndex



impl Sync for MsgCtor



impl Sync for NameMapNoIntern



impl Sync for Nanoseconds



impl Sync for NewCtor



impl Sync for NonMaxU8



impl Sync for NonMaxU16



impl Sync for NonMaxU32



impl Sync for NonMaxU64



impl Sync for NonMaxUsize



impl Sync for NonZeroCharInner



impl Sync for NonZeroI8Inner



impl Sync for NonZeroI16Inner



impl Sync for NonZeroI32Inner



impl Sync for NonZeroI64Inner



impl Sync for NonZeroI128Inner



impl Sync for NonZeroIsizeInner



impl Sync for NonZeroU8Inner



impl Sync for NonZeroU16Inner



impl Sync for NonZeroU32Inner



impl Sync for NonZeroU64Inner



impl Sync for NonZeroU128Inner



impl Sync for NonZeroUsizeInner



impl Sync for NullTypeLayouts



impl Sync for ObjectCrateErrorWrapper



impl Sync for ObjectKind



impl Sync for OneSidedRangeBound



impl Sync for OperatorCost



impl Sync for OperatorCostStrategy



impl Sync for OptionsId



impl Sync for OptionsIndex



impl Sync for wasmtime_environ::__core::cmp::Ordering



impl Sync for wasmtime_environ::__core::sync::atomic::Ordering



impl Sync for OwnedMemoryIndex



impl Sync for ParseBoolError



impl Sync for ParseCharError



impl Sync for ParseFloatError



impl Sync for ParseIntError



impl Sync for PassiveElemIndex



impl Sync for PhantomPinned



impl Sync for Pointer



impl Sync for PostReturnId



impl Sync for RandomState



impl Sync for RangeFull



impl Sync for RawWakerVTable



impl Sync for ReallocId



impl Sync for RecGroupRelativeTypeIndex



impl Sync for RecordField



impl Sync for Reference



impl Sync for wasmtime_environ::__core::io::Repeat



impl Sync for wasmtime_environ::component::Resource



impl Sync for wasmtime_environ::component::dfg::Resource



impl Sync for ResourceIndex



impl Sync for ResourcesBuilder



impl Sync for ReturnToArg



impl Sync for RuntimeCallbackIndex



impl Sync for RuntimeComponentInstanceIndex



impl Sync for RuntimeDataIndex



impl Sync for RuntimeImportIndex



impl Sync for RuntimeInstanceIndex



impl Sync for RuntimeMemoryIndex



impl Sync for RuntimePostReturnIndex



impl Sync for RuntimeReallocIndex



impl Sync for RuntimeTableIndex



impl Sync for Scc



impl Sync for SearchStep



impl Sync for Setting



impl Sync for SettingKind



impl Sync for SideEffect



impl Sync for Sign



impl Sync for wasmtime_environ::__core::fmt::Sign



impl Sync for SimdAlign



impl Sync for Sink



impl Sync for SipHasher



impl Sync for SizeOverflow



impl Sync for Slice



impl Sync for SocketAddr



impl Sync for SocketAddrV4



impl Sync for SocketAddrV6



impl Sync for StackMapSection



impl Sync for StaticComponentIndex



impl Sync for StaticModuleIndex



impl Sync for Str



impl Sync for StreamInfo



impl Sync for String



impl Sync for StringEncoding



impl Sync for StringPool



impl Sync for Struct



impl Sync for Table



impl Sync for TableId



impl Sync for TableIndex



impl Sync for TableInitialValue



impl Sync for TableInitialization



impl Sync for TableSegment



impl Sync for TableSegmentElements



impl Sync for Tag



impl Sync for TagIndex



impl Sync for ToLowercase



impl Sync for ToTitlecase



impl Sync for ToUppercase



impl Sync for Trait



impl Sync for wasmtime_environ::component::Trampoline



impl Sync for wasmtime_environ::component::dfg::Trampoline



impl Sync for TrampolineIndex



impl Sync for Transcode



impl Sync for Trap



impl Sync for TrapEncodingBuilder



impl Sync for TrapInformation



impl Sync for TrapSentinel



impl Sync for TryCaptureWithDebug



impl Sync for TryCaptureWithoutDebug



impl Sync for TryFromCharError



impl Sync for TryFromFloatSecsError



impl Sync for TryFromIntError



impl Sync for TryFromSliceError



impl Sync for TryString



impl Sync for Tunables



impl Sync for Tuple



impl Sync for Type



impl Sync for TypeComponent



impl Sync for TypeComponentGlobalErrorContextTableIndex



impl Sync for TypeComponentIndex



impl Sync for TypeComponentInstance



impl Sync for TypeComponentInstanceIndex



impl Sync for TypeComponentLocalErrorContextTableIndex



impl Sync for TypeDef



impl Sync for TypeEnum



impl Sync for TypeEnumIndex



impl Sync for TypeErrorContextTable



impl Sync for TypeFixedLengthList



impl Sync for TypeFixedLengthListIndex



impl Sync for TypeFlags



impl Sync for TypeFlagsIndex



impl Sync for TypeFunc



impl Sync for TypeFuncIndex



impl Sync for TypeFuture



impl Sync for TypeFutureIndex



impl Sync for TypeFutureTable



impl Sync for TypeFutureTableIndex



impl Sync for TypeIndex



impl Sync for TypeKind



impl Sync for TypeList



impl Sync for TypeListIndex



impl Sync for TypeMap



impl Sync for TypeMapIndex



impl Sync for TypeModule



impl Sync for TypeModuleIndex



impl Sync for TypeOption



impl Sync for TypeOptionIndex



impl Sync for TypeRecord



impl Sync for TypeRecordIndex



impl Sync for TypeResourceTable



impl Sync for TypeResourceTableIndex



impl Sync for TypeResult



impl Sync for TypeResultIndex



impl Sync for TypeStream



impl Sync for TypeStreamIndex



impl Sync for TypeStreamTable



impl Sync for TypeStreamTableIndex



impl Sync for TypeTuple



impl Sync for TypeTupleIndex



impl Sync for TypeVariant



impl Sync for TypeVariantIndex



impl Sync for U32NotAllOnes



impl Sync for U64NotAllOnes



impl Sync for wasmtime_environ::__core::mem::type_info::Union



impl Sync for UnsafeIntrinsic



impl Sync for UnwindActionArg



impl Sync for UnwindTerminateReason



impl Sync for UsizeNoHighBit



impl Sync for Utf8BoundaryError



impl Sync for Utf8Error



impl Sync for VMGcKind



impl Sync for VMSharedTypeIndex



impl Sync for Variant



impl Sync for VariantInfo



impl Sync for WasmArrayType



impl Sync for WasmChecksum



impl Sync for WasmCompositeInnerType



impl Sync for WasmCompositeType



impl Sync for WasmContType



impl Sync for WasmError



impl Sync for WasmExnType



impl Sync for WasmFieldType



impl Sync for WasmFileInfo



impl Sync for WasmFuncType



impl Sync for WasmHeapBottomType



impl Sync for WasmHeapTopType



impl Sync for WasmHeapType



impl Sync for WasmRecGroup



impl Sync for WasmRefType



impl Sync for WasmStorageType



impl Sync for WasmStructType



impl Sync for WasmSubType



impl Sync for WasmValType



impl Sync for __m128



impl Sync for __m256



impl Sync for __m512



impl Sync for __m128bh



impl Sync for __m128d



impl Sync for __m128h



impl Sync for __m128i



impl Sync for __m256bh



impl Sync for __m256d



impl Sync for __m256h



impl Sync for __m256i



impl Sync for __m512bh



impl Sync for __m512d



impl Sync for __m512h



impl Sync for __m512i



impl Sync for bf16



impl Sync for c_void



impl<'a, 'b, const N: usize> Sync for CharArrayRefSearcher<'a, 'b, N>



impl<'a, 'b> !Sync for DebugList<'a, 'b>



impl<'a, 'b> !Sync for DebugMap<'a, 'b>



impl<'a, 'b> !Sync for DebugSet<'a, 'b>



impl<'a, 'b> !Sync for DebugStruct<'a, 'b>



impl<'a, 'b> !Sync for DebugTuple<'a, 'b>



impl<'a, 'b> Sync for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Sync for StrSearcher<'a, 'b>



impl<'a, 'data> !Sync for Translator<'a, 'data>



impl<'a, 'data> Sync for ModuleEnvironment<'a, 'data>



impl<'a, A> Sync for wasmtime_environ::__core::option::Iter<'a, A>
where A: Sync,



impl<'a, A> Sync for wasmtime_environ::__core::option::IterMut<'a, A>
where A: Sync,



impl<'a, B> Sync for TryCow<'a, B>
where <B as TryToOwned>::Owned: Sync, B: Sync + ?Sized,



impl<'a, F> Sync for CharPredicateSearcher<'a, F>
where F: Sync,



impl<'a, F> Sync for WasmparserTypeConverter<'a, F>
where F: Sync,



impl<'a, I, A> Sync for Splice<'a, I, A>
where I: Sync, <I as Iterator>::Item: Sync, A: Sync,



impl<'a, I> Sync for ByRefSized<'a, I>
where I: Sync,



impl<'a, K, A> Sync for wasmtime_environ::collections::oom_abort::hash_set::Drain<'a, K, A>
where A: Sync, K: Sync,



impl<'a, K, F, A> Sync for wasmtime_environ::collections::oom_abort::hash_set::ExtractIf<'a, K, F, A>
where F: Sync, A: Sync, K: Sync,



impl<'a, K, V, A> Sync for wasmtime_environ::collections::oom_abort::hash_map::Drain<'a, K, V, A>
where A: Sync, K: Sync, V: Sync,



impl<'a, K, V, A> Sync for wasmtime_environ::collections::oom_abort::hash_map::Entry<'a, K, V, A>
where K: Sync, V: Sync, A: Sync,



impl<'a, K, V, A> Sync for wasmtime_environ::collections::oom_abort::hash_map::OccupiedEntry<'a, K, V, A>
where K: Sync, V: Sync, A: Sync,



impl<'a, K, V, A> Sync for OccupiedError<'a, K, V, A>
where K: Sync, V: Sync, A: Sync,



impl<'a, K, V, A> Sync for wasmtime_environ::collections::oom_abort::hash_map::VacantEntry<'a, K, V, A>
where K: Sync, A: Sync, V: Sync,



impl<'a, K, V, F, A> Sync for wasmtime_environ::collections::oom_abort::hash_map::ExtractIf<'a, K, V, F, A>
where F: Sync, A: Sync, K: Sync, V: Sync,



impl<'a, K, V> Sync for BTreeMapIter<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for BTreeMapIterMut<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for BTreeMapKeys<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for BTreeMapRange<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for BTreeMapRangeMut<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for BTreeMapValues<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for BTreeMapValuesMut<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for wasmtime_environ::collections::btree_map::Entry<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for wasmtime_environ::collections::oom_abort::hash_map::Iter<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for wasmtime_environ::Iter<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for wasmtime_environ::collections::oom_abort::hash_map::IterMut<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for wasmtime_environ::IterMut<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for wasmtime_environ::collections::oom_abort::hash_map::Keys<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for wasmtime_environ::collections::btree_map::OccupiedEntry<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for wasmtime_environ::collections::btree_map::VacantEntry<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for Values<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for ValuesMut<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K> Sync for wasmtime_environ::collections::oom_abort::hash_set::Iter<'a, K>
where K: Sync,



impl<'a, K> Sync for SetIter<'a, K>
where K: Sync,



impl<'a, P> Sync for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for wasmtime_environ::__core::str::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for wasmtime_environ::__core::str::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for wasmtime_environ::__core::str::Split<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for wasmtime_environ::__core::str::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for wasmtime_environ::__core::str::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, T, A> Sync for PeekMut<'a, T, A>
where A: Sync, T: Sync,



impl<'a, T, F, A> Sync for wasmtime_environ::prelude::vec::ExtractIf<'a, T, F, A>
where F: Sync, A: Sync, T: Sync,



impl<'a, T, P> Sync for ChunkBy<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for ChunkByMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for wasmtime_environ::__core::slice::RSplit<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for RSplitMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for wasmtime_environ::__core::slice::RSplitN<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for RSplitNMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for wasmtime_environ::__core::slice::Split<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for wasmtime_environ::__core::slice::SplitInclusive<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitInclusiveMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for wasmtime_environ::__core::slice::SplitN<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitNMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, S, A> Sync for Difference<'a, T, S, A>
where S: Sync, A: Sync, T: Sync,



impl<'a, T, S, A> Sync for wasmtime_environ::collections::oom_abort::hash_set::Entry<'a, T, S, A>
where T: Sync, S: Sync, A: Sync,



impl<'a, T, S, A> Sync for Intersection<'a, T, S, A>
where S: Sync, A: Sync, T: Sync,



impl<'a, T, S, A> Sync for wasmtime_environ::collections::oom_abort::hash_set::OccupiedEntry<'a, T, S, A>
where T: Sync, S: Sync, A: Sync,



impl<'a, T, S, A> Sync for SymmetricDifference<'a, T, S, A>
where S: Sync, A: Sync, T: Sync,



impl<'a, T, S, A> Sync for wasmtime_environ::collections::oom_abort::hash_set::Union<'a, T, S, A>
where S: Sync, A: Sync, T: Sync,



impl<'a, T, S, A> Sync for wasmtime_environ::collections::oom_abort::hash_set::VacantEntry<'a, T, S, A>
where T: Sync, S: Sync, A: Sync,



impl<'a, T, const N: usize> Sync for ArrayWindows<'a, T, N>
where T: Sync,



impl<'a, T> Sync for Chunks<'a, T>
where T: Sync,



impl<'a, T> Sync for ChunksExact<'a, T>
where T: Sync,



impl<'a, T> Sync for wasmtime_environ::__core::result::Iter<'a, T>
where T: Sync,



impl<'a, T> Sync for wasmtime_environ::__core::result::IterMut<'a, T>
where T: Sync,



impl<'a, T> Sync for RChunks<'a, T>
where T: Sync,



impl<'a, T> Sync for RChunksExact<'a, T>
where T: Sync,



impl<'a, T> Sync for Windows<'a, T>
where T: Sync,



impl<'a, const N: usize> Sync for CharArraySearcher<'a, N>



impl<'a> !Sync for wasmtime_environ::error::Chain<'a>



impl<'a> !Sync for Context<'a>



impl<'a> !Sync for ContextBuilder<'a>



impl<'a> !Sync for Formatter<'a>



impl<'a> !Sync for PanicInfo<'a>



impl<'a> !Sync for PanicMessage<'a>



impl<'a> !Sync for Request<'a>



impl<'a> !Sync for Source<'a>



impl<'a> !Sync for VaList<'a>



impl<'a> Sync for AbstractInstantiations<'a>



impl<'a> Sync for BorrowedCursor<'a>



impl<'a> Sync for wasmtime_environ::__core::str::Bytes<'a>



impl<'a> Sync for CharIndices<'a>



impl<'a> Sync for CharSearcher<'a>



impl<'a> Sync for Chars<'a>



impl<'a> Sync for DebugInfoData<'a>



impl<'a> Sync for EncodeUtf16<'a>



impl<'a> Sync for EscapeAscii<'a>



impl<'a> Sync for wasmtime_environ::__core::str::EscapeDebug<'a>



impl<'a> Sync for wasmtime_environ::__core::str::EscapeDefault<'a>



impl<'a> Sync for wasmtime_environ::__core::str::EscapeUnicode<'a>



impl<'a> Sync for FlagValue<'a>



impl<'a> Sync for FlatTypes<'a>



impl<'a> Sync for Formatted<'a>



impl<'a> Sync for FrameStateSlot<'a>



impl<'a> Sync for FrameTable<'a>



impl<'a> Sync for FrameTableBreakpointData<'a>



impl<'a> Sync for FunctionBodyData<'a>



impl<'a> Sync for Lines<'a>



impl<'a> Sync for LinesAny<'a>



impl<'a> Sync for MemoryInit<'a>



impl<'a> Sync for MemoryInitializer<'a>



impl<'a> Sync for MemoryTunables<'a>



impl<'a> Sync for wasmtime_environ::fact::Module<'a>



impl<'a> Sync for NameSection<'a>



impl<'a> Sync for ObjectBuilder<'a>



impl<'a> Sync for Part<'a>



impl<'a> Sync for PhantomContravariantLifetime<'a>



impl<'a> Sync for PhantomCovariantLifetime<'a>



impl<'a> Sync for PhantomInvariantLifetime<'a>



impl<'a> Sync for SplitAsciiWhitespace<'a>



impl<'a> Sync for SplitWhitespace<'a>



impl<'a> Sync for StackMap<'a>



impl<'a> Sync for Utf8Chunk<'a>



impl<'a> Sync for Utf8Chunks<'a>



impl<'a> Sync for Utf8Pattern<'a>



impl<'b, T> !Sync for Ref<'b, T>



impl<'b, T> !Sync for RefMut<'b, T>



impl<'data> Sync for BorrowedBuf<'data>



impl<'data> Sync for ModuleTranslation<'data>



impl<A, B> Sync for wasmtime_environ::__core::iter::Chain<A, B>
where A: Sync, B: Sync,



impl<A, B> Sync for Zip<A, B>
where A: Sync, B: Sync,



impl<A> Sync for wasmtime_environ::__core::option::IntoIter<A>
where A: Sync,



impl<A> Sync for OptionFlatten<A>
where A: Sync,



impl<A> Sync for RangeFromIter<A>
where A: Sync,



impl<A> Sync for RangeInclusiveIter<A>
where A: Sync,



impl<A> Sync for RangeIter<A>
where A: Sync,



impl<A> Sync for wasmtime_environ::__core::iter::Repeat<A>
where A: Sync,



impl<A> Sync for RepeatN<A>
where A: Sync,



impl<B, C> Sync for ControlFlow<B, C>
where C: Sync, B: Sync,



impl<E, M> Sync for Capture<E, M>
where E: Sync, M: Sync,



impl<E> Sync for IterEntityRange<E>
where E: Sync,



impl<F> Sync for wasmtime_environ::__core::iter::FromFn<F>
where F: Sync,



impl<F> Sync for wasmtime_environ::__core::fmt::FromFn<F>
where F: Sync,



impl<F> Sync for OnceWith<F>
where F: Sync,



impl<F> Sync for PollFn<F>
where F: Sync,



impl<F> Sync for RepeatWith<F>
where F: Sync,



impl<G, F> Sync for FilterNodes<G, F>
where G: Sync, F: Sync,



impl<G> Sync for FromCoroutine<G>
where G: Sync,



impl<H> Sync for BuildHasherDefault<H>



impl<I, F, const N: usize> Sync for MapWindows<I, F, N>
where F: Sync, I: Sync, <I as Iterator>::Item: Sync,



impl<I, F> Sync for FilterMap<I, F>
where I: Sync, F: Sync,



impl<I, F> Sync for Inspect<I, F>
where I: Sync, F: Sync,



impl<I, F> Sync for Map<I, F>
where I: Sync, F: Sync,



impl<I, G> Sync for IntersperseWith<I, G>
where G: Sync, I: Sync, <I as Iterator>::Item: Sync,



impl<I, P> Sync for Filter<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for MapWhile<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for SkipWhile<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for TakeWhile<I, P>
where I: Sync, P: Sync,



impl<I, St, F> Sync for Scan<I, St, F>
where I: Sync, F: Sync, St: Sync,



impl<I, U, F> Sync for FlatMap<I, U, F>
where <U as IntoIterator>::IntoIter: Sync, I: Sync, F: Sync,



impl<I, const N: usize> Sync for ArrayChunks<I, N>
where I: Sync, <I as Iterator>::Item: Sync,



impl<I> Sync for Cloned<I>
where I: Sync,



impl<I> Sync for Copied<I>
where I: Sync,



impl<I> Sync for Cycle<I>
where I: Sync,



impl<I> Sync for DecodeUtf16<I>
where I: Sync,



impl<I> Sync for Enumerate<I>
where I: Sync,



impl<I> Sync for Flatten<I>
where <<I as Iterator>::Item as IntoIterator>::IntoIter: Sync, I: Sync,



impl<I> Sync for FromIter<I>
where I: Sync,



impl<I> Sync for Fuse<I>
where I: Sync,



impl<I> Sync for Intersperse<I>
where <I as Iterator>::Item: Sized + Sync, I: Sync,



impl<I> Sync for Peekable<I>
where I: Sync, <I as Iterator>::Item: Sync,



impl<I> Sync for Skip<I>
where I: Sync,



impl<I> Sync for StepBy<I>
where I: Sync,



impl<I> Sync for wasmtime_environ::__core::iter::Take<I>
where I: Sync,



impl<Idx> Sync for Clamp<Idx>
where Idx: Sync,



impl<Idx> Sync for wasmtime_environ::__core::ops::Range<Idx>
where Idx: Sync,



impl<Idx> Sync for wasmtime_environ::__core::range::Range<Idx>
where Idx: Sync,



impl<Idx> Sync for wasmtime_environ::__core::ops::RangeFrom<Idx>
where Idx: Sync,



impl<Idx> Sync for wasmtime_environ::__core::range::RangeFrom<Idx>
where Idx: Sync,



impl<Idx> Sync for wasmtime_environ::__core::ops::RangeInclusive<Idx>
where Idx: Sync,



impl<Idx> Sync for wasmtime_environ::__core::range::RangeInclusive<Idx>
where Idx: Sync,



impl<Idx> Sync for RangeTo<Idx>
where Idx: Sync,



impl<Idx> Sync for wasmtime_environ::__core::ops::RangeToInclusive<Idx>
where Idx: Sync,



impl<Idx> Sync for wasmtime_environ::__core::range::RangeToInclusive<Idx>
where Idx: Sync,



impl<K, A> Sync for wasmtime_environ::collections::oom_abort::hash_set::IntoIter<K, A>
where A: Sync, K: Sync,



impl<K, V, A> Sync for wasmtime_environ::collections::oom_abort::hash_map::IntoIter<K, V, A>
where A: Sync, K: Sync, V: Sync,



impl<K, V, A> Sync for IntoKeys<K, V, A>
where A: Sync, K: Sync, V: Sync,



impl<K, V, A> Sync for IntoValues<K, V, A>
where A: Sync, K: Sync, V: Sync,



impl<K, V, S, A> Sync for HashMap<K, V, S, A>
where S: Sync, A: Sync, K: Sync, V: Sync,



impl<K, V, S> Sync for TryHashMap<K, V, S>
where S: Sync, K: Sync, V: Sync,



impl<K, V, S> Sync for TryIndexMap<K, V, S>
where S: Sync, K: Sync, V: Sync,



impl<K, V> Sync for BTreeMapIntoIter<K, V>
where K: Sync, V: Sync,



impl<K, V> Sync for BoxedSlice<K, V>
where K: Sync, V: Sync,



impl<K, V> Sync for IndexMap<K, V>
where K: Sync, V: Sync,



impl<K, V> Sync for Intern<K, V>
where K: Sync, V: Sync,



impl<K, V> Sync for wasmtime_environ::IntoIter<K, V>
where K: Sync, V: Sync,



impl<K, V> Sync for NameMap<K, V>
where K: Sync, V: Sync,



impl<K, V> Sync for PrimaryMap<K, V>
where K: Sync, V: Sync,



impl<K, V> Sync for SecondaryMap<K, V>
where V: Sync, K: Sync,



impl<K, V> Sync for SparseMap<K, V>
where K: Sync, V: Sync,



impl<K, V> Sync for TryBTreeMap<K, V>
where K: Sync, V: Sync,



impl<K, V> Sync for TryPrimaryMap<K, V>
where K: Sync, V: Sync,



impl<K, V> Sync for TrySecondaryMap<K, V>
where V: Sync, K: Sync,



impl<K> Sync for EntitySet<K>
where K: Sync,



impl<K> Sync for wasmtime_environ::Keys<K>
where K: Sync,



impl<K> Sync for TryEntitySet<K>
where K: Sync,



impl<Node> Sync for Dfs<Node>
where Node: Sync,



impl<Node> Sync for DfsEvent<Node>
where Node: Sync,



impl<Node> Sync for EntityGraph<Node>
where Node: Sync,



impl<Node> Sync for StronglyConnectedComponents<Node>
where Node: Sync,



impl<P> Sync for MaybeDangling<P>
where P: Sync + ?Sized,



impl<P> Sync for VMComponentOffsets<P>
where P: Sync,



impl<P> Sync for VMOffsets<P>
where P: Sync,



impl<P> Sync for VMOffsetsFields<P>
where P: Sync,



impl<Ptr> Sync for Pin<Ptr>
where Ptr: Sync,



impl<T, A> Sync for Box<T, A>
where A: Sync, T: Sync + ?Sized,



impl<T, A> Sync for Vec<T, A>
where A: Sync, T: Sync,



impl<T, E> Sync for Result<T, E>
where T: Sync, E: Sync,



impl<T, F = fn() -> T> !Sync for LazyCell<T, F>



impl<T, F> Sync for DropGuard<T, F>
where T: Sync, F: Sync,



impl<T, F> Sync for Successors<T, F>
where F: Sync, T: Sync,



impl<T, F> Sync for Undo<T, F>
where T: Sync, F: Sync,



impl<T, S, A> Sync for HashSet<T, S, A>
where S: Sync, A: Sync, T: Sync,



impl<T, S> Sync for TryHashSet<T, S>
where S: Sync, T: Sync,



impl<T, U> Sync for wasmtime_environ::__core::io::Chain<T, U>
where T: Sync, U: Sync,



impl<T, const N: usize> Sync for wasmtime_environ::__core::array::IntoIter<T, N>
where T: Sync,



impl<T, const N: usize> Sync for Mask<T, N>
where T: Sync,



impl<T, const N: usize> Sync for Simd<T, N>
where T: Sync,



impl<T, const VARIANT: u32, const FIELD: u32> Sync for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,



impl<T> !Sync for ScopeVec<T>



impl<T> Sync for AssertUnwindSafe<T>
where T: Sync,



impl<T> Sync for Bound<T>
where T: Sync,



impl<T> Sync for wasmtime_environ::component::CoreExport<T>
where T: Sync,



impl<T> Sync for wasmtime_environ::component::dfg::CoreExport<T>
where T: Sync,



impl<T> Sync for wasmtime_environ::__core::io::Cursor<T>
where T: Sync,



impl<T> Sync for Discriminant<T>



impl<T> Sync for wasmtime_environ::__core::iter::Empty<T>



impl<T> Sync for EntityList<T>
where T: Sync,



impl<T> Sync for ExportItem<T>
where T: Sync,



impl<T> Sync for IndexSet<T>
where T: Sync,



impl<T> Sync for wasmtime_environ::__core::result::IntoIter<T>
where T: Sync,



impl<T> Sync for ListPool<T>
where T: Sync,



impl<T> Sync for ManuallyDrop<T>
where T: Sync + ?Sized,



impl<T> Sync for MaybeUninit<T>
where T: Sync,



impl<T> Sync for NumBuffer<T>
where T: Sync,



impl<T> Sync for Once<T>
where T: Sync,



impl<T> Sync for Option<T>
where T: Sync,



impl<T> Sync for PackedOption<T>
where T: Sync,



impl<T> Sync for Pending<T>



impl<T> Sync for PhantomContravariant<T>
where T: ?Sized,



impl<T> Sync for PhantomCovariant<T>
where T: ?Sized,



impl<T> Sync for PhantomData<T>
where T: Sync + ?Sized,



impl<T> Sync for PhantomInvariant<T>
where T: ?Sized,



impl<T> Sync for Poll<T>
where T: Sync,



impl<T> Sync for Ready<T>
where T: Sync,



impl<T> Sync for Rev<T>
where T: Sync,



impl<T> Sync for Reverse<T>
where T: Sync,



impl<T> Sync for Saturating<T>
where T: Sync,



impl<T> Sync for wasmtime_environ::__core::io::Take<T>
where T: Sync,



impl<T> Sync for TraitImpl<T>
where T: ?Sized,



impl<T> Sync for TryVec<T>
where T: Sync,



impl<T> Sync for Wrapper<T>
where T: Sync,



impl<T> Sync for Wrapping<T>
where T: Sync,



impl<T> Sync for Yeet<T>
where T: Sync,



impl<Y, R> Sync for CoroutineState<Y, R>
where Y: Sync, R: Sync,