pub struct ComponentExternData {
pub implements: Option<String>,
pub external_id: Option<String>,
}Expand description
Metadata associated with the name of a component import or export.
Fields
implements: Option<String>The (implements "...") annotation, if present: the name of the
interface that this item implements, used when matching this item
against imports by interface name rather than by import name.
external_id: Option<String>The (external-id "...") annotation, if present: a free-form
host-defined identifier which is ignored by type checking.