pub struct TypeMap {
pub key: InterfaceType,
pub value: InterfaceType,
pub entry_abi: CanonicalAbiInfo,
pub value_offset32: u32,
pub value_offset64: u32,
}Expand description
Shape of a “map” interface type.
Fields
key: InterfaceTypeThe key type of the map.
value: InterfaceTypeThe value type of the map.
entry_abi: CanonicalAbiInfoByte information for each map entry represented as tuple<key, value>.
value_offset32: u32Offset in bytes from the start of the entry tuple to the value field in memory32.
value_offset64: u32Offset in bytes from the start of the entry tuple to the value field in memory64.