InlineTraceInfo

Enum InlineTraceInfo 

pub enum InlineTraceInfo {
    OutOfLine,
    Array {
        elems_are_gc_refs: bool,
    },
    Struct {
        gc_ref_bitmap: u32,
    },
}
The inline trace info encoded in a VMCopyingHeader’s reserved bits.

Variants



OutOfLine

The trace info is not encoded inline. Look it up from TraceInfos.



Array

Inline trace info for an array type.

Fields

elems_are_gc_refs: bool

Whether the array’s elements are GC references that need tracing.



Struct

Inline trace info for a struct, exception, or externref type.

Fields

gc_ref_bitmap: u32

A bitmap where the ith bit is set iff the ith u32 in the object’s data (after the header) is a VMGcRef that needs tracing. Only the lower 23 bits are meaningful.

Implementations

Source

impl InlineTraceInfo

pub const NO_GC_EDGES: InlineTraceInfo

Inline trace info for an object with no GC-reference edges (e.g. externrefs). This is a Struct with an empty bitmap.

pub fn new(layout: &GcLayout) -> Self

Create inline trace info for the given GC layout.

pub fn array(layout: &GcArrayLayout) -> Self

Create inline trace info for an array type.

Arrays can always be represented inline (only one bit of payload is needed), so this never returns OutOfLine.

pub fn struct(layout: &GcStructLayout) -> Self

Create inline trace info for a struct or exception type.

Returns OutOfLine only when there is a GC-reference field whose offset cannot be represented in the 23-bit bitmap. Non-GC-reference fields are ignored regardless of offset.

pub fn encode(&self) -> u32

Encode this inline trace info as its bit-packed representation for storage in a VMGcHeader’s reserved bits.

pub fn decode(reserved: u32) -> Self

Decode inline trace info from the reserved bits of a VMGcHeader.