VMGcKind

Enum VMGcKind 

#[repr(u32)]
pub enum VMGcKind { ExternRef = 1_073_741_824, AnyRef = 2_147_483_648, EqRef = 2_684_354_560, ArrayRef = 2_818_572_288, StructRef = 2_952_790_016, ExnRef = 67_108_864, }
The kind of an object in a GC heap.

Note that this type is accessed from Wasm JIT code.

VMGcKind is a bitset where to test if a is a subtype of an “abstract-ish” type b, we can simply use a single bitwise-and operation:

a <: b   iff   a & b == b

For example, because VMGcKind::AnyRef has the high bit set, every kind representing some subtype of anyref also has its high bit set.

We say “abstract-ish” type because in addition to the abstract heap types (other than i31) we also have variants for externrefs that have been converted into an anyref via extern.convert_any and externrefs that have been converted into an anyref via any.convert_extern. Note that in the latter case, because any.convert_extern $foo produces a value that is not an instance of eqref, VMGcKind::AnyOfExternRef & VMGcKind::EqRef != VMGcKind::EqRef.

Furthermore, this type only uses the highest 6 bits of its u32 representation, allowing the lower 26 bits to be bitpacked with other stuff as users see fit.

Variants



ExternRef = 1_073_741_824



AnyRef = 2_147_483_648



EqRef = 2_684_354_560



ArrayRef = 2_818_572_288



StructRef = 2_952_790_016



ExnRef = 67_108_864

Implementations

Source

impl VMGcKind

pub const MASK: u32

Mask this value with a u32 to get just the bits that VMGcKind uses.

pub const UNUSED_MASK: u32

Mask this value with a u32 that potentially contains a VMGcKind to get the bits that VMGcKind doesn’t use.

pub fn value_fits_in_unused_bits(value: u32) -> bool

Does the given value fit in the unused bits of a VMGcKind?

pub fn from_high_bits_of_u32(val: u32) -> VMGcKind

Convert the given value into a VMGcKind by masking off the unused bottom bits.

pub fn matches(self, other: Self) -> bool

Does this kind match the other kind?

That is, is this kind a subtype of the other kind?

pub fn as_u32(self) -> u32

Get this VMGcKind as a raw u32.

pub fn try_from_u32(x: u32) -> Option<VMGcKind>

Try to convert a u32 into a VMGcKind.

Returns None if the value doesn’t match any known kind.