VMDeferredThread

Struct VMDeferredThread 

pub struct VMDeferredThread<P: PtrSize>(pub P);
Offsets of fields within the VMDeferredThread type.

Tuple Fields

0: P

Implementations

Source

impl<P: PtrSize> VMDeferredThread<P>

pub fn parent(&self) -> u8

The offset of the parent field of VMDeferredThread.

pub fn caller_instance(&self) -> u8

The offset of the caller_instance field of VMDeferredThread.

pub fn callee_async(&self) -> u8

The offset of the callee_async field of VMDeferredThread.

pub fn callee_instance(&self) -> u8

The offset of the callee_instance field of VMDeferredThread.

pub fn saved_context(&self) -> u8

The offset of the saved_context field of VMDeferredThread.

pub fn align(&self) -> u8

The alignment of the VMDeferredThread type.

pub fn size(&self) -> u8

The size of the VMDeferredThread type.

Source

impl<P: PtrSize> VMDeferredThread<P>

Offsets within a VMDeferredThread that are not simply the offset of one of its fields, and so are not generated by for_each_vm_type!.

pub fn saved_context_slot(&self, i: u8) -> u8

The offset of the saved_context[i] slot within a VMDeferredThread.