VMStoreContext

Struct VMStoreContext 

pub struct VMStoreContext<P: PtrSize>(pub P);
Offsets of fields within the VMStoreContext type.

Tuple Fields

0: P

Implementations

Source

impl<P: PtrSize> VMStoreContext<P>

pub fn fuel_consumed(&self) -> u8

The offset of the fuel_consumed field of VMStoreContext.

pub fn epoch_deadline(&self) -> u8

The offset of the epoch_deadline field of VMStoreContext.

pub fn execution_version(&self) -> u8

The offset of the execution_version field of VMStoreContext.

pub fn stack_limit(&self) -> u8

The offset of the stack_limit field of VMStoreContext.

pub fn gc_heap(&self) -> u8

The offset of the gc_heap field of VMStoreContext.

pub fn last_wasm_exit_trampoline_fp(&self) -> u8

The offset of the last_wasm_exit_trampoline_fp field of VMStoreContext.

pub fn last_wasm_exit_pc(&self) -> u8

The offset of the last_wasm_exit_pc field of VMStoreContext.

pub fn last_wasm_entry_sp(&self) -> u8

The offset of the last_wasm_entry_sp field of VMStoreContext.

pub fn last_wasm_entry_fp(&self) -> u8

The offset of the last_wasm_entry_fp field of VMStoreContext.

pub fn last_wasm_entry_trap_handler(&self) -> u8

The offset of the last_wasm_entry_trap_handler field of VMStoreContext.

pub fn stack_chain(&self) -> u8

The offset of the stack_chain field of VMStoreContext.

pub fn store_data(&self) -> u8

The offset of the store_data field of VMStoreContext.

pub fn async_guard_range(&self) -> u8

The offset of the async_guard_range field of VMStoreContext.

pub fn component_context(&self) -> u8

The offset of the component_context field of VMStoreContext.

pub fn current_thread(&self) -> u8

The offset of the current_thread field of VMStoreContext.

pub fn align(&self) -> u8

The alignment of the VMStoreContext type.

pub fn size(&self) -> u8

The size of the VMStoreContext type.

Source

impl<P: PtrSize> VMStoreContext<P>

Offsets within a VMStoreContext that are not simply the offset of one of its fields, and so are not generated by for_each_vm_type!.

pub fn gc_heap_base(&self) -> u8

The offset of the gc_heap.base field within a VMStoreContext.

pub fn gc_heap_current_length(&self) -> u8

The offset of the gc_heap.current_length field within a VMStoreContext.

pub fn component_context_slot(&self, i: u8) -> u8

The offset of the component_context[i] slot within a VMStoreContext.