pub struct ArrayOffsets<I> { /* private fields */ }Expand description
The offsets of one array field within a vmctx.
Implementations
Sourceimpl<I> ArrayOffsets<I>
impl<I> ArrayOffsets<I>
Sourcepub fn new(begin: u32, stride: u32, count: u32) -> Self
pub fn new(begin: u32, stride: u32, count: u32) -> Self
Create the offsets for an array of count elements which begins at
begin within its vmctx and whose elements are stride bytes apart.
Sourceimpl<I: VmctxArrayIndex> ArrayOffsets<I>
impl<I: VmctxArrayIndex> ArrayOffsets<I>