pub struct ComponentPC(/* private fields */);Expand description
A Wasm bytecode offset relative to the start of a component (or top-level module) binary.
When compiling a component, the Wasm parser returns source
positions relative to the entire component binary. This type
captures that convention. Use
ComponentPC::to_module_pc to convert to a
ModulePC given the byte offset of the module within the
component.
Implementations
Sourceimpl ComponentPC
impl ComponentPC
Sourcepub fn to_module_pc(self, wasm_module_offset: u64) -> ModulePC
pub fn to_module_pc(self, wasm_module_offset: u64) -> ModulePC
Convert to a module-relative PC by subtracting the byte offset of the module within the component binary.