pub struct MemoryInitializer<'a> {
pub memory_index: MemoryIndex,
pub offset: ConstExpr,
pub data: &'a [u8],
}Expand description
A WebAssembly linear memory initializer.
Fields
memory_index: MemoryIndexThe index of a linear memory to initialize.
offset: ConstExprThe base offset to start this segment at.
data: &'a [u8]The range of the data to write within the linear memory.
This range indexes into a separately stored data section which will be provided with the compiled module’s code as well.