MemoryTunables

Struct MemoryTunables 

pub struct MemoryTunables<'a> { /* private fields */ }
A view into a Tunables that selects the appropriate linear-memory or GC-heap flavor of each tunable based on a MemoryKind.

Implementations

Source

impl<'a> MemoryTunables<'a>

pub fn new(tunables: &'a Tunables, kind: MemoryKind) -> Self

Create a new MemoryTunables view.

pub fn reservation(&self) -> u64

The virtual memory reservation for this kind of memory.

pub fn guard_size(&self) -> u64

The size of the guard page region for this kind of memory.

pub fn reservation_for_growth(&self) -> u64

Extra virtual memory to reserve beyond the initially mapped pages for this kind of memory.

pub fn may_move(&self) -> bool

Whether this kind of memory’s base pointer may be relocated at runtime.

pub fn tunables(&self) -> &'a Tunables

Get the underlying tunables.

This is ONLY for accessing tunable fields that DO NOT come in a linear-memory flavor and a GC-heap flavor.