pub struct RuntimeDataIndex(/* private fields */);Expand description
Index into data segments needed at runtime by a module.
This does not directly correspond to either active or passive data segments
in the wasm spec. Instead this is a concept purely for Wasmtime and
organizing memory initialization within the
ModuleTranslation::finalize_memory_init function, for example.
Passive data segments at runtime all have a corresponding
RuntimeDataIndex, but active data segments maybe coalesced or mutated if
they’re statically evaluated.
Implementations
Sourceimpl RuntimeDataIndex
impl RuntimeDataIndex
Sourcepub fn as_bits(self) -> u32
pub fn as_bits(self) -> u32
Return the raw bit encoding for this instance.
Warning: the raw bit encoding is opaque and has no
guaranteed correspondence to the entity’s index. It encodes the
entire state of this index value: either a valid index or an
invalid-index sentinel. The value returned by this method should
only be passed to from_bits.
Sourcepub fn from_bits(x: u32) -> Self
pub fn from_bits(x: u32) -> Self
Create a new instance from the raw bit encoding.
Warning: the raw bit encoding is opaque and has no
guaranteed correspondence to the entity’s index. It encodes the
entire state of this index value: either a valid index or an
invalid-index sentinel. The value returned by this method should
only be given bits from as_bits.