PtrSize

Trait PtrSize 

pub trait PtrSize {
Show 32 methods // Required method fn size(&self) -> u8; // Provided methods fn vm_memory_definition(&self) -> VMMemoryDefinition<&Self> { ... } fn vm_table_definition(&self) -> VMTableDefinition<&Self> { ... } fn vm_global_definition(&self) -> VMGlobalDefinition<&Self> { ... } fn vm_tag_definition(&self) -> VMTagDefinition<&Self> { ... } fn vm_func_ref(&self) -> VMFuncRef<&Self> { ... } fn vm_function_import(&self) -> VMFunctionImport<&Self> { ... } fn vm_table_import(&self) -> VMTableImport<&Self> { ... } fn vm_memory_import(&self) -> VMMemoryImport<&Self> { ... } fn vm_global_import(&self) -> VMGlobalImport<&Self> { ... } fn vm_tag_import(&self) -> VMTagImport<&Self> { ... } fn vm_store_context(&self) -> VMStoreContext<&Self> { ... } fn vm_lazy_thread(&self) -> VMLazyThread<&Self> { ... } fn vm_deferred_thread(&self) -> VMDeferredThread<&Self> { ... } fn vm_stack_limits(&self) -> VMStackLimits<&Self> { ... } fn vm_host_array(&self) -> VMHostArray<&Self> { ... } fn vm_common_stack_information(&self) -> VMCommonStackInformation<&Self> { ... } fn vm_cont_ref(&self) -> VMContRef<&Self> { ... } fn vm_drc_heap_data(&self) -> VMDrcHeapData<&Self> { ... } fn vm_copying_heap_data(&self) -> VMCopyingHeapData<&Self> { ... } fn vm_null_heap_data(&self) -> VMNullHeapData<&Self> { ... } fn vmctx(&self) -> VMContext<&Self> { ... } fn vmcomponent(&self) -> VMComponentContext<&Self> { ... } fn size_of_vmshared_type_index(&self) -> u8 { ... } fn align_of_vmshared_type_index(&self) -> u8 { ... } fn maximum_value_size(&self) -> u8 { ... } fn size_of_vmmemory_pointer(&self) -> u8 { ... } fn vmarray_call_host_func_context_func_ref(&self) -> u8 { ... } fn size_of_vmstack_chain(&self) -> u8 { ... } fn vmcontobj_contref(&self) -> u8 { ... } fn vmcontobj_revision(&self) -> u8 { ... } fn size_of_vmcontobj(&self) -> u8 { ... }
}
Trait used for the ptr representation of the field of VMOffsets

Required Methods

fn size(&self) -> u8

Returns the pointer size, in bytes, for the target.

Provided Methods

fn vm_memory_definition(&self) -> VMMemoryDefinition<&Self>

Get the offsets::VMMemoryDefinition offsets for this pointer size.

fn vm_table_definition(&self) -> VMTableDefinition<&Self>

Get the offsets::VMTableDefinition offsets for this pointer size.

fn vm_global_definition(&self) -> VMGlobalDefinition<&Self>

Get the offsets::VMGlobalDefinition offsets for this pointer size.

fn vm_tag_definition(&self) -> VMTagDefinition<&Self>

Get the offsets::VMTagDefinition offsets for this pointer size.

fn vm_func_ref(&self) -> VMFuncRef<&Self>

Get the offsets::VMFuncRef offsets for this pointer size.

fn vm_function_import(&self) -> VMFunctionImport<&Self>

Get the offsets::VMFunctionImport offsets for this pointer size.

fn vm_table_import(&self) -> VMTableImport<&Self>

Get the offsets::VMTableImport offsets for this pointer size.

fn vm_memory_import(&self) -> VMMemoryImport<&Self>

Get the offsets::VMMemoryImport offsets for this pointer size.

fn vm_global_import(&self) -> VMGlobalImport<&Self>

Get the offsets::VMGlobalImport offsets for this pointer size.

fn vm_tag_import(&self) -> VMTagImport<&Self>

Get the offsets::VMTagImport offsets for this pointer size.

fn vm_store_context(&self) -> VMStoreContext<&Self>

Get the offsets::VMStoreContext offsets for this pointer size.

fn vm_lazy_thread(&self) -> VMLazyThread<&Self>

Get the offsets::VMLazyThread offsets for this pointer size.

fn vm_deferred_thread(&self) -> VMDeferredThread<&Self>

Get the offsets::VMDeferredThread offsets for this pointer size.

fn vm_stack_limits(&self) -> VMStackLimits<&Self>

Get the offsets::VMStackLimits offsets for this pointer size.

fn vm_host_array(&self) -> VMHostArray<&Self>

Get the offsets::VMHostArray offsets for this pointer size.

fn vm_common_stack_information(&self) -> VMCommonStackInformation<&Self>

Get the offsets::VMCommonStackInformation offsets for this pointer size.

fn vm_cont_ref(&self) -> VMContRef<&Self>

Get the offsets::VMContRef offsets for this pointer size.

fn vm_drc_heap_data(&self) -> VMDrcHeapData<&Self>

Get the offsets::VMDrcHeapData offsets for this pointer size.

fn vm_copying_heap_data(&self) -> VMCopyingHeapData<&Self>

Get the offsets::VMCopyingHeapData offsets for this pointer size.

fn vm_null_heap_data(&self) -> VMNullHeapData<&Self>

Get the offsets::VMNullHeapData offsets for this pointer size.

fn vmctx(&self) -> VMContext<&Self>

Get the offsets::VMContext offsets for this pointer size.

fn vmcomponent(&self) -> VMComponentContext<&Self>

Get the offsets::VMComponentContext offsets for this pointer size.

fn size_of_vmshared_type_index(&self) -> u8

Return the size of VMSharedTypeIndex.

fn align_of_vmshared_type_index(&self) -> u8

Return the alignment of VMSharedTypeIndex.

fn maximum_value_size(&self) -> u8

This is the size of the largest value type (i.e. a V128).

fn size_of_vmmemory_pointer(&self) -> u8

Return the size of *mut VMMemoryDefinition.

fn vmarray_call_host_func_context_func_ref(&self) -> u8

Return the offset of VMArrayCallHostFuncContext::func_ref.

fn size_of_vmstack_chain(&self) -> u8

Return the size of VMStackChain.

fn vmcontobj_contref(&self) -> u8

Return the offset of VMContObj::contref

fn vmcontobj_revision(&self) -> u8

Return the offset of VMContObj::revision

fn size_of_vmcontobj(&self) -> u8

Return the size of VMContObj.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl PtrSize for u8

Source

fn size(&self) -> u8

Source

impl<P> PtrSize for &P
where P: PtrSize + ?Sized,

Source

fn size(&self) -> u8

Implementors