pub enum ModuleStartup {
None,
Always(EngineOrModuleTypeIndex),
IfMemoriesNeedInit(EngineOrModuleTypeIndex),
}Expand description
Different means of startup for a wasm module.
Variants
None
No startup is necessary.
Always(EngineOrModuleTypeIndex)
Startup is always required, for example to apply active table segments.
The type of the startup function, of wasm signature [] -> [], is
provided here.
IfMemoriesNeedInit(EngineOrModuleTypeIndex)
Startup is only required if some linear memory within this module, at
runtime, says needs_init() == true.
This special mode of startup indicates that the startup function has no
purpose other than to initialize the initial contents of
MemoryInitialization::Static linear memories. In this situation if all
memories say needs_init() == false then the startup function won’t
actually do anything meaning that it can be optimized slightly by
skipping it entirely.
Implementations