pub struct VMDeferredThread<P: PtrSize>(pub P);Expand description
Offsets of fields within the VMDeferredThread type.
Tuple Fields
0: PImplementations
Sourceimpl<P: PtrSize> VMDeferredThread<P>
impl<P: PtrSize> VMDeferredThread<P>
Sourcepub fn caller_instance(&self) -> u8
pub fn caller_instance(&self) -> u8
The offset of the caller_instance field of VMDeferredThread.
Sourcepub fn callee_async(&self) -> u8
pub fn callee_async(&self) -> u8
The offset of the callee_async field of VMDeferredThread.
Sourcepub fn callee_instance(&self) -> u8
pub fn callee_instance(&self) -> u8
The offset of the callee_instance field of VMDeferredThread.
Sourcepub fn saved_context(&self) -> u8
pub fn saved_context(&self) -> u8
The offset of the saved_context field of VMDeferredThread.
Sourceimpl<P: PtrSize> VMDeferredThread<P>
Offsets within a VMDeferredThread that are not simply the offset of one of
its fields, and so are not generated by for_each_vm_type!.
impl<P: PtrSize> VMDeferredThread<P>
Offsets within a VMDeferredThread that are not simply the offset of one of
its fields, and so are not generated by for_each_vm_type!.
Sourcepub fn saved_context_slot(&self, i: u8) -> u8
pub fn saved_context_slot(&self, i: u8) -> u8
The offset of the saved_context[i] slot within a VMDeferredThread.