pub struct VMStoreContext<P: PtrSize>(pub P);Expand description
Offsets of fields within the VMStoreContext type.
Tuple Fields
0: PImplementations
Sourceimpl<P: PtrSize> VMStoreContext<P>
impl<P: PtrSize> VMStoreContext<P>
Sourcepub fn fuel_consumed(&self) -> u8
pub fn fuel_consumed(&self) -> u8
The offset of the fuel_consumed field of VMStoreContext.
Sourcepub fn epoch_deadline(&self) -> u8
pub fn epoch_deadline(&self) -> u8
The offset of the epoch_deadline field of VMStoreContext.
Sourcepub fn execution_version(&self) -> u8
pub fn execution_version(&self) -> u8
The offset of the execution_version field of VMStoreContext.
Sourcepub fn stack_limit(&self) -> u8
pub fn stack_limit(&self) -> u8
The offset of the stack_limit field of VMStoreContext.
Sourcepub fn last_wasm_exit_trampoline_fp(&self) -> u8
pub fn last_wasm_exit_trampoline_fp(&self) -> u8
The offset of the last_wasm_exit_trampoline_fp field of VMStoreContext.
Sourcepub fn last_wasm_exit_pc(&self) -> u8
pub fn last_wasm_exit_pc(&self) -> u8
The offset of the last_wasm_exit_pc field of VMStoreContext.
Sourcepub fn last_wasm_entry_sp(&self) -> u8
pub fn last_wasm_entry_sp(&self) -> u8
The offset of the last_wasm_entry_sp field of VMStoreContext.
Sourcepub fn last_wasm_entry_fp(&self) -> u8
pub fn last_wasm_entry_fp(&self) -> u8
The offset of the last_wasm_entry_fp field of VMStoreContext.
Sourcepub fn last_wasm_entry_trap_handler(&self) -> u8
pub fn last_wasm_entry_trap_handler(&self) -> u8
The offset of the last_wasm_entry_trap_handler field of VMStoreContext.
Sourcepub fn stack_chain(&self) -> u8
pub fn stack_chain(&self) -> u8
The offset of the stack_chain field of VMStoreContext.
Sourcepub fn store_data(&self) -> u8
pub fn store_data(&self) -> u8
The offset of the store_data field of VMStoreContext.
Sourcepub fn async_guard_range(&self) -> u8
pub fn async_guard_range(&self) -> u8
The offset of the async_guard_range field of VMStoreContext.
Sourcepub fn component_context(&self) -> u8
pub fn component_context(&self) -> u8
The offset of the component_context field of VMStoreContext.
Sourcepub fn current_thread(&self) -> u8
pub fn current_thread(&self) -> u8
The offset of the current_thread field of VMStoreContext.
Sourceimpl<P: PtrSize> VMStoreContext<P>
Offsets within a VMStoreContext that are not simply the offset of one of
its fields, and so are not generated by for_each_vm_type!.
impl<P: PtrSize> VMStoreContext<P>
Offsets within a VMStoreContext that are not simply the offset of one of
its fields, and so are not generated by for_each_vm_type!.
Sourcepub fn gc_heap_base(&self) -> u8
pub fn gc_heap_base(&self) -> u8
The offset of the gc_heap.base field within a VMStoreContext.
Sourcepub fn gc_heap_current_length(&self) -> u8
pub fn gc_heap_current_length(&self) -> u8
The offset of the gc_heap.current_length field within a
VMStoreContext.
Sourcepub fn component_context_slot(&self, i: u8) -> u8
pub fn component_context_slot(&self, i: u8) -> u8
The offset of the component_context[i] slot within a VMStoreContext.