pub struct MemoryTunables<'a> { /* private fields */ }Expand description
A view into a Tunables that selects the appropriate linear-memory or
GC-heap flavor of each tunable based on a MemoryKind.
Implementations
Sourceimpl<'a> MemoryTunables<'a>
impl<'a> MemoryTunables<'a>
Sourcepub fn new(tunables: &'a Tunables, kind: MemoryKind) -> Self
pub fn new(tunables: &'a Tunables, kind: MemoryKind) -> Self
Create a new MemoryTunables view.
Sourcepub fn reservation(&self) -> u64
pub fn reservation(&self) -> u64
The virtual memory reservation for this kind of memory.
Sourcepub fn guard_size(&self) -> u64
pub fn guard_size(&self) -> u64
The size of the guard page region for this kind of memory.
Sourcepub fn reservation_for_growth(&self) -> u64
pub fn reservation_for_growth(&self) -> u64
Extra virtual memory to reserve beyond the initially mapped pages for this kind of memory.