pub trait PtrSize {
Show 32 methods
// Required method
fn size(&self) -> u8;
// Provided methods
fn vm_memory_definition(&self) -> VMMemoryDefinition<&Self> { ... }
fn vm_table_definition(&self) -> VMTableDefinition<&Self> { ... }
fn vm_global_definition(&self) -> VMGlobalDefinition<&Self> { ... }
fn vm_tag_definition(&self) -> VMTagDefinition<&Self> { ... }
fn vm_func_ref(&self) -> VMFuncRef<&Self> { ... }
fn vm_function_import(&self) -> VMFunctionImport<&Self> { ... }
fn vm_table_import(&self) -> VMTableImport<&Self> { ... }
fn vm_memory_import(&self) -> VMMemoryImport<&Self> { ... }
fn vm_global_import(&self) -> VMGlobalImport<&Self> { ... }
fn vm_tag_import(&self) -> VMTagImport<&Self> { ... }
fn vm_store_context(&self) -> VMStoreContext<&Self> { ... }
fn vm_lazy_thread(&self) -> VMLazyThread<&Self> { ... }
fn vm_deferred_thread(&self) -> VMDeferredThread<&Self> { ... }
fn vm_stack_limits(&self) -> VMStackLimits<&Self> { ... }
fn vm_host_array(&self) -> VMHostArray<&Self> { ... }
fn vm_common_stack_information(&self) -> VMCommonStackInformation<&Self> { ... }
fn vm_cont_ref(&self) -> VMContRef<&Self> { ... }
fn vm_drc_heap_data(&self) -> VMDrcHeapData<&Self> { ... }
fn vm_copying_heap_data(&self) -> VMCopyingHeapData<&Self> { ... }
fn vm_null_heap_data(&self) -> VMNullHeapData<&Self> { ... }
fn vmctx(&self) -> VMContext<&Self> { ... }
fn vmcomponent(&self) -> VMComponentContext<&Self> { ... }
fn size_of_vmshared_type_index(&self) -> u8 { ... }
fn align_of_vmshared_type_index(&self) -> u8 { ... }
fn maximum_value_size(&self) -> u8 { ... }
fn size_of_vmmemory_pointer(&self) -> u8 { ... }
fn vmarray_call_host_func_context_func_ref(&self) -> u8 { ... }
fn size_of_vmstack_chain(&self) -> u8 { ... }
fn vmcontobj_contref(&self) -> u8 { ... }
fn vmcontobj_revision(&self) -> u8 { ... }
fn size_of_vmcontobj(&self) -> u8 { ... }
}Expand description
Trait used for the ptr representation of the field of VMOffsets
Required Methods
Provided Methods
Sourcefn vm_memory_definition(&self) -> VMMemoryDefinition<&Self>
fn vm_memory_definition(&self) -> VMMemoryDefinition<&Self>
Get the offsets::VMMemoryDefinition offsets for this pointer size.
Sourcefn vm_table_definition(&self) -> VMTableDefinition<&Self>
fn vm_table_definition(&self) -> VMTableDefinition<&Self>
Get the offsets::VMTableDefinition offsets for this pointer size.
Sourcefn vm_global_definition(&self) -> VMGlobalDefinition<&Self>
fn vm_global_definition(&self) -> VMGlobalDefinition<&Self>
Get the offsets::VMGlobalDefinition offsets for this pointer size.
Sourcefn vm_tag_definition(&self) -> VMTagDefinition<&Self>
fn vm_tag_definition(&self) -> VMTagDefinition<&Self>
Get the offsets::VMTagDefinition offsets for this pointer size.
Sourcefn vm_func_ref(&self) -> VMFuncRef<&Self>
fn vm_func_ref(&self) -> VMFuncRef<&Self>
Get the offsets::VMFuncRef offsets for this pointer size.
Sourcefn vm_function_import(&self) -> VMFunctionImport<&Self>
fn vm_function_import(&self) -> VMFunctionImport<&Self>
Get the offsets::VMFunctionImport offsets for this pointer size.
Sourcefn vm_table_import(&self) -> VMTableImport<&Self>
fn vm_table_import(&self) -> VMTableImport<&Self>
Get the offsets::VMTableImport offsets for this pointer size.
Sourcefn vm_memory_import(&self) -> VMMemoryImport<&Self>
fn vm_memory_import(&self) -> VMMemoryImport<&Self>
Get the offsets::VMMemoryImport offsets for this pointer size.
Sourcefn vm_global_import(&self) -> VMGlobalImport<&Self>
fn vm_global_import(&self) -> VMGlobalImport<&Self>
Get the offsets::VMGlobalImport offsets for this pointer size.
Sourcefn vm_tag_import(&self) -> VMTagImport<&Self>
fn vm_tag_import(&self) -> VMTagImport<&Self>
Get the offsets::VMTagImport offsets for this pointer size.
Sourcefn vm_store_context(&self) -> VMStoreContext<&Self>
fn vm_store_context(&self) -> VMStoreContext<&Self>
Get the offsets::VMStoreContext offsets for this pointer size.
Sourcefn vm_lazy_thread(&self) -> VMLazyThread<&Self>
fn vm_lazy_thread(&self) -> VMLazyThread<&Self>
Get the offsets::VMLazyThread offsets for this pointer size.
Sourcefn vm_deferred_thread(&self) -> VMDeferredThread<&Self>
fn vm_deferred_thread(&self) -> VMDeferredThread<&Self>
Get the offsets::VMDeferredThread offsets for this pointer size.
Sourcefn vm_stack_limits(&self) -> VMStackLimits<&Self>
fn vm_stack_limits(&self) -> VMStackLimits<&Self>
Get the offsets::VMStackLimits offsets for this pointer size.
Sourcefn vm_host_array(&self) -> VMHostArray<&Self>
fn vm_host_array(&self) -> VMHostArray<&Self>
Get the offsets::VMHostArray offsets for this pointer size.
Sourcefn vm_common_stack_information(&self) -> VMCommonStackInformation<&Self>
fn vm_common_stack_information(&self) -> VMCommonStackInformation<&Self>
Get the offsets::VMCommonStackInformation offsets for this pointer size.
Sourcefn vm_cont_ref(&self) -> VMContRef<&Self>
fn vm_cont_ref(&self) -> VMContRef<&Self>
Get the offsets::VMContRef offsets for this pointer size.
Sourcefn vm_drc_heap_data(&self) -> VMDrcHeapData<&Self>
fn vm_drc_heap_data(&self) -> VMDrcHeapData<&Self>
Get the offsets::VMDrcHeapData offsets for this pointer size.
Sourcefn vm_copying_heap_data(&self) -> VMCopyingHeapData<&Self>
fn vm_copying_heap_data(&self) -> VMCopyingHeapData<&Self>
Get the offsets::VMCopyingHeapData offsets for this pointer size.
Sourcefn vm_null_heap_data(&self) -> VMNullHeapData<&Self>
fn vm_null_heap_data(&self) -> VMNullHeapData<&Self>
Get the offsets::VMNullHeapData offsets for this pointer size.
Sourcefn vmctx(&self) -> VMContext<&Self>
fn vmctx(&self) -> VMContext<&Self>
Get the offsets::VMContext offsets for this pointer size.
Sourcefn vmcomponent(&self) -> VMComponentContext<&Self>
fn vmcomponent(&self) -> VMComponentContext<&Self>
Get the offsets::VMComponentContext offsets for this pointer size.
Return the size of VMSharedTypeIndex.
Return the alignment of VMSharedTypeIndex.
Sourcefn maximum_value_size(&self) -> u8
fn maximum_value_size(&self) -> u8
This is the size of the largest value type (i.e. a V128).
Sourcefn size_of_vmmemory_pointer(&self) -> u8
fn size_of_vmmemory_pointer(&self) -> u8
Return the size of *mut VMMemoryDefinition.
Sourcefn vmarray_call_host_func_context_func_ref(&self) -> u8
fn vmarray_call_host_func_context_func_ref(&self) -> u8
Return the offset of VMArrayCallHostFuncContext::func_ref.
Sourcefn size_of_vmstack_chain(&self) -> u8
fn size_of_vmstack_chain(&self) -> u8
Return the size of VMStackChain.
Sourcefn vmcontobj_contref(&self) -> u8
fn vmcontobj_contref(&self) -> u8
Return the offset of VMContObj::contref
Sourcefn vmcontobj_revision(&self) -> u8
fn vmcontobj_revision(&self) -> u8
Return the offset of VMContObj::revision
Sourcefn size_of_vmcontobj(&self) -> u8
fn size_of_vmcontobj(&self) -> u8
Return the size of VMContObj.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".