PtrSize

Trait PtrSize 

pub trait PtrSize {
Show 54 methods // Required method fn size(&self) -> u8; // Provided methods fn vm_memory_definition(&self) -> VMMemoryDefinition<&Self> { ... } fn vm_table_definition(&self) -> VMTableDefinition<&Self> { ... } fn vm_global_definition(&self) -> VMGlobalDefinition<&Self> { ... } fn vm_tag_definition(&self) -> VMTagDefinition<&Self> { ... } fn vm_func_ref(&self) -> VMFuncRef<&Self> { ... } fn vm_function_import(&self) -> VMFunctionImport<&Self> { ... } fn vm_table_import(&self) -> VMTableImport<&Self> { ... } fn vm_memory_import(&self) -> VMMemoryImport<&Self> { ... } fn vm_global_import(&self) -> VMGlobalImport<&Self> { ... } fn vm_tag_import(&self) -> VMTagImport<&Self> { ... } fn vm_store_context(&self) -> VMStoreContext<&Self> { ... } fn vm_lazy_thread(&self) -> VMLazyThread<&Self> { ... } fn vm_deferred_thread(&self) -> VMDeferredThread<&Self> { ... } fn vmctx(&self) -> VMContext<&Self> { ... } fn vmcomponent(&self) -> VMComponentContext<&Self> { ... } fn size_of_vmshared_type_index(&self) -> u8 { ... } fn align_of_vmshared_type_index(&self) -> u8 { ... } fn maximum_value_size(&self) -> u8 { ... } fn size_of_vmmemory_pointer(&self) -> u8 { ... } fn vmarray_call_host_func_context_func_ref(&self) -> u8 { ... } fn size_of_vmstack_chain(&self) -> u8 { ... } fn vmstack_limits_stack_limit(&self) -> u8 { ... } fn vmstack_limits_last_wasm_entry_fp(&self) -> u8 { ... } fn vmstack_limits_last_wasm_entry_sp(&self) -> u8 { ... } fn vmstack_limits_last_wasm_entry_trap_handler(&self) -> u8 { ... } fn vmhostarray_length(&self) -> u8 { ... } fn vmhostarray_capacity(&self) -> u8 { ... } fn vmhostarray_data(&self) -> u8 { ... } fn size_of_vmhostarray(&self) -> u8 { ... } fn vmcommon_stack_information_limits(&self) -> u8 { ... } fn vmcommon_stack_information_state(&self) -> u8 { ... } fn vmcommon_stack_information_handlers(&self) -> u8 { ... } fn vmcommon_stack_information_first_switch_handler_index(&self) -> u8 { ... } fn size_of_vmcommon_stack_information(&self) -> u8 { ... } fn vmcontobj_contref(&self) -> u8 { ... } fn vmcontobj_revision(&self) -> u8 { ... } fn size_of_vmcontobj(&self) -> u8 { ... } fn vmcontref_common_stack_information(&self) -> u8 { ... } fn vmcontref_parent_chain(&self) -> u8 { ... } fn vmcontref_last_ancestor(&self) -> u8 { ... } fn vmcontref_revision(&self) -> u8 { ... } fn vmcontref_stack(&self) -> u8 { ... } fn vmcontref_args(&self) -> u8 { ... } fn vmcontref_values(&self) -> u8 { ... } fn vmdrc_heap_data_over_approximated_stack_roots(&self) -> u8 { ... } fn vmdrc_heap_data_current_over_approximated_stack_roots_len(&self) -> u8 { ... } fn vmdrc_heap_data_over_approximated_stack_roots_len_after_last_gc( &self, ) -> u8 { ... } fn size_of_vmdrc_heap_data(&self) -> u8 { ... } fn align_of_vmdrc_heap_data(&self) -> u8 { ... } fn vmcopying_heap_data_bump_ptr(&self) -> u8 { ... } fn vmcopying_heap_data_active_space_end(&self) -> u8 { ... } fn size_of_vmcopying_heap_data(&self) -> u8 { ... } fn align_of_vmcopying_heap_data(&self) -> u8 { ... }
}
Trait used for the ptr representation of the field of VMOffsets

Required Methods

fn size(&self) -> u8

Returns the pointer size, in bytes, for the target.

Provided Methods

fn vm_memory_definition(&self) -> VMMemoryDefinition<&Self>

Get the offsets::VMMemoryDefinition offsets for this pointer size.

fn vm_table_definition(&self) -> VMTableDefinition<&Self>

Get the offsets::VMTableDefinition offsets for this pointer size.

fn vm_global_definition(&self) -> VMGlobalDefinition<&Self>

Get the offsets::VMGlobalDefinition offsets for this pointer size.

fn vm_tag_definition(&self) -> VMTagDefinition<&Self>

Get the offsets::VMTagDefinition offsets for this pointer size.

fn vm_func_ref(&self) -> VMFuncRef<&Self>

Get the offsets::VMFuncRef offsets for this pointer size.

fn vm_function_import(&self) -> VMFunctionImport<&Self>

Get the offsets::VMFunctionImport offsets for this pointer size.

fn vm_table_import(&self) -> VMTableImport<&Self>

Get the offsets::VMTableImport offsets for this pointer size.

fn vm_memory_import(&self) -> VMMemoryImport<&Self>

Get the offsets::VMMemoryImport offsets for this pointer size.

fn vm_global_import(&self) -> VMGlobalImport<&Self>

Get the offsets::VMGlobalImport offsets for this pointer size.

fn vm_tag_import(&self) -> VMTagImport<&Self>

Get the offsets::VMTagImport offsets for this pointer size.

fn vm_store_context(&self) -> VMStoreContext<&Self>

Get the offsets::VMStoreContext offsets for this pointer size.

fn vm_lazy_thread(&self) -> VMLazyThread<&Self>

Get the offsets::VMLazyThread offsets for this pointer size.

fn vm_deferred_thread(&self) -> VMDeferredThread<&Self>

Get the offsets::VMDeferredThread offsets for this pointer size.

fn vmctx(&self) -> VMContext<&Self>

Get the offsets::VMContext offsets for this pointer size.

fn vmcomponent(&self) -> VMComponentContext<&Self>

Get the offsets::VMComponentContext offsets for this pointer size.

fn size_of_vmshared_type_index(&self) -> u8

Return the size of VMSharedTypeIndex.

fn align_of_vmshared_type_index(&self) -> u8

Return the alignment of VMSharedTypeIndex.

fn maximum_value_size(&self) -> u8

This is the size of the largest value type (i.e. a V128).

fn size_of_vmmemory_pointer(&self) -> u8

Return the size of *mut VMMemoryDefinition.

fn vmarray_call_host_func_context_func_ref(&self) -> u8

Return the offset of VMArrayCallHostFuncContext::func_ref.

fn size_of_vmstack_chain(&self) -> u8

Return the size of VMStackChain.

fn vmstack_limits_stack_limit(&self) -> u8

Return the offset of VMStackLimits::stack_limit.

fn vmstack_limits_last_wasm_entry_fp(&self) -> u8

Return the offset of VMStackLimits::last_wasm_entry_fp.

fn vmstack_limits_last_wasm_entry_sp(&self) -> u8

Return the offset of VMStackLimits::last_wasm_entry_sp.

fn vmstack_limits_last_wasm_entry_trap_handler(&self) -> u8

Return the offset of VMStackLimits::last_wasm_entry_trap_handler.

fn vmhostarray_length(&self) -> u8

Return the offset of VMHostArray::length.

fn vmhostarray_capacity(&self) -> u8

Return the offset of VMHostArray::capacity.

fn vmhostarray_data(&self) -> u8

Return the offset of VMHostArray::data.

fn size_of_vmhostarray(&self) -> u8

Return the size of VMHostArray.

fn vmcommon_stack_information_limits(&self) -> u8

Return the offset of VMCommonStackInformation::limits.

fn vmcommon_stack_information_state(&self) -> u8

Return the offset of VMCommonStackInformation::state.

fn vmcommon_stack_information_handlers(&self) -> u8

Return the offset of VMCommonStackInformation::handlers.

fn vmcommon_stack_information_first_switch_handler_index(&self) -> u8

Return the offset of VMCommonStackInformation::first_switch_handler_index.

fn size_of_vmcommon_stack_information(&self) -> u8

Return the size of VMCommonStackInformation.

fn vmcontobj_contref(&self) -> u8

Return the offset of VMContObj::contref

fn vmcontobj_revision(&self) -> u8

Return the offset of VMContObj::revision

fn size_of_vmcontobj(&self) -> u8

Return the size of VMContObj.

fn vmcontref_common_stack_information(&self) -> u8

Return the offset of VMContRef::common_stack_information.

fn vmcontref_parent_chain(&self) -> u8

Return the offset of VMContRef::parent_chain.

fn vmcontref_last_ancestor(&self) -> u8

Return the offset of VMContRef::last_ancestor.

fn vmcontref_revision(&self) -> u8

Return the offset of VMContRef::revision.

fn vmcontref_stack(&self) -> u8

Return the offset of VMContRef::stack.

fn vmcontref_args(&self) -> u8

Return the offset of VMContRef::args.

fn vmcontref_values(&self) -> u8

Return the offset of VMContRef::values.

fn vmdrc_heap_data_over_approximated_stack_roots(&self) -> u8

Return the offset of the over_approximated_stack_roots field within VMDrcHeapData.

fn vmdrc_heap_data_current_over_approximated_stack_roots_len(&self) -> u8

Return the offset of the current_over_approximated_stack_roots_len field within VMDrcHeapData.

fn vmdrc_heap_data_over_approximated_stack_roots_len_after_last_gc(&self) -> u8

Return the offset of the over_approximated_stack_roots_len_after_last_gc field within VMDrcHeapData.

fn size_of_vmdrc_heap_data(&self) -> u8

Return the size of VMDrcHeapData.

fn align_of_vmdrc_heap_data(&self) -> u8

Return the alignment of VMDrcHeapData.

fn vmcopying_heap_data_bump_ptr(&self) -> u8

Return the offset of the bump_ptr field within VMCopyingHeapData.

fn vmcopying_heap_data_active_space_end(&self) -> u8

Return the offset of the active_space_end field within VMCopyingHeapData.

fn size_of_vmcopying_heap_data(&self) -> u8

Return the size of VMCopyingHeapData.

fn align_of_vmcopying_heap_data(&self) -> u8

Return the alignment of VMCopyingHeapData.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl PtrSize for u8

Source

fn size(&self) -> u8

Source

impl<P> PtrSize for &P
where P: PtrSize + ?Sized,

Source

fn size(&self) -> u8

Implementors