pub trait PtrSize {
Show 70 methods
// Required method
fn size(&self) -> u8;
// Provided methods
fn vmcontext_store_context(&self) -> u8 { ... }
fn vmcontext_builtin_functions(&self) -> u8 { ... }
fn vm_func_ref_array_call(&self) -> u8 { ... }
fn vm_func_ref_wasm_call(&self) -> u8 { ... }
fn vm_func_ref_type_index(&self) -> u8 { ... }
fn vm_func_ref_vmctx(&self) -> u8 { ... }
fn size_of_vm_func_ref(&self) -> u8 { ... }
fn size_of_vmglobal_definition(&self) -> u8 { ... }
fn size_of_vmtag_definition(&self) -> u8 { ... }
fn maximum_value_size(&self) -> u8 { ... }
fn vmstore_context_fuel_consumed(&self) -> u8 { ... }
fn vmstore_context_epoch_deadline(&self) -> u8 { ... }
fn vmstore_context_execution_version(&self) -> u8 { ... }
fn vmstore_context_stack_limit(&self) -> u8 { ... }
fn vmstore_context_gc_heap(&self) -> u8 { ... }
fn vmstore_context_gc_heap_base(&self) -> u8 { ... }
fn vmstore_context_gc_heap_current_length(&self) -> u8 { ... }
fn vmstore_context_last_wasm_exit_trampoline_fp(&self) -> u8 { ... }
fn vmstore_context_last_wasm_exit_pc(&self) -> u8 { ... }
fn vmstore_context_last_wasm_entry_sp(&self) -> u8 { ... }
fn vmstore_context_last_wasm_entry_fp(&self) -> u8 { ... }
fn vmstore_context_last_wasm_entry_trap_handler(&self) -> u8 { ... }
fn vmstore_context_stack_chain(&self) -> u8 { ... }
fn vmstore_context_store_data(&self) -> u8 { ... }
fn vmstore_context_async_guard_range(&self) -> u8 { ... }
fn vmstore_context_component_context_slot(&self, i: u8) -> u8 { ... }
fn vmmemory_definition_base(&self) -> u8 { ... }
fn vmmemory_definition_current_length(&self) -> u8 { ... }
fn size_of_vmmemory_definition(&self) -> u8 { ... }
fn size_of_vmmemory_pointer(&self) -> u8 { ... }
fn vmarray_call_host_func_context_func_ref(&self) -> u8 { ... }
fn size_of_vmstack_chain(&self) -> u8 { ... }
fn vmstack_limits_stack_limit(&self) -> u8 { ... }
fn vmstack_limits_last_wasm_entry_fp(&self) -> u8 { ... }
fn vmhostarray_length(&self) -> u8 { ... }
fn vmhostarray_capacity(&self) -> u8 { ... }
fn vmhostarray_data(&self) -> u8 { ... }
fn size_of_vmhostarray(&self) -> u8 { ... }
fn vmcommon_stack_information_limits(&self) -> u8 { ... }
fn vmcommon_stack_information_state(&self) -> u8 { ... }
fn vmcommon_stack_information_handlers(&self) -> u8 { ... }
fn vmcommon_stack_information_first_switch_handler_index(&self) -> u8 { ... }
fn size_of_vmcommon_stack_information(&self) -> u8 { ... }
fn vmcontobj_contref(&self) -> u8 { ... }
fn vmcontobj_revision(&self) -> u8 { ... }
fn size_of_vmcontobj(&self) -> u8 { ... }
fn vmcontref_common_stack_information(&self) -> u8 { ... }
fn vmcontref_parent_chain(&self) -> u8 { ... }
fn vmcontref_last_ancestor(&self) -> u8 { ... }
fn vmcontref_revision(&self) -> u8 { ... }
fn vmcontref_stack(&self) -> u8 { ... }
fn vmcontref_args(&self) -> u8 { ... }
fn vmcontref_values(&self) -> u8 { ... }
fn vmctx_magic(&self) -> u8 { ... }
fn vmctx_store_context(&self) -> u8 { ... }
fn vmctx_builtin_functions(&self) -> u8 { ... }
fn vmctx_epoch_ptr(&self) -> u8 { ... }
fn vmctx_gc_heap_data(&self) -> u8 { ... }
fn vmdrc_heap_data_over_approximated_stack_roots(&self) -> u8 { ... }
fn vmdrc_heap_data_current_over_approximated_stack_roots_len(&self) -> u8 { ... }
fn vmdrc_heap_data_over_approximated_stack_roots_len_after_last_gc(
&self,
) -> u8 { ... }
fn size_of_vmdrc_heap_data(&self) -> u8 { ... }
fn align_of_vmdrc_heap_data(&self) -> u8 { ... }
fn vmcopying_heap_data_bump_ptr(&self) -> u8 { ... }
fn vmcopying_heap_data_active_space_end(&self) -> u8 { ... }
fn size_of_vmcopying_heap_data(&self) -> u8 { ... }
fn align_of_vmcopying_heap_data(&self) -> u8 { ... }
fn vmctx_type_ids_array(&self) -> u8 { ... }
fn vmctx_dynamic_data_start(&self) -> u8 { ... }
}Expand description
Trait used for the ptr representation of the field of VMOffsets
Required Methods
Provided Methods
Sourcefn vmcontext_store_context(&self) -> u8
fn vmcontext_store_context(&self) -> u8
The offset of the VMContext::store_context field
Sourcefn vmcontext_builtin_functions(&self) -> u8
fn vmcontext_builtin_functions(&self) -> u8
The offset of the VMContext::builtin_functions field
Sourcefn vm_func_ref_array_call(&self) -> u8
fn vm_func_ref_array_call(&self) -> u8
The offset of the array_call field.
Sourcefn vm_func_ref_wasm_call(&self) -> u8
fn vm_func_ref_wasm_call(&self) -> u8
The offset of the wasm_call field.
Sourcefn vm_func_ref_type_index(&self) -> u8
fn vm_func_ref_type_index(&self) -> u8
The offset of the type_index field.
Sourcefn vm_func_ref_vmctx(&self) -> u8
fn vm_func_ref_vmctx(&self) -> u8
The offset of the vmctx field.
Sourcefn size_of_vm_func_ref(&self) -> u8
fn size_of_vm_func_ref(&self) -> u8
Return the size of VMFuncRef.
Sourcefn size_of_vmglobal_definition(&self) -> u8
fn size_of_vmglobal_definition(&self) -> u8
Return the size of VMGlobalDefinition; this is the size of the largest value type (i.e. a
V128).
Sourcefn size_of_vmtag_definition(&self) -> u8
fn size_of_vmtag_definition(&self) -> u8
Return the size of VMTagDefinition.
Sourcefn maximum_value_size(&self) -> u8
fn maximum_value_size(&self) -> u8
This is the size of the largest value type (i.e. a V128).
Sourcefn vmstore_context_fuel_consumed(&self) -> u8
fn vmstore_context_fuel_consumed(&self) -> u8
Return the offset of the fuel_consumed field of VMStoreContext
Sourcefn vmstore_context_epoch_deadline(&self) -> u8
fn vmstore_context_epoch_deadline(&self) -> u8
Return the offset of the epoch_deadline field of VMStoreContext
Sourcefn vmstore_context_execution_version(&self) -> u8
fn vmstore_context_execution_version(&self) -> u8
Return the offset of the execution_version field of
VMStoreContext
Sourcefn vmstore_context_stack_limit(&self) -> u8
fn vmstore_context_stack_limit(&self) -> u8
Return the offset of the stack_limit field of VMStoreContext
Sourcefn vmstore_context_gc_heap(&self) -> u8
fn vmstore_context_gc_heap(&self) -> u8
Return the offset of the gc_heap field of VMStoreContext.
Sourcefn vmstore_context_gc_heap_base(&self) -> u8
fn vmstore_context_gc_heap_base(&self) -> u8
Return the offset of the gc_heap.base field within a VMStoreContext.
Sourcefn vmstore_context_gc_heap_current_length(&self) -> u8
fn vmstore_context_gc_heap_current_length(&self) -> u8
Return the offset of the gc_heap.current_length field within a VMStoreContext.
Sourcefn vmstore_context_last_wasm_exit_trampoline_fp(&self) -> u8
fn vmstore_context_last_wasm_exit_trampoline_fp(&self) -> u8
Return the offset of the last_wasm_exit_trampoline_fp field
of VMStoreContext.
Sourcefn vmstore_context_last_wasm_exit_pc(&self) -> u8
fn vmstore_context_last_wasm_exit_pc(&self) -> u8
Return the offset of the last_wasm_exit_pc field of VMStoreContext.
Sourcefn vmstore_context_last_wasm_entry_sp(&self) -> u8
fn vmstore_context_last_wasm_entry_sp(&self) -> u8
Return the offset of the last_wasm_entry_sp field of VMStoreContext.
Sourcefn vmstore_context_last_wasm_entry_fp(&self) -> u8
fn vmstore_context_last_wasm_entry_fp(&self) -> u8
Return the offset of the last_wasm_entry_fp field of VMStoreContext.
Sourcefn vmstore_context_last_wasm_entry_trap_handler(&self) -> u8
fn vmstore_context_last_wasm_entry_trap_handler(&self) -> u8
Return the offset of the last_wasm_entry_trap_handler field of VMStoreContext.
Sourcefn vmstore_context_stack_chain(&self) -> u8
fn vmstore_context_stack_chain(&self) -> u8
Return the offset of the stack_chain field of VMStoreContext.
Sourcefn vmstore_context_store_data(&self) -> u8
fn vmstore_context_store_data(&self) -> u8
Return the offset of the stack_chain field of VMStoreContext.
Sourcefn vmstore_context_async_guard_range(&self) -> u8
fn vmstore_context_async_guard_range(&self) -> u8
Return the offset of the async_guard_range field of VMStoreContext.
Sourcefn vmstore_context_component_context_slot(&self, i: u8) -> u8
fn vmstore_context_component_context_slot(&self, i: u8) -> u8
Return the offset of the component_context[i] field of
VMStoreContext.
Sourcefn vmmemory_definition_base(&self) -> u8
fn vmmemory_definition_base(&self) -> u8
The offset of the base field.
Sourcefn vmmemory_definition_current_length(&self) -> u8
fn vmmemory_definition_current_length(&self) -> u8
The offset of the current_length field.
Sourcefn size_of_vmmemory_definition(&self) -> u8
fn size_of_vmmemory_definition(&self) -> u8
Return the size of VMMemoryDefinition.
Sourcefn size_of_vmmemory_pointer(&self) -> u8
fn size_of_vmmemory_pointer(&self) -> u8
Return the size of *mut VMMemoryDefinition.
Sourcefn vmarray_call_host_func_context_func_ref(&self) -> u8
fn vmarray_call_host_func_context_func_ref(&self) -> u8
Return the offset of VMArrayCallHostFuncContext::func_ref.
Sourcefn size_of_vmstack_chain(&self) -> u8
fn size_of_vmstack_chain(&self) -> u8
Return the size of VMStackChain.
Sourcefn vmstack_limits_stack_limit(&self) -> u8
fn vmstack_limits_stack_limit(&self) -> u8
Return the offset of VMStackLimits::stack_limit.
Sourcefn vmstack_limits_last_wasm_entry_fp(&self) -> u8
fn vmstack_limits_last_wasm_entry_fp(&self) -> u8
Return the offset of VMStackLimits::last_wasm_entry_fp.
Sourcefn vmhostarray_length(&self) -> u8
fn vmhostarray_length(&self) -> u8
Return the offset of VMHostArray::length.
Sourcefn vmhostarray_capacity(&self) -> u8
fn vmhostarray_capacity(&self) -> u8
Return the offset of VMHostArray::capacity.
Sourcefn vmhostarray_data(&self) -> u8
fn vmhostarray_data(&self) -> u8
Return the offset of VMHostArray::data.
Sourcefn size_of_vmhostarray(&self) -> u8
fn size_of_vmhostarray(&self) -> u8
Return the size of VMHostArray.
Sourcefn vmcommon_stack_information_limits(&self) -> u8
fn vmcommon_stack_information_limits(&self) -> u8
Return the offset of VMCommonStackInformation::limits.
Sourcefn vmcommon_stack_information_state(&self) -> u8
fn vmcommon_stack_information_state(&self) -> u8
Return the offset of VMCommonStackInformation::state.
Sourcefn vmcommon_stack_information_handlers(&self) -> u8
fn vmcommon_stack_information_handlers(&self) -> u8
Return the offset of VMCommonStackInformation::handlers.
Sourcefn vmcommon_stack_information_first_switch_handler_index(&self) -> u8
fn vmcommon_stack_information_first_switch_handler_index(&self) -> u8
Return the offset of VMCommonStackInformation::first_switch_handler_index.
Sourcefn size_of_vmcommon_stack_information(&self) -> u8
fn size_of_vmcommon_stack_information(&self) -> u8
Return the size of VMCommonStackInformation.
Sourcefn vmcontobj_contref(&self) -> u8
fn vmcontobj_contref(&self) -> u8
Return the offset of VMContObj::contref
Sourcefn vmcontobj_revision(&self) -> u8
fn vmcontobj_revision(&self) -> u8
Return the offset of VMContObj::revision
Sourcefn size_of_vmcontobj(&self) -> u8
fn size_of_vmcontobj(&self) -> u8
Return the size of VMContObj.
Sourcefn vmcontref_common_stack_information(&self) -> u8
fn vmcontref_common_stack_information(&self) -> u8
Return the offset of VMContRef::common_stack_information.
Sourcefn vmcontref_parent_chain(&self) -> u8
fn vmcontref_parent_chain(&self) -> u8
Return the offset of VMContRef::parent_chain.
Sourcefn vmcontref_last_ancestor(&self) -> u8
fn vmcontref_last_ancestor(&self) -> u8
Return the offset of VMContRef::last_ancestor.
Sourcefn vmcontref_revision(&self) -> u8
fn vmcontref_revision(&self) -> u8
Return the offset of VMContRef::revision.
Sourcefn vmcontref_stack(&self) -> u8
fn vmcontref_stack(&self) -> u8
Return the offset of VMContRef::stack.
Sourcefn vmcontref_args(&self) -> u8
fn vmcontref_args(&self) -> u8
Return the offset of VMContRef::args.
Sourcefn vmcontref_values(&self) -> u8
fn vmcontref_values(&self) -> u8
Return the offset of VMContRef::values.
Sourcefn vmctx_magic(&self) -> u8
fn vmctx_magic(&self) -> u8
Return the offset to the magic value in this VMContext.
Sourcefn vmctx_store_context(&self) -> u8
fn vmctx_store_context(&self) -> u8
Return the offset to the VMStoreContext structure
Sourcefn vmctx_builtin_functions(&self) -> u8
fn vmctx_builtin_functions(&self) -> u8
Return the offset to the VMBuiltinFunctionsArray structure
Sourcefn vmctx_epoch_ptr(&self) -> u8
fn vmctx_epoch_ptr(&self) -> u8
Return the offset to the *const AtomicU64 epoch-counter
pointer.
Sourcefn vmctx_gc_heap_data(&self) -> u8
fn vmctx_gc_heap_data(&self) -> u8
Return the offset to the *mut T collector-specific data.
This is a pointer that different collectors can use however they see fit.
Sourcefn vmdrc_heap_data_over_approximated_stack_roots(&self) -> u8
fn vmdrc_heap_data_over_approximated_stack_roots(&self) -> u8
Return the offset of the over_approximated_stack_roots field within
VMDrcHeapData.
Sourcefn vmdrc_heap_data_current_over_approximated_stack_roots_len(&self) -> u8
fn vmdrc_heap_data_current_over_approximated_stack_roots_len(&self) -> u8
Return the offset of the current_over_approximated_stack_roots_len
field within VMDrcHeapData.
Sourcefn vmdrc_heap_data_over_approximated_stack_roots_len_after_last_gc(&self) -> u8
fn vmdrc_heap_data_over_approximated_stack_roots_len_after_last_gc(&self) -> u8
Return the offset of the
over_approximated_stack_roots_len_after_last_gc field within
VMDrcHeapData.
Sourcefn size_of_vmdrc_heap_data(&self) -> u8
fn size_of_vmdrc_heap_data(&self) -> u8
Return the size of VMDrcHeapData.
Sourcefn align_of_vmdrc_heap_data(&self) -> u8
fn align_of_vmdrc_heap_data(&self) -> u8
Return the alignment of VMDrcHeapData.
Sourcefn vmcopying_heap_data_bump_ptr(&self) -> u8
fn vmcopying_heap_data_bump_ptr(&self) -> u8
Return the offset of the bump_ptr field within VMCopyingHeapData.
Sourcefn vmcopying_heap_data_active_space_end(&self) -> u8
fn vmcopying_heap_data_active_space_end(&self) -> u8
Return the offset of the active_space_end field within
VMCopyingHeapData.
Sourcefn size_of_vmcopying_heap_data(&self) -> u8
fn size_of_vmcopying_heap_data(&self) -> u8
Return the size of VMCopyingHeapData.
Sourcefn align_of_vmcopying_heap_data(&self) -> u8
fn align_of_vmcopying_heap_data(&self) -> u8
Return the alignment of VMCopyingHeapData.
Sourcefn vmctx_type_ids_array(&self) -> u8
fn vmctx_type_ids_array(&self) -> u8
The offset of the type_ids array pointer.
Sourcefn vmctx_dynamic_data_start(&self) -> u8
fn vmctx_dynamic_data_start(&self) -> u8
The end of statically known offsets in VMContext.
Data after this is dynamically sized.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".